import React, { useState } from 'react';
import { BrowserRouter as Router, Routes, Route, useNavigate } from 'react-router-dom';
import { Layout, Menu, Typography, ConfigProvider } from 'antd';
import {
  DashboardOutlined,
  PhoneOutlined,
  FileTextOutlined,
  CalendarOutlined,
  UserOutlined,
  TeamOutlined,
  DollarOutlined,
  SettingOutlined,
  WalletOutlined,
  BarChartOutlined,
  CalculatorOutlined
} from '@ant-design/icons';
import zhCN from 'antd/locale/zh_CN';
import 'antd/dist/reset.css';
import './App.css';

// 导入页面组件
import Dashboard from './pages/Dashboard';
import CallList from './pages/Calls/CallList';
import CallDetail from './pages/Calls/CallDetail';
import DocumentList from './pages/Documents/DocumentList';
import DocumentDetail from './pages/Documents/DocumentDetail';
import AppointmentList from './pages/Appointments/AppointmentList';
import AppointmentDetail from './pages/Appointments/AppointmentDetail';
import UserList from './pages/Users/UserList';
import TranslatorList from './pages/Translators/TranslatorList';
import PaymentList from './pages/Payments/PaymentList';
import SystemSettings from './pages/Settings/SystemSettings';

// 导入计费管理页面
import BillingRules from './pages/Billing/BillingRules';
import UserAccounts from './pages/Billing/UserAccounts';
import BillingStats from './pages/Billing/BillingStats';

const { Header, Sider, Content } = Layout;
const { Title } = Typography;

const AppContent: React.FC = () => {
  const [collapsed, setCollapsed] = useState(false);
  const navigate = useNavigate();

  const handleMenuClick = ({ key }: { key: string }) => {
    switch (key) {
      case 'dashboard':
        navigate('/');
        break;
      case 'calls':
        navigate('/calls');
        break;
      case 'documents':
        navigate('/documents');
        break;
      case 'appointments':
        navigate('/appointments');
        break;
      case 'users':
        navigate('/users');
        break;
      case 'translators':
        navigate('/translators');
        break;
      case 'payments':
        navigate('/payments');
        break;
      case 'billing-rules':
        navigate('/billing/rules');
        break;
      case 'user-accounts':
        navigate('/billing/accounts');
        break;
      case 'billing-stats':
        navigate('/billing/stats');
        break;
      case 'settings':
        navigate('/settings');
        break;
      default:
        navigate('/');
    }
  };

  const menuItems = [
    {
      key: 'dashboard',
      icon: <DashboardOutlined />,
      label: '仪表板',
    },
    {
      key: 'calls',
      icon: <PhoneOutlined />,
      label: '通话记录',
    },
    {
      key: 'documents',
      icon: <FileTextOutlined />,
      label: '文档翻译',
    },
    {
      key: 'appointments',
      icon: <CalendarOutlined />,
      label: '预约管理',
    },
    {
      key: 'users',
      icon: <UserOutlined />,
      label: '用户管理',
    },
    {
      key: 'translators',
      icon: <TeamOutlined />,
      label: '译员管理',
    },
    {
      key: 'billing',
      icon: <CalculatorOutlined />,
      label: '计费管理',
      children: [
        {
          key: 'billing-rules',
          icon: <CalculatorOutlined />,
          label: '计费规则',
        },
        {
          key: 'user-accounts',
          icon: <WalletOutlined />,
          label: '用户账户',
        },
        {
          key: 'billing-stats',
          icon: <BarChartOutlined />,
          label: '计费统计',
        },
      ],
    },
    {
      key: 'payments',
      icon: <DollarOutlined />,
      label: '支付记录',
    },
    {
      key: 'settings',
      icon: <SettingOutlined />,
      label: '系统设置',
    },
  ];

  return (
    <Layout style={{ minHeight: '100vh' }}>
      <Sider
        collapsible
        collapsed={collapsed}
        onCollapse={setCollapsed}
        theme="dark"
        width={250}
      >
        <div style={{ 
          height: '64px', 
          display: 'flex', 
          alignItems: 'center', 
          justifyContent: 'center',
          color: 'white',
          fontSize: '18px',
          fontWeight: 'bold'
        }}>
          {collapsed ? 'T' : 'Twilio管理后台'}
        </div>
        <Menu
          theme="dark"
          defaultSelectedKeys={['dashboard']}
          mode="inline"
          items={menuItems}
          onClick={handleMenuClick}
        />
      </Sider>
      
      <Layout>
        <Header style={{ 
          padding: '0 24px', 
          background: '#fff', 
          display: 'flex', 
          alignItems: 'center',
          borderBottom: '1px solid #f0f0f0'
        }}>
          <Title level={4} style={{ margin: 0 }}>
            Twilio翻译服务管理系统
          </Title>
        </Header>
        
        <Content style={{ 
          margin: '0', 
          background: '#f0f2f5',
          minHeight: 'calc(100vh - 64px)'
        }}>
          <div style={{ padding: '24px' }}>
            <Routes>
              <Route path="/" element={<Dashboard />} />
              <Route path="/calls" element={<CallList />} />
              <Route path="/calls/:id" element={<CallDetail />} />
              <Route path="/documents" element={<DocumentList />} />
              <Route path="/documents/:id" element={<DocumentDetail />} />
              <Route path="/appointments" element={<AppointmentList />} />
              <Route path="/appointments/:id" element={<AppointmentDetail />} />
              <Route path="/users" element={<UserList />} />
              <Route path="/translators" element={<TranslatorList />} />
              <Route path="/payments" element={<PaymentList />} />
              
              {/* 计费管理路由 */}
              <Route path="/billing/rules" element={<BillingRules />} />
              <Route path="/billing/accounts" element={<UserAccounts />} />
              <Route path="/billing/stats" element={<BillingStats />} />
              
              <Route path="/settings" element={<SystemSettings />} />
              <Route path="*" element={<Dashboard />} />
            </Routes>
          </div>
        </Content>
      </Layout>
    </Layout>
  );
};

const App: React.FC = () => {
  return (
    <ConfigProvider locale={zhCN}>
      <Router>
        <AppContent />
      </Router>
    </ConfigProvider>
  );
};

export default App; 