import React, { useState, useEffect } from 'react';
import { useParams, useNavigate } from 'react-router-dom';
import {
  Card,
  Descriptions,
  Button,
  Tag,
  Typography,
  Space,
  Modal,
  Input,
  message,
  Spin,
  Timeline,
  Tabs,
  Avatar,
  Select,
  Form,
  Alert,
  DatePicker,
  Rate,
  Statistic,
  Row,
  Col,
} from 'antd';
import {
  ArrowLeftOutlined,
  CalendarOutlined,
  ClockCircleOutlined,
  UserOutlined,
  PhoneOutlined,
  VideoCameraOutlined,
  DollarOutlined,
  EditOutlined,
  CheckCircleOutlined,
  StarOutlined,
  MessageOutlined,
  SettingOutlined,
  TeamOutlined,
  GlobalOutlined,
  AuditOutlined,
  EnvironmentOutlined,
  ReloadOutlined,
} from '@ant-design/icons';
import moment from 'moment';
import { Appointment } from '../../types';
import { database } from '../../utils/database';
import { api } from '../../utils/api';

const { Title, Text, Paragraph } = Typography;
const { TextArea } = Input;
const { TabPane } = Tabs;
const { Option } = Select;
const { RangePicker } = DatePicker;

interface AppointmentDetailProps {}

const AppointmentDetail: React.FC<AppointmentDetailProps> = () => {
  const { id } = useParams<{ id: string }>();
  const navigate = useNavigate();
  
  const [appointment, setAppointment] = useState<Appointment | null>(null);
  const [loading, setLoading] = useState(true);
  const [editModalVisible, setEditModalVisible] = useState(false);
  const [statusModalVisible, setStatusModalVisible] = useState(false);
  const [rescheduleModalVisible, setRescheduleModalVisible] = useState(false);
  const [reassignModalVisible, setReassignModalVisible] = useState(false);
  const [refundModalVisible, setRefundModalVisible] = useState(false);
  const [adminNoteModalVisible, setAdminNoteModalVisible] = useState(false);
  const [form] = Form.useForm();
  const [statusForm] = Form.useForm();
  const [rescheduleForm] = Form.useForm();
  const [reassignForm] = Form.useForm();
  const [refundForm] = Form.useForm();
  const [noteForm] = Form.useForm();

  useEffect(() => {
    if (id) {
      loadAppointmentDetails();
    }
  }, [id]);

  const loadAppointmentDetails = async () => {
    try {
      setLoading(true);
      
      // 模拟获取预约详情（管理员视角）
      const mockAppointment: Appointment = {
        id: id!,
        userId: 'user_1',
        translatorId: 'translator_1',
        title: '商务会议口译',
        description: '重要商务合作谈判，需要专业口译服务',
        type: 'interpretation',
        sourceLanguage: 'zh-CN',
        targetLanguage: 'en-US',
        startTime: '2024-01-20T14:00:00Z',
        endTime: '2024-01-20T16:00:00Z',
        status: 'confirmed',
        cost: 380.00,
        meetingUrl: 'https://zoom.us/j/123456789',
        notes: '客户要求专业商务术语翻译，注意礼貌用语',
        reminderSent: true,
        createdAt: '2024-01-15T10:00:00Z',
        updatedAt: '2024-01-16T09:30:00Z',
        // 管理员相关字段
        clientName: '陈总',
        clientEmail: 'chen@company.com',
        clientPhone: '+86 138 0013 8000',
        translatorName: '李翻译',
        translatorEmail: 'li@translator.com',
        translatorPhone: '+86 138 0013 8001',
        adminNotes: '高级客户，服务质量要求高',
        paymentStatus: 'paid',
        refundAmount: 0,
        qualityScore: 96,
        issues: [],
        rating: 5,
        feedback: '翻译非常专业，帮助我们成功完成了商务谈判。',
        location: '上海市浦东新区陆家嘴金融中心',
        urgency: 'normal',
      };

      setAppointment(mockAppointment);
      
      // 填充表单数据
      form.setFieldsValue({
        title: mockAppointment.title,
        description: mockAppointment.description,
        type: mockAppointment.type,
        cost: mockAppointment.cost,
        location: mockAppointment.location,
        urgency: mockAppointment.urgency,
      });
      
      statusForm.setFieldsValue({
        status: mockAppointment.status,
      });
      
    } catch (error) {
      console.error('加载预约详情失败:', error);
      message.error('加载预约详情失败');
    } finally {
      setLoading(false);
    }
  };

  const handleEdit = async (values: any) => {
    if (!appointment) return;
    
    try {
      const updatedAppointment = {
        ...appointment,
        ...values,
        updatedAt: new Date().toISOString(),
      };
      
      setAppointment(updatedAppointment);
      setEditModalVisible(false);
      message.success('预约信息更新成功');
    } catch (error) {
      message.error('更新预约信息失败');
    }
  };

  const handleStatusChange = async (values: any) => {
    if (!appointment) return;
    
    try {
      const updatedAppointment = {
        ...appointment,
        status: values.status,
        updatedAt: new Date().toISOString(),
      };
      
      setAppointment(updatedAppointment);
      setStatusModalVisible(false);
      message.success('状态更新成功');
    } catch (error) {
      message.error('更新状态失败');
    }
  };

  const handleReschedule = async (values: any) => {
    if (!appointment) return;
    
    try {
      const updatedAppointment = {
        ...appointment,
        startTime: values.timeRange[0].toISOString(),
        endTime: values.timeRange[1].toISOString(),
        adminNotes: `${appointment.adminNotes || ''}\n改期原因: ${values.reason}`,
        updatedAt: new Date().toISOString(),
      };
      
      setAppointment(updatedAppointment);
      setRescheduleModalVisible(false);
      message.success('预约时间更新成功');
    } catch (error) {
      message.error('更新预约时间失败');
    }
  };

  const handleReassign = async (values: any) => {
    if (!appointment) return;
    
    try {
      const updatedAppointment = {
        ...appointment,
        translatorId: values.translatorId,
        translatorName: values.translatorName,
        translatorEmail: values.translatorEmail,
        translatorPhone: values.translatorPhone,
        adminNotes: `${appointment.adminNotes || ''}\n重新分配译员原因: ${values.reason}`,
        updatedAt: new Date().toISOString(),
      };
      
      setAppointment(updatedAppointment);
      setReassignModalVisible(false);
      message.success('译员重新分配成功');
    } catch (error) {
      message.error('重新分配译员失败');
    }
  };

  const handleRefund = async (values: any) => {
    if (!appointment) return;
    
    try {
      const refundAmount = values.amount || appointment.cost;
      
      const updatedAppointment: Appointment = {
        ...appointment,
        refundAmount: refundAmount,
        paymentStatus: 'refunded' as const,
        status: 'cancelled' as const,
        updatedAt: new Date().toISOString(),
      };
      
      setAppointment(updatedAppointment);
      setRefundModalVisible(false);
      message.success('退款处理成功');
    } catch (error) {
      message.error('退款处理失败');
    }
  };

  const handleAddAdminNote = async (values: any) => {
    if (!appointment) return;
    
    try {
      const updatedAppointment = {
        ...appointment,
        adminNotes: values.note,
        updatedAt: new Date().toISOString(),
      };
      
      setAppointment(updatedAppointment);
      setAdminNoteModalVisible(false);
      message.success('管理员备注添加成功');
    } catch (error) {
      message.error('添加备注失败');
    }
  };

  const getStatusColor = (status: string) => {
    const colors = {
      pending: 'orange',
      confirmed: 'blue',
      in_progress: 'processing',
      completed: 'green',
      cancelled: 'red',
      no_show: 'red',
    };
    return colors[status as keyof typeof colors] || 'default';
  };

  const getStatusText = (status: string) => {
    const texts = {
      pending: '待确认',
      confirmed: '已确认',
      in_progress: '进行中',
      completed: '已完成',
      cancelled: '已取消',
      no_show: '未出席',
    };
    return texts[status as keyof typeof texts] || status;
  };

  const getPaymentStatusColor = (status: string) => {
    const colors = {
      pending: 'orange',
      paid: 'green',
      refunded: 'purple',
      failed: 'red',
    };
    return colors[status as keyof typeof colors] || 'default';
  };

  const getPaymentStatusText = (status: string) => {
    const texts = {
      pending: '待支付',
      paid: '已支付',
      refunded: '已退款',
      failed: '支付失败',
    };
    return texts[status as keyof typeof texts] || status;
  };

  const getTypeText = (type: string) => {
    const texts = {
      interpretation: '口译服务',
      translation: '笔译服务',
      consultation: '咨询服务',
    };
    return texts[type as keyof typeof texts] || type;
  };

  const getUrgencyText = (urgency: string) => {
    const texts = {
      normal: '普通',
      low: '低',
      high: '高',
      urgent: '加急',
    };
    return texts[urgency as keyof typeof texts] || urgency;
  };

  const calculateDuration = () => {
    if (!appointment) return 0;
    const start = new Date(appointment.startTime);
    const end = new Date(appointment.endTime);
    return Math.round((end.getTime() - start.getTime()) / (1000 * 60)); // 分钟
  };

  if (loading) {
    return (
      <div style={{ textAlign: 'center', padding: '50px' }}>
        <Spin size="large" />
        <div style={{ marginTop: '16px' }}>加载预约详情...</div>
      </div>
    );
  }

  if (!appointment) {
    return (
      <div style={{ textAlign: 'center', padding: '50px' }}>
        <div>预约记录不存在</div>
        <Button type="primary" onClick={() => navigate('/appointments')} style={{ marginTop: '16px' }}>
          返回预约列表
        </Button>
      </div>
    );
  }

  return (
    <div style={{ padding: '24px' }}>
      {/* 头部导航 */}
      <div style={{ marginBottom: '24px', display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
        <div>
          <Button
            icon={<ArrowLeftOutlined />}
            onClick={() => navigate('/appointments')}
            style={{ marginRight: '16px' }}
          >
            返回
          </Button>
          <Title level={2} style={{ display: 'inline-block', margin: 0 }}>
            预约详情 #{appointment.id}
          </Title>
        </div>
        
        {/* 管理员操作按钮 */}
        <Space>
          <Button
            icon={<EditOutlined />}
            onClick={() => setEditModalVisible(true)}
          >
            编辑信息
          </Button>
          <Button
            icon={<SettingOutlined />}
            onClick={() => setStatusModalVisible(true)}
          >
            更改状态
          </Button>
          <Button
            icon={<ClockCircleOutlined />}
            onClick={() => setRescheduleModalVisible(true)}
            disabled={appointment.status === 'completed' || appointment.status === 'cancelled'}
          >
            改期
          </Button>
          <Button
            icon={<TeamOutlined />}
            onClick={() => setReassignModalVisible(true)}
            disabled={appointment.status === 'completed' || appointment.status === 'cancelled'}
          >
            重新分配
          </Button>
          <Button
            icon={<DollarOutlined />}
            onClick={() => setRefundModalVisible(true)}
            disabled={appointment.paymentStatus !== 'paid'}
          >
            处理退款
          </Button>
          <Button
            icon={<MessageOutlined />}
            onClick={() => setAdminNoteModalVisible(true)}
          >
            添加备注
          </Button>
        </Space>
      </div>

      {/* 系统状态提醒 */}
      {appointment.issues && appointment.issues.length > 0 && (
        <Alert
          message="系统检测到问题"
          description={appointment.issues.join(', ')}
          type="warning"
          showIcon
          style={{ marginBottom: '24px' }}
        />
      )}

      {/* 统计概览 */}
      <Row gutter={16} style={{ marginBottom: '24px' }}>
        <Col span={6}>
          <Card>
            <Statistic
              title="预约状态"
              value={getStatusText(appointment.status)}
              valueStyle={{ color: appointment.status === 'completed' ? '#3f8600' : '#1890ff' }}
              prefix={<CheckCircleOutlined />}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="预约时长"
              value={calculateDuration()}
              suffix="分钟"
              valueStyle={{ color: '#1890ff' }}
              prefix={<ClockCircleOutlined />}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="费用金额"
              value={appointment.cost}
              precision={2}
              prefix="¥"
              valueStyle={{ color: '#3f8600' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="质量评分"
              value={appointment.qualityScore || 0}
              suffix="/100"
              valueStyle={{ color: (appointment.qualityScore || 0) >= 90 ? '#3f8600' : '#faad14' }}
              prefix={<AuditOutlined />}
            />
          </Card>
        </Col>
      </Row>

      {/* 基本信息卡片 */}
      <Card title="预约信息" style={{ marginBottom: '24px' }}>
        <Descriptions column={3} bordered>
          <Descriptions.Item label="预约标题" span={2}>
            {appointment.title}
          </Descriptions.Item>
          <Descriptions.Item label="服务类型" span={1}>
            <Tag color="blue">{getTypeText(appointment.type)}</Tag>
          </Descriptions.Item>
          <Descriptions.Item label="状态" span={1}>
            <Tag color={getStatusColor(appointment.status)}>
              {getStatusText(appointment.status)}
            </Tag>
          </Descriptions.Item>
          <Descriptions.Item label="支付状态" span={1}>
            <Tag color={getPaymentStatusColor(appointment.paymentStatus)}>
              {getPaymentStatusText(appointment.paymentStatus)}
            </Tag>
          </Descriptions.Item>
          <Descriptions.Item label="紧急程度" span={1}>
            <Tag color={appointment.urgency === 'urgent' ? 'orange' : appointment.urgency === 'high' ? 'red' : 'default'}>
              {getUrgencyText(appointment.urgency)}
            </Tag>
          </Descriptions.Item>
          <Descriptions.Item label="客户姓名" span={1}>
            <Space>
              <UserOutlined />
              {appointment.clientName}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="客户邮箱" span={1}>
            {appointment.clientEmail}
          </Descriptions.Item>
          <Descriptions.Item label="客户电话" span={1}>
            <Space>
              <PhoneOutlined />
              {appointment.clientPhone}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="译员姓名" span={1}>
            <Space>
              <Avatar size="small" icon={<UserOutlined />} />
              {appointment.translatorName}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="译员邮箱" span={1}>
            {appointment.translatorEmail}
          </Descriptions.Item>
          <Descriptions.Item label="译员电话" span={1}>
            <Space>
              <PhoneOutlined />
              {appointment.translatorPhone}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="源语言" span={1}>
            <Space>
              <GlobalOutlined />
              {appointment.sourceLanguage}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="目标语言" span={1}>
            <Space>
              <GlobalOutlined />
              {appointment.targetLanguage}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="会议地点" span={1}>
            <Space>
              <EnvironmentOutlined />
              {appointment.location || '线上会议'}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="开始时间" span={1}>
            <Space>
              <CalendarOutlined />
              {moment(appointment.startTime).format('YYYY-MM-DD HH:mm')}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="结束时间" span={1}>
            <Space>
              <CalendarOutlined />
              {moment(appointment.endTime).format('YYYY-MM-DD HH:mm')}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="预约时长" span={1}>
            <Space>
              <ClockCircleOutlined />
              {calculateDuration()} 分钟
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="费用" span={1}>
            <Space>
              <DollarOutlined />
              <Text strong>¥{appointment.cost.toFixed(2)}</Text>
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="退款金额" span={1}>
            <Space>
              <DollarOutlined />
              <Text type={(appointment.refundAmount || 0) > 0 ? 'danger' : 'secondary'}>
                ¥{(appointment.refundAmount || 0).toFixed(2)}
              </Text>
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="提醒状态" span={1}>
            <Tag color={appointment.reminderSent ? 'green' : 'orange'}>
              {appointment.reminderSent ? '已发送' : '未发送'}
            </Tag>
          </Descriptions.Item>
          <Descriptions.Item label="创建时间" span={1}>
            <Space>
              <CalendarOutlined />
              {moment(appointment.createdAt).format('YYYY-MM-DD HH:mm')}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="更新时间" span={1}>
            <Space>
              <CalendarOutlined />
              {appointment.updatedAt ? moment(appointment.updatedAt).format('YYYY-MM-DD HH:mm') : '-'}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="会议链接" span={1}>
            {appointment.meetingUrl ? (
              <a href={appointment.meetingUrl} target="_blank" rel="noopener noreferrer">
                <VideoCameraOutlined /> 加入会议
              </a>
            ) : (
              '-'
            )}
          </Descriptions.Item>
        </Descriptions>
        
        {appointment.description && (
          <div style={{ marginTop: '16px' }}>
            <Text strong>预约描述：</Text>
            <Paragraph style={{ marginTop: '8px' }}>
              {appointment.description}
            </Paragraph>
          </div>
        )}
        
        {appointment.notes && (
          <div style={{ marginTop: '16px' }}>
            <Text strong>客户备注：</Text>
            <Paragraph style={{ marginTop: '8px', background: '#f0f8ff', padding: '12px', borderRadius: '6px' }}>
              {appointment.notes}
            </Paragraph>
          </div>
        )}
        
        {appointment.adminNotes && (
          <div style={{ marginTop: '16px' }}>
            <Text strong>管理员备注：</Text>
            <Paragraph style={{ marginTop: '8px', background: '#f6f6f6', padding: '12px', borderRadius: '6px' }}>
              {appointment.adminNotes}
            </Paragraph>
          </div>
        )}
      </Card>

      {/* 详细内容标签页 */}
      <Card>
        <Tabs defaultActiveKey="timeline">
          <TabPane
            tab={
              <Space>
                <ClockCircleOutlined />
                时间线
              </Space>
            }
            key="timeline"
          >
            <div style={{ padding: '20px' }}>
              <Timeline>
                <Timeline.Item color="green">
                  <div>
                    <Text strong>预约创建</Text>
                    <div style={{ color: '#999', fontSize: '12px' }}>
                      {moment(appointment.createdAt).format('YYYY-MM-DD HH:mm')}
                    </div>
                  </div>
                </Timeline.Item>
                <Timeline.Item color="blue">
                  <div>
                    <Text strong>分配译员</Text>
                    <div style={{ color: '#999', fontSize: '12px' }}>
                      译员：{appointment.translatorName}
                    </div>
                  </div>
                </Timeline.Item>
                {appointment.status === 'confirmed' && (
                  <Timeline.Item color="blue">
                    <div>
                      <Text strong>预约确认</Text>
                      <div style={{ color: '#999', fontSize: '12px' }}>
                        预约已确认，等待服务开始
                      </div>
                    </div>
                  </Timeline.Item>
                )}
                {appointment.status === 'in_progress' && (
                  <Timeline.Item color="processing">
                    <div>
                      <Text strong>服务进行中</Text>
                      <div style={{ color: '#999', fontSize: '12px' }}>
                        {moment(appointment.startTime).format('YYYY-MM-DD HH:mm')}
                      </div>
                    </div>
                  </Timeline.Item>
                )}
                {appointment.status === 'completed' && (
                  <Timeline.Item color="green">
                    <div>
                      <Text strong>服务完成</Text>
                      <div style={{ color: '#999', fontSize: '12px' }}>
                        {moment(appointment.endTime).format('YYYY-MM-DD HH:mm')}
                      </div>
                    </div>
                  </Timeline.Item>
                )}
                {appointment.status === 'cancelled' && (
                  <Timeline.Item color="red">
                    <div>
                      <Text strong>预约取消</Text>
                      <div style={{ color: '#999', fontSize: '12px' }}>
                        预约已取消
                      </div>
                    </div>
                  </Timeline.Item>
                )}
              </Timeline>
            </div>
          </TabPane>
          
          <TabPane
            tab={
              <Space>
                <StarOutlined />
                用户评价
              </Space>
            }
            key="rating"
          >
            <div style={{ padding: '20px' }}>
              {appointment.rating ? (
                <>
                  <div style={{ marginBottom: '20px' }}>
                    <Text strong>服务评分：</Text>
                    <Rate disabled value={appointment.rating} style={{ marginLeft: '8px' }} />
                    <Text style={{ marginLeft: '8px' }}>
                      ({appointment.rating}/5 分)
                    </Text>
                  </div>
                  
                  {appointment.feedback && (
                    <div>
                      <Text strong>用户反馈：</Text>
                      <Paragraph style={{ marginTop: '8px' }}>
                        {appointment.feedback}
                      </Paragraph>
                    </div>
                  )}
                </>
              ) : (
                <div style={{ textAlign: 'center', color: '#999', padding: '50px' }}>
                  暂无用户评价
                </div>
              )}
            </div>
          </TabPane>
          
          <TabPane
            tab={
              <Space>
                <AuditOutlined />
                质量分析
              </Space>
            }
            key="quality"
          >
            <div style={{ padding: '20px' }}>
              <Descriptions column={2}>
                <Descriptions.Item label="质量评分">
                  <div style={{ textAlign: 'center' }}>
                    <div style={{ fontSize: '24px', fontWeight: 'bold', color: (appointment.qualityScore || 0) >= 90 ? '#52c41a' : (appointment.qualityScore || 0) >= 70 ? '#faad14' : '#ff4d4f' }}>
                      {appointment.qualityScore || 0}/100
                    </div>
                    <div style={{ color: '#999', fontSize: '12px' }}>系统评分</div>
                  </div>
                </Descriptions.Item>
                <Descriptions.Item label="系统检测">
                  {appointment.issues && appointment.issues.length > 0 ? (
                    <div>
                      {appointment.issues.map((issue, index) => (
                        <Tag key={index} color="red" style={{ marginBottom: '4px' }}>
                          {issue}
                        </Tag>
                      ))}
                    </div>
                  ) : (
                    <Tag color="green">无异常</Tag>
                  )}
                </Descriptions.Item>
                <Descriptions.Item label="服务满意度">
                  {appointment.rating ? (
                    <Rate disabled value={appointment.rating} />
                  ) : (
                    <Text type="secondary">暂无评价</Text>
                  )}
                </Descriptions.Item>
                <Descriptions.Item label="准时性">
                  <Tag color="green">准时</Tag>
                </Descriptions.Item>
              </Descriptions>
            </div>
          </TabPane>
        </Tabs>
      </Card>

      {/* 编辑信息弹窗 */}
      <Modal
        title="编辑预约信息"
        visible={editModalVisible}
        onCancel={() => setEditModalVisible(false)}
        footer={null}
        width={600}
      >
        <Form
          form={form}
          layout="vertical"
          onFinish={handleEdit}
        >
          <Form.Item
            name="title"
            label="预约标题"
            rules={[{ required: true, message: '请输入预约标题' }]}
          >
            <Input />
          </Form.Item>
          
          <Form.Item
            name="description"
            label="预约描述"
          >
            <TextArea rows={3} />
          </Form.Item>
          
          <Form.Item
            name="type"
            label="服务类型"
            rules={[{ required: true, message: '请选择服务类型' }]}
          >
            <Select>
              <Option value="interpretation">口译服务</Option>
              <Option value="translation">笔译服务</Option>
              <Option value="consultation">咨询服务</Option>
            </Select>
          </Form.Item>
          
          <Form.Item
            name="urgency"
            label="紧急程度"
            rules={[{ required: true, message: '请选择紧急程度' }]}
          >
            <Select>
              <Option value="normal">普通</Option>
              <Option value="low">低</Option>
              <Option value="high">高</Option>
              <Option value="urgent">加急</Option>
            </Select>
          </Form.Item>
          
          <Form.Item
            name="cost"
            label="费用"
            rules={[{ required: true, message: '请输入费用' }]}
          >
            <Input type="number" addonAfter="元" />
          </Form.Item>
          
          <Form.Item
            name="location"
            label="会议地点"
          >
            <Input placeholder="如为线上会议可不填" />
          </Form.Item>
          
          <Form.Item style={{ marginBottom: 0, textAlign: 'right' }}>
            <Space>
              <Button onClick={() => setEditModalVisible(false)}>
                取消
              </Button>
              <Button type="primary" htmlType="submit">
                保存
              </Button>
            </Space>
          </Form.Item>
        </Form>
      </Modal>

      {/* 更改状态弹窗 */}
      <Modal
        title="更改预约状态"
        visible={statusModalVisible}
        onCancel={() => setStatusModalVisible(false)}
        footer={null}
      >
        <Form
          form={statusForm}
          layout="vertical"
          onFinish={handleStatusChange}
        >
          <Form.Item
            name="status"
            label="新状态"
            rules={[{ required: true, message: '请选择状态' }]}
          >
            <Select>
              <Option value="pending">待确认</Option>
              <Option value="confirmed">已确认</Option>
              <Option value="in_progress">进行中</Option>
              <Option value="completed">已完成</Option>
              <Option value="cancelled">已取消</Option>
              <Option value="no_show">未出席</Option>
            </Select>
          </Form.Item>
          
          <Form.Item style={{ marginBottom: 0, textAlign: 'right' }}>
            <Space>
              <Button onClick={() => setStatusModalVisible(false)}>
                取消
              </Button>
              <Button type="primary" htmlType="submit">
                更新状态
              </Button>
            </Space>
          </Form.Item>
        </Form>
      </Modal>

      {/* 改期弹窗 */}
      <Modal
        title="预约改期"
        visible={rescheduleModalVisible}
        onCancel={() => setRescheduleModalVisible(false)}
        footer={null}
      >
        <Form
          form={rescheduleForm}
          layout="vertical"
          onFinish={handleReschedule}
        >
          <Form.Item
            name="timeRange"
            label="新的时间"
            rules={[{ required: true, message: '请选择新的时间' }]}
          >
            <RangePicker
              showTime
              format="YYYY-MM-DD HH:mm"
              style={{ width: '100%' }}
            />
          </Form.Item>
          
          <Form.Item
            name="reason"
            label="改期原因"
            rules={[{ required: true, message: '请输入改期原因' }]}
          >
            <TextArea rows={3} placeholder="请输入改期原因..." />
          </Form.Item>
          
          <Form.Item style={{ marginBottom: 0, textAlign: 'right' }}>
            <Space>
              <Button onClick={() => setRescheduleModalVisible(false)}>
                取消
              </Button>
              <Button type="primary" htmlType="submit">
                确认改期
              </Button>
            </Space>
          </Form.Item>
        </Form>
      </Modal>

      {/* 重新分配译员弹窗 */}
      <Modal
        title="重新分配译员"
        visible={reassignModalVisible}
        onCancel={() => setReassignModalVisible(false)}
        footer={null}
      >
        <Form
          form={reassignForm}
          layout="vertical"
          onFinish={handleReassign}
        >
          <Form.Item
            name="translatorId"
            label="选择译员"
            rules={[{ required: true, message: '请选择译员' }]}
          >
            <Select>
              <Option value="translator_1">李翻译 - 商务专家</Option>
              <Option value="translator_2">王译员 - 技术专家</Option>
              <Option value="translator_3">张翻译 - 法律专家</Option>
            </Select>
          </Form.Item>
          
          <Form.Item
            name="translatorName"
            label="译员姓名"
            rules={[{ required: true, message: '请输入译员姓名' }]}
          >
            <Input />
          </Form.Item>
          
          <Form.Item
            name="translatorEmail"
            label="译员邮箱"
            rules={[{ required: true, message: '请输入译员邮箱' }]}
          >
            <Input />
          </Form.Item>
          
          <Form.Item
            name="translatorPhone"
            label="译员电话"
            rules={[{ required: true, message: '请输入译员电话' }]}
          >
            <Input />
          </Form.Item>
          
          <Form.Item
            name="reason"
            label="重新分配原因"
            rules={[{ required: true, message: '请输入原因' }]}
          >
            <TextArea rows={3} placeholder="请输入重新分配原因..." />
          </Form.Item>
          
          <Form.Item style={{ marginBottom: 0, textAlign: 'right' }}>
            <Space>
              <Button onClick={() => setReassignModalVisible(false)}>
                取消
              </Button>
              <Button type="primary" htmlType="submit">
                确认分配
              </Button>
            </Space>
          </Form.Item>
        </Form>
      </Modal>

      {/* 退款处理弹窗 */}
      <Modal
        title="处理退款"
        visible={refundModalVisible}
        onCancel={() => setRefundModalVisible(false)}
        footer={null}
      >
        <Form
          form={refundForm}
          layout="vertical"
          onFinish={handleRefund}
          initialValues={{ amount: appointment.cost }}
        >
          <Alert
            message="退款提醒"
            description={`原支付金额：¥${appointment.cost.toFixed(2)}`}
            type="info"
            style={{ marginBottom: '16px' }}
          />
          
          <Form.Item
            name="amount"
            label="退款金额"
            rules={[
              { required: true, message: '请输入退款金额' },
              { type: 'number', min: 0, max: appointment.cost, message: `退款金额不能超过¥${appointment.cost.toFixed(2)}` }
            ]}
          >
            <Input type="number" addonAfter="元" />
          </Form.Item>
          
          <Form.Item
            name="reason"
            label="退款原因"
            rules={[{ required: true, message: '请输入退款原因' }]}
          >
            <TextArea rows={3} placeholder="请输入退款原因..." />
          </Form.Item>
          
          <Form.Item style={{ marginBottom: 0, textAlign: 'right' }}>
            <Space>
              <Button onClick={() => setRefundModalVisible(false)}>
                取消
              </Button>
              <Button type="primary" danger htmlType="submit">
                确认退款
              </Button>
            </Space>
          </Form.Item>
        </Form>
      </Modal>

      {/* 添加管理员备注弹窗 */}
      <Modal
        title="添加管理员备注"
        visible={adminNoteModalVisible}
        onCancel={() => setAdminNoteModalVisible(false)}
        footer={null}
      >
        <Form
          form={noteForm}
          layout="vertical"
          onFinish={handleAddAdminNote}
          initialValues={{ note: appointment.adminNotes }}
        >
          <Form.Item
            name="note"
            label="备注内容"
            rules={[{ required: true, message: '请输入备注内容' }]}
          >
            <TextArea rows={4} placeholder="请输入管理员备注..." />
          </Form.Item>
          
          <Form.Item style={{ marginBottom: 0, textAlign: 'right' }}>
            <Space>
              <Button onClick={() => setAdminNoteModalVisible(false)}>
                取消
              </Button>
              <Button type="primary" htmlType="submit">
                保存备注
              </Button>
            </Space>
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default AppointmentDetail; 