import React, { useState, useEffect } from 'react';
import {
  Table,
  Button,
  Modal,
  Form,
  Input,
  Select,
  Switch,
  InputNumber,
  Space,
  Popconfirm,
  message,
  Card,
  Row,
  Col,
  Statistic,
} from 'antd';
import { PlusOutlined, EditOutlined, DeleteOutlined } from '@ant-design/icons';
import { BillingRule, CallType, TranslationType, UserType } from '../../types/billing';
import billingService from '../../services/billingService';

const { Option } = Select;

const BillingRules: React.FC = () => {
  const [rules, setRules] = useState<BillingRule[]>([]);
  const [loading, setLoading] = useState(false);
  const [modalVisible, setModalVisible] = useState(false);
  const [editingRule, setEditingRule] = useState<BillingRule | null>(null);
  const [form] = Form.useForm();

  useEffect(() => {
    fetchRules();
  }, []);

  const fetchRules = async () => {
    setLoading(true);
    try {
      const rulesData = await billingService.getBillingRules();
      setRules(rulesData);
    } catch (error) {
      message.error('获取计费规则失败');
    } finally {
      setLoading(false);
    }
  };

  const handleAdd = () => {
    setEditingRule(null);
    form.resetFields();
    setModalVisible(true);
  };

  const handleEdit = (rule: BillingRule) => {
    setEditingRule(rule);
    form.setFieldsValue(rule);
    setModalVisible(true);
  };

  const handleDelete = async (id: string) => {
    try {
      await billingService.deleteBillingRule(id);
      message.success('删除成功');
      fetchRules();
    } catch (error) {
      message.error('删除失败');
    }
  };

  const handleSubmit = async (values: any) => {
    try {
      if (editingRule) {
        await billingService.updateBillingRule(editingRule.id, values);
        message.success('更新成功');
      } else {
        await billingService.createBillingRule(values);
        message.success('创建成功');
      }
      setModalVisible(false);
      fetchRules();
    } catch (error) {
      message.error(editingRule ? '更新失败' : '创建失败');
    }
  };

  const columns = [
    {
      title: '规则名称',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '通话类型',
      dataIndex: 'callType',
      key: 'callType',
      render: (type: CallType) => {
        const typeMap = {
          [CallType.VOICE]: '语音通话',
          [CallType.VIDEO]: '视频通话',
        };
        return typeMap[type];
      },
    },
    {
      title: '翻译类型',
      dataIndex: 'translationType',
      key: 'translationType',
      render: (type: TranslationType) => {
        const typeMap = {
          [TranslationType.TEXT]: '文字翻译',
          [TranslationType.SIGN_LANGUAGE]: '手语翻译',
          [TranslationType.HUMAN_INTERPRETER]: '真人翻译',
        };
        return typeMap[type];
      },
    },
    {
      title: '用户类型',
      dataIndex: 'userType',
      key: 'userType',
      render: (type: UserType) => {
        const typeMap = {
          [UserType.INDIVIDUAL]: '普通用户',
          [UserType.ENTERPRISE]: '企业用户',
        };
        return typeMap[type];
      },
    },
    {
      title: '每分钟价格',
      dataIndex: 'pricePerMinute',
      key: 'pricePerMinute',
      render: (price: number) => `¥${(price / 100).toFixed(2)}`,
    },
    {
      title: '最低收费',
      dataIndex: 'minimumCharge',
      key: 'minimumCharge',
      render: (charge: number) => `¥${(charge / 100).toFixed(2)}`,
    },
    {
      title: '状态',
      dataIndex: 'isActive',
      key: 'isActive',
      render: (isActive: boolean) => (
        <span style={{ color: isActive ? '#52c41a' : '#ff4d4f' }}>
          {isActive ? '启用' : '禁用'}
        </span>
      ),
    },
    {
      title: '操作',
      key: 'action',
      render: (_: any, record: BillingRule) => (
        <Space size="middle">
          <Button
            type="link"
            icon={<EditOutlined />}
            onClick={() => handleEdit(record)}
          >
            编辑
          </Button>
          <Popconfirm
            title="确定要删除这个计费规则吗？"
            onConfirm={() => handleDelete(record.id)}
            okText="确定"
            cancelText="取消"
          >
            <Button type="link" danger icon={<DeleteOutlined />}>
              删除
            </Button>
          </Popconfirm>
        </Space>
      ),
    },
  ];

  const activeRules = rules.filter(rule => rule.isActive);
  const inactiveRules = rules.filter(rule => !rule.isActive);

  return (
    <div>
      <Row gutter={16} style={{ marginBottom: 16 }}>
        <Col span={8}>
          <Card>
            <Statistic title="总计费规则" value={rules.length} />
          </Card>
        </Col>
        <Col span={8}>
          <Card>
            <Statistic title="启用规则" value={activeRules.length} />
          </Card>
        </Col>
        <Col span={8}>
          <Card>
            <Statistic title="禁用规则" value={inactiveRules.length} />
          </Card>
        </Col>
      </Row>

      <Card
        title="计费规则管理"
        extra={
          <Button type="primary" icon={<PlusOutlined />} onClick={handleAdd}>
            新增规则
          </Button>
        }
      >
        <Table
          columns={columns}
          dataSource={rules}
          rowKey="id"
          loading={loading}
          pagination={{
            pageSize: 10,
            showSizeChanger: true,
            showQuickJumper: true,
            showTotal: (total) => `共 ${total} 条记录`,
          }}
        />
      </Card>

      <Modal
        title={editingRule ? '编辑计费规则' : '新增计费规则'}
        open={modalVisible}
        onCancel={() => setModalVisible(false)}
        footer={null}
        width={600}
      >
        <Form
          form={form}
          layout="vertical"
          onFinish={handleSubmit}
        >
          <Form.Item
            name="name"
            label="规则名称"
            rules={[{ required: true, message: '请输入规则名称' }]}
          >
            <Input placeholder="请输入规则名称" />
          </Form.Item>

          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                name="callType"
                label="通话类型"
                rules={[{ required: true, message: '请选择通话类型' }]}
              >
                <Select placeholder="请选择通话类型">
                  <Option value={CallType.VOICE}>语音通话</Option>
                  <Option value={CallType.VIDEO}>视频通话</Option>
                </Select>
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                name="translationType"
                label="翻译类型"
                rules={[{ required: true, message: '请选择翻译类型' }]}
              >
                <Select placeholder="请选择翻译类型">
                  <Option value={TranslationType.TEXT}>文字翻译</Option>
                  <Option value={TranslationType.SIGN_LANGUAGE}>手语翻译</Option>
                  <Option value={TranslationType.HUMAN_INTERPRETER}>真人翻译</Option>
                </Select>
              </Form.Item>
            </Col>
          </Row>

          <Form.Item
            name="userType"
            label="用户类型"
            rules={[{ required: true, message: '请选择用户类型' }]}
          >
            <Select placeholder="请选择用户类型">
              <Option value={UserType.INDIVIDUAL}>普通用户</Option>
              <Option value={UserType.ENTERPRISE}>企业用户</Option>
            </Select>
          </Form.Item>

          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                name="pricePerMinute"
                label="每分钟价格（分）"
                rules={[{ required: true, message: '请输入每分钟价格' }]}
              >
                <InputNumber
                  min={1}
                  placeholder="请输入价格（分）"
                  style={{ width: '100%' }}
                  addonAfter="分"
                />
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                name="minimumCharge"
                label="最低收费（分）"
                rules={[{ required: true, message: '请输入最低收费' }]}
              >
                <InputNumber
                  min={1}
                  placeholder="请输入最低收费（分）"
                  style={{ width: '100%' }}
                  addonAfter="分"
                />
              </Form.Item>
            </Col>
          </Row>

          <Form.Item
            name="isActive"
            label="状态"
            valuePropName="checked"
            initialValue={true}
          >
            <Switch checkedChildren="启用" unCheckedChildren="禁用" />
          </Form.Item>

          <Form.Item>
            <Space>
              <Button type="primary" htmlType="submit">
                {editingRule ? '更新' : '创建'}
              </Button>
              <Button onClick={() => setModalVisible(false)}>
                取消
              </Button>
            </Space>
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default BillingRules; 