import React, { useState, useEffect } from 'react';
import {
  Card,
  Row,
  Col,
  Statistic,
  Table,
  DatePicker,
  Select,
  Space,
  Button,
} from 'antd';
import {
  LineChart,
  Line,
  AreaChart,
  Area,
  BarChart,
  Bar,
  PieChart,
  Pie,
  Cell,
  XAxis,
  YAxis,
  CartesianGrid,
  Tooltip,
  Legend,
  ResponsiveContainer,
} from 'recharts';
import { BillingStats as BillingStatsType } from '../../types/billing';
import billingService from '../../services/billingService';

const { RangePicker } = DatePicker;
const { Option } = Select;

const BillingStats: React.FC = () => {
  const [stats, setStats] = useState<BillingStatsType | null>(null);
  const [loading, setLoading] = useState(false);
  const [dateRange, setDateRange] = useState<[any, any] | null>(null);

  useEffect(() => {
    fetchStats();
  }, [dateRange]);

  const fetchStats = async () => {
    setLoading(true);
    try {
      const startDate = dateRange?.[0]?.toDate();
      const endDate = dateRange?.[1]?.toDate();
      const statsData = await billingService.getBillingStats(startDate, endDate);
      setStats(statsData);
    } catch (error) {
      console.error('获取统计数据失败:', error);
    } finally {
      setLoading(false);
    }
  };

  if (!stats) {
    return <div>加载中...</div>;
  }

  // 饼图颜色配置
  const COLORS = ['#0088FE', '#00C49F', '#FFBB28', '#FF8042', '#8884D8'];

  // 服务统计表格列
  const serviceColumns = [
    {
      title: '服务类型',
      dataIndex: 'type',
      key: 'type',
    },
    {
      title: '使用次数',
      dataIndex: 'count',
      key: 'count',
    },
    {
      title: '收入金额',
      dataIndex: 'revenue',
      key: 'revenue',
      render: (revenue: number) => `¥${(revenue / 100).toFixed(2)}`,
    },
    {
      title: '平均单价',
      key: 'avgPrice',
      render: (_: any, record: any) => 
        `¥${((record.revenue / record.count) / 100).toFixed(2)}`,
    },
  ];

  return (
    <div>
      {/* 筛选条件 */}
      <Card style={{ marginBottom: 16 }}>
        <Space>
          <span>时间范围：</span>
          <RangePicker
            value={dateRange}
            onChange={setDateRange}
            placeholder={['开始日期', '结束日期']}
          />
          <Button type="primary" onClick={fetchStats} loading={loading}>
            查询
          </Button>
        </Space>
      </Card>

      {/* 核心指标 */}
      <Row gutter={16} style={{ marginBottom: 16 }}>
        <Col span={6}>
          <Card>
            <Statistic
              title="总收入"
              value={stats.totalRevenue / 100}
              precision={2}
              prefix="¥"
              valueStyle={{ color: '#3f8600' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="总用户数"
              value={stats.totalUsers}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="活跃用户数"
              value={stats.activeUsers}
              valueStyle={{ color: '#722ed1' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="用户活跃率"
              value={(stats.activeUsers / stats.totalUsers * 100)}
              precision={1}
              suffix="%"
              valueStyle={{ color: '#13c2c2' }}
            />
          </Card>
        </Col>
      </Row>

      <Row gutter={16} style={{ marginBottom: 16 }}>
        <Col span={6}>
          <Card>
            <Statistic
              title="总通话数"
              value={stats.totalCalls}
              valueStyle={{ color: '#52c41a' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="总预约数"
              value={stats.totalAppointments}
              valueStyle={{ color: '#fa8c16' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="平均通话时长"
              value={stats.averageCallDuration}
              suffix="分钟"
              valueStyle={{ color: '#eb2f96' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="平均通话费用"
              value={stats.averageCallCost / 100}
              precision={2}
              prefix="¥"
              valueStyle={{ color: '#f5222d' }}
            />
          </Card>
        </Col>
      </Row>

      {/* 图表区域 */}
      <Row gutter={16} style={{ marginBottom: 16 }}>
        {/* 收入趋势图 */}
        <Col span={16}>
          <Card title="收入趋势">
            <ResponsiveContainer width="100%" height={300}>
              <AreaChart data={stats.revenueByDate}>
                <CartesianGrid strokeDasharray="3 3" />
                <XAxis dataKey="date" />
                <YAxis tickFormatter={(value) => `¥${(value / 100).toFixed(0)}`} />
                <Tooltip 
                  formatter={(value: any) => [`¥${(value / 100).toFixed(2)}`, '收入']}
                />
                <Area 
                  type="monotone" 
                  dataKey="revenue" 
                  stroke="#1890ff" 
                  fill="#1890ff" 
                  fillOpacity={0.3}
                />
              </AreaChart>
            </ResponsiveContainer>
          </Card>
        </Col>

        {/* 服务类型分布 */}
        <Col span={8}>
          <Card title="服务类型分布">
            <ResponsiveContainer width="100%" height={300}>
              <PieChart>
                <Pie
                  data={stats.topServices}
                  cx="50%"
                  cy="50%"
                  labelLine={false}
                  label={({ type, percent }) => `${type} ${(percent * 100).toFixed(0)}%`}
                  outerRadius={80}
                  fill="#8884d8"
                  dataKey="count"
                >
                  {stats.topServices.map((entry, index) => (
                    <Cell key={`cell-${index}`} fill={COLORS[index % COLORS.length]} />
                  ))}
                </Pie>
                <Tooltip />
              </PieChart>
            </ResponsiveContainer>
          </Card>
        </Col>
      </Row>

      <Row gutter={16}>
        {/* 服务收入对比 */}
        <Col span={12}>
          <Card title="服务收入对比">
            <ResponsiveContainer width="100%" height={300}>
              <BarChart data={stats.topServices}>
                <CartesianGrid strokeDasharray="3 3" />
                <XAxis dataKey="type" />
                <YAxis tickFormatter={(value) => `¥${(value / 100).toFixed(0)}`} />
                <Tooltip 
                  formatter={(value: any) => [`¥${(value / 100).toFixed(2)}`, '收入']}
                />
                <Bar dataKey="revenue" fill="#52c41a" />
              </BarChart>
            </ResponsiveContainer>
          </Card>
        </Col>

        {/* 服务使用次数对比 */}
        <Col span={12}>
          <Card title="服务使用次数对比">
            <ResponsiveContainer width="100%" height={300}>
              <BarChart data={stats.topServices}>
                <CartesianGrid strokeDasharray="3 3" />
                <XAxis dataKey="type" />
                <YAxis />
                <Tooltip formatter={(value: any) => [value, '次数']} />
                <Bar dataKey="count" fill="#1890ff" />
              </BarChart>
            </ResponsiveContainer>
          </Card>
        </Col>
      </Row>

      {/* 详细数据表格 */}
      <Card title="服务详细统计" style={{ marginTop: 16 }}>
        <Table
          columns={serviceColumns}
          dataSource={stats.topServices}
          rowKey="type"
          pagination={false}
        />
      </Card>
    </div>
  );
};

export default BillingStats; 