import React, { useState, useEffect } from 'react';
import {
  Table,
  Button,
  Modal,
  Form,
  Input,
  InputNumber,
  Space,
  message,
  Card,
  Row,
  Col,
  Statistic,
  Tag,
  Tabs,
} from 'antd';
import { WalletOutlined, PlusOutlined, MinusOutlined, StopOutlined } from '@ant-design/icons';
import { UserAccount, UserType, RechargeRecord, ConsumptionRecord } from '../../types/billing';
import billingService from '../../services/billingService';

const { TabPane } = Tabs;

const UserAccounts: React.FC = () => {
  const [accounts, setAccounts] = useState<UserAccount[]>([]);
  const [rechargeRecords, setRechargeRecords] = useState<RechargeRecord[]>([]);
  const [consumptionRecords, setConsumptionRecords] = useState<ConsumptionRecord[]>([]);
  const [loading, setLoading] = useState(false);
  const [modalVisible, setModalVisible] = useState(false);
  const [modalType, setModalType] = useState<'recharge' | 'deduct' | 'freeze' | 'unfreeze'>('recharge');
  const [selectedAccount, setSelectedAccount] = useState<UserAccount | null>(null);
  const [form] = Form.useForm();

  useEffect(() => {
    fetchAccounts();
    fetchRechargeRecords();
    fetchConsumptionRecords();
  }, []);

  const fetchAccounts = async () => {
    setLoading(true);
    try {
      const { accounts: accountsData } = await billingService.getUserAccounts();
      setAccounts(accountsData);
    } catch (error) {
      message.error('获取用户账户失败');
    } finally {
      setLoading(false);
    }
  };

  const fetchRechargeRecords = async () => {
    try {
      const { records } = await billingService.getRechargeRecords();
      setRechargeRecords(records);
    } catch (error) {
      message.error('获取充值记录失败');
    }
  };

  const fetchConsumptionRecords = async () => {
    try {
      const { records } = await billingService.getConsumptionRecords();
      setConsumptionRecords(records);
    } catch (error) {
      message.error('获取消费记录失败');
    }
  };

  const handleBalanceOperation = (account: UserAccount, type: 'recharge' | 'deduct' | 'freeze' | 'unfreeze') => {
    setSelectedAccount(account);
    setModalType(type);
    form.resetFields();
    setModalVisible(true);
  };

  const handleSubmit = async (values: any) => {
    if (!selectedAccount) return;

    try {
      const { amount, reason } = values;
      
      switch (modalType) {
        case 'recharge':
          await billingService.updateUserBalance(selectedAccount.userId, amount, reason || '管理员充值');
          message.success('充值成功');
          break;
        case 'deduct':
          await billingService.updateUserBalance(selectedAccount.userId, -amount, reason || '管理员扣费');
          message.success('扣费成功');
          break;
        case 'freeze':
          await billingService.freezeUserBalance(selectedAccount.userId, amount);
          message.success('冻结成功');
          break;
        case 'unfreeze':
          await billingService.unfreezeUserBalance(selectedAccount.userId, amount);
          message.success('解冻成功');
          break;
      }
      
      setModalVisible(false);
      fetchAccounts();
    } catch (error: any) {
      message.error(error.message || '操作失败');
    }
  };

  const accountColumns = [
    {
      title: '用户ID',
      dataIndex: 'userId',
      key: 'userId',
    },
    {
      title: '用户类型',
      dataIndex: 'userType',
      key: 'userType',
      render: (type: UserType) => {
        const typeMap = {
          [UserType.INDIVIDUAL]: { text: '普通用户', color: 'blue' },
          [UserType.ENTERPRISE]: { text: '企业用户', color: 'gold' },
        };
        const config = typeMap[type];
        return <Tag color={config.color}>{config.text}</Tag>;
      },
    },
    {
      title: '账户余额',
      dataIndex: 'balance',
      key: 'balance',
      render: (balance: number) => (
        <span style={{ color: balance > 0 ? '#52c41a' : '#ff4d4f' }}>
          ¥{(balance / 100).toFixed(2)}
        </span>
      ),
    },
    {
      title: '冻结余额',
      dataIndex: 'frozenBalance',
      key: 'frozenBalance',
      render: (balance: number) => `¥${(balance / 100).toFixed(2)}`,
    },
    {
      title: '累计充值',
      dataIndex: 'totalRecharge',
      key: 'totalRecharge',
      render: (amount: number) => `¥${(amount / 100).toFixed(2)}`,
    },
    {
      title: '累计消费',
      dataIndex: 'totalConsumption',
      key: 'totalConsumption',
      render: (amount: number) => `¥${(amount / 100).toFixed(2)}`,
    },
    {
      title: '操作',
      key: 'action',
      render: (_: any, record: UserAccount) => (
        <Space size="small">
          <Button
            type="link"
            icon={<PlusOutlined />}
            onClick={() => handleBalanceOperation(record, 'recharge')}
          >
            充值
          </Button>
          <Button
            type="link"
            danger
            icon={<MinusOutlined />}
            onClick={() => handleBalanceOperation(record, 'deduct')}
          >
            扣费
          </Button>
          <Button
            type="link"
            icon={<StopOutlined />}
            onClick={() => handleBalanceOperation(record, 'freeze')}
          >
            冻结
          </Button>
        </Space>
      ),
    },
  ];

  const totalBalance = accounts.reduce((sum, account) => sum + account.balance, 0);
  const totalFrozenBalance = accounts.reduce((sum, account) => sum + account.frozenBalance, 0);

  const getModalTitle = () => {
    const titles = {
      recharge: '用户充值',
      deduct: '用户扣费',
      freeze: '冻结余额',
      unfreeze: '解冻余额',
    };
    return titles[modalType];
  };

  return (
    <div>
      <Row gutter={16} style={{ marginBottom: 16 }}>
        <Col span={8}>
          <Card>
            <Statistic 
              title="总账户余额" 
              value={totalBalance / 100} 
              precision={2}
              prefix="¥"
            />
          </Card>
        </Col>
        <Col span={8}>
          <Card>
            <Statistic 
              title="总冻结余额" 
              value={totalFrozenBalance / 100} 
              precision={2}
              prefix="¥"
            />
          </Card>
        </Col>
        <Col span={8}>
          <Card>
            <Statistic 
              title="用户数量" 
              value={accounts.length}
            />
          </Card>
        </Col>
      </Row>

      <Card>
        <Tabs defaultActiveKey="accounts">
          <TabPane tab="用户账户" key="accounts">
            <Table
              columns={accountColumns}
              dataSource={accounts}
              rowKey="id"
              loading={loading}
              pagination={{
                pageSize: 10,
                showSizeChanger: true,
                showQuickJumper: true,
                showTotal: (total) => `共 ${total} 条记录`,
              }}
            />
          </TabPane>
        </Tabs>
      </Card>

      <Modal
        title={getModalTitle()}
        open={modalVisible}
        onCancel={() => setModalVisible(false)}
        footer={null}
        width={500}
      >
        <Form
          form={form}
          layout="vertical"
          onFinish={handleSubmit}
        >
          <Form.Item label="用户ID">
            <Input value={selectedAccount?.userId} disabled />
          </Form.Item>

          <Form.Item label="当前余额">
            <Input 
              value={`¥${((selectedAccount?.balance || 0) / 100).toFixed(2)}`} 
              disabled 
            />
          </Form.Item>

          <Form.Item
            name="amount"
            label="金额（分）"
            rules={[{ required: true, message: '请输入金额' }]}
          >
            <InputNumber
              min={1}
              placeholder="请输入金额（分）"
              style={{ width: '100%' }}
              addonAfter="分"
            />
          </Form.Item>

          {(modalType === 'recharge' || modalType === 'deduct') && (
            <Form.Item
              name="reason"
              label="操作原因"
              rules={[{ required: true, message: '请输入操作原因' }]}
            >
              <Input.TextArea 
                placeholder="请输入操作原因" 
                rows={3}
              />
            </Form.Item>
          )}

          <Form.Item>
            <Space>
              <Button type="primary" htmlType="submit">
                确认{getModalTitle()}
              </Button>
              <Button onClick={() => setModalVisible(false)}>
                取消
              </Button>
            </Space>
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default UserAccounts; 