import React, { useState, useEffect } from 'react';
import { 
  Card, 
  Row, 
  Col, 
  Statistic, 
  Typography, 
  Table, 
  Tag, 
  Progress,
  Spin,
  message,
  Space,
  Button
} from 'antd';
import { 
  PhoneOutlined, 
  FileTextOutlined, 
  CalendarOutlined, 
  DollarOutlined,
  UserOutlined,
  VideoCameraOutlined,
  ReloadOutlined,
  TrophyOutlined
} from '@ant-design/icons';

const { Title, Text } = Typography;

interface DashboardData {
  totalCalls: number;
  totalDocuments: number;
  totalAppointments: number;
  totalRevenue: number;
  activeUsers: number;
  videoCalls: number;
  recentCalls: Array<{
    id: string;
    caller: string;
    duration: string;
    status: 'completed' | 'ongoing' | 'failed';
    time: string;
  }>;
  systemStatus: {
    api: 'online' | 'offline';
    database: 'online' | 'offline';
    twilio: 'online' | 'offline';
  };
}

const Dashboard: React.FC = () => {
  const [loading, setLoading] = useState(true);
  const [data, setData] = useState<DashboardData>({
    totalCalls: 0,
    totalDocuments: 0,
    totalAppointments: 0,
    totalRevenue: 0,
    activeUsers: 0,
    videoCalls: 0,
    recentCalls: [],
    systemStatus: {
      api: 'online',
      database: 'online',
      twilio: 'online'
    }
  });

  const fetchDashboardData = async () => {
    try {
      setLoading(true);
      
      // 模拟API调用
      await new Promise(resolve => setTimeout(resolve, 1000));
      
      const mockData: DashboardData = {
        totalCalls: 1128,
        totalDocuments: 892,
        totalAppointments: 456,
        totalRevenue: 25680,
        activeUsers: 89,
        videoCalls: 234,
        recentCalls: [
          {
            id: '1',
            caller: '张三',
            duration: '15:30',
            status: 'completed',
            time: '2024-01-15 14:30'
          },
          {
            id: '2',
            caller: '李四',
            duration: '08:45',
            status: 'ongoing',
            time: '2024-01-15 14:25'
          },
          {
            id: '3',
            caller: '王五',
            duration: '22:10',
            status: 'completed',
            time: '2024-01-15 14:20'
          },
          {
            id: '4',
            caller: '赵六',
            duration: '05:15',
            status: 'failed',
            time: '2024-01-15 14:15'
          }
        ],
        systemStatus: {
          api: 'online',
          database: 'online',
          twilio: 'online'
        }
      };
      
      setData(mockData);
      message.success('仪表板数据加载成功');
    } catch (error) {
      console.error('获取仪表板数据失败:', error);
      message.error('获取仪表板数据失败');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchDashboardData();
  }, []);

  const recentCallsColumns = [
    {
      title: '呼叫者',
      dataIndex: 'caller',
      key: 'caller',
    },
    {
      title: '通话时长',
      dataIndex: 'duration',
      key: 'duration',
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      render: (status: string) => {
        const statusConfig = {
          completed: { color: 'green', text: '已完成' },
          ongoing: { color: 'blue', text: '进行中' },
          failed: { color: 'red', text: '失败' }
        };
        const config = statusConfig[status as keyof typeof statusConfig];
        return <Tag color={config.color}>{config.text}</Tag>;
      }
    },
    {
      title: '时间',
      dataIndex: 'time',
      key: 'time',
    }
  ];

  if (loading) {
    return (
      <div style={{ 
        padding: '24px', 
        display: 'flex', 
        justifyContent: 'center', 
        alignItems: 'center',
        minHeight: '400px'
      }}>
        <Spin size="large" tip="加载仪表板数据中..." />
      </div>
    );
  }

  return (
    <div style={{ padding: '24px' }}>
      <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center', marginBottom: '24px' }}>
        <Title level={2} style={{ margin: 0 }}>仪表板</Title>
        <Button 
          type="primary" 
          icon={<ReloadOutlined />} 
          onClick={fetchDashboardData}
          loading={loading}
        >
          刷新数据
        </Button>
      </div>
      
      {/* 统计卡片 */}
      <Row gutter={16} style={{ marginBottom: '24px' }}>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="总通话数"
              value={data.totalCalls}
              prefix={<PhoneOutlined />}
              valueStyle={{ color: '#3f8600' }}
            />
          </Card>
        </Col>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="文档翻译"
              value={data.totalDocuments}
              prefix={<FileTextOutlined />}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="预约服务"
              value={data.totalAppointments}
              prefix={<CalendarOutlined />}
              valueStyle={{ color: '#faad14' }}
            />
          </Card>
        </Col>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="总收入"
              value={data.totalRevenue}
              prefix={<DollarOutlined />}
              valueStyle={{ color: '#cf1322' }}
              suffix="元"
            />
          </Card>
        </Col>
      </Row>

      {/* 第二行统计 */}
      <Row gutter={16} style={{ marginBottom: '24px' }}>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="活跃用户"
              value={data.activeUsers}
              prefix={<UserOutlined />}
              valueStyle={{ color: '#722ed1' }}
            />
          </Card>
        </Col>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="视频通话"
              value={data.videoCalls}
              prefix={<VideoCameraOutlined />}
              valueStyle={{ color: '#eb2f96' }}
            />
          </Card>
        </Col>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <Statistic
              title="成功率"
              value={94.5}
              prefix={<TrophyOutlined />}
              valueStyle={{ color: '#52c41a' }}
              suffix="%"
            />
          </Card>
        </Col>
        <Col xs={24} sm={12} lg={6}>
          <Card>
            <div style={{ textAlign: 'center' }}>
              <Text type="secondary">系统负载</Text>
              <Progress 
                type="circle" 
                percent={75} 
                size={80}
                strokeColor={{
                  '0%': '#108ee9',
                  '100%': '#87d068',
                }}
              />
            </div>
          </Card>
        </Col>
      </Row>

      <Row gutter={16}>
        {/* 最近通话记录 */}
        <Col xs={24} lg={16}>
          <Card title="最近通话记录" style={{ marginBottom: '24px' }}>
            <Table
              columns={recentCallsColumns}
              dataSource={data.recentCalls}
              pagination={false}
              size="small"
              rowKey="id"
            />
          </Card>
        </Col>

        {/* 系统状态 */}
        <Col xs={24} lg={8}>
          <Card title="系统状态" style={{ marginBottom: '24px' }}>
            <Space direction="vertical" style={{ width: '100%' }}>
              <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
                <Text>API服务</Text>
                <Tag color={data.systemStatus.api === 'online' ? 'green' : 'red'}>
                  {data.systemStatus.api === 'online' ? '在线' : '离线'}
                </Tag>
              </div>
              <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
                <Text>数据库</Text>
                <Tag color={data.systemStatus.database === 'online' ? 'green' : 'red'}>
                  {data.systemStatus.database === 'online' ? '在线' : '离线'}
                </Tag>
              </div>
              <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
                <Text>Twilio服务</Text>
                <Tag color={data.systemStatus.twilio === 'online' ? 'green' : 'red'}>
                  {data.systemStatus.twilio === 'online' ? '在线' : '离线'}
                </Tag>
              </div>
            </Space>
          </Card>

          {/* 快速操作 */}
          <Card title="快速操作">
            <Space direction="vertical" style={{ width: '100%' }}>
              <Button type="primary" block icon={<PhoneOutlined />}>
                查看通话记录
              </Button>
              <Button block icon={<FileTextOutlined />}>
                管理文档翻译
              </Button>
              <Button block icon={<CalendarOutlined />}>
                预约管理
              </Button>
            </Space>
          </Card>
        </Col>
      </Row>
    </div>
  );
};

export default Dashboard; 