import React, { useState, useEffect } from 'react';
import { 
  Table, 
  Card, 
  Button, 
  Input, 
  Select, 
  Space, 
  Tag, 
  Typography, 
  Modal,
  message,
  Upload,
  Progress,
  Row,
  Col,
  Statistic,
  Tooltip
} from 'antd';
import { 
  SearchOutlined, 
  EyeOutlined, 
  DownloadOutlined,
  UploadOutlined,
  ReloadOutlined,
  FileTextOutlined,
  FilePdfOutlined,
  FileWordOutlined,
  FileExcelOutlined,
  DeleteOutlined,
  TranslationOutlined
} from '@ant-design/icons';
import type { ColumnsType } from 'antd/es/table';
import type { UploadProps } from 'antd';

const { Title } = Typography;
const { Option } = Select;

interface Document {
  id: string;
  fileName: string;
  fileType: string;
  fileSize: number;
  uploadTime: string;
  status: 'pending' | 'translating' | 'completed' | 'failed';
  sourceLanguage: string;
  targetLanguage: string;
  translator?: string;
  progress: number;
  downloadCount: number;
  cost: number;
}

const DocumentList: React.FC = () => {
  const [loading, setLoading] = useState(false);
  const [documents, setDocuments] = useState<Document[]>([]);
  const [filteredDocuments, setFilteredDocuments] = useState<Document[]>([]);
  const [searchText, setSearchText] = useState('');
  const [statusFilter, setStatusFilter] = useState<string>('all');
  const [uploadModalVisible, setUploadModalVisible] = useState(false);

  // 模拟数据
  const mockDocuments: Document[] = [
    {
      id: '1',
      fileName: '商业合同.pdf',
      fileType: 'pdf',
      fileSize: 2048576,
      uploadTime: '2024-01-15 14:30:00',
      status: 'completed',
      sourceLanguage: '中文',
      targetLanguage: '英文',
      translator: '王译员',
      progress: 100,
      downloadCount: 5,
      cost: 128.50
    },
    {
      id: '2',
      fileName: '技术文档.docx',
      fileType: 'docx',
      fileSize: 1536000,
      uploadTime: '2024-01-15 14:25:00',
      status: 'translating',
      sourceLanguage: '英文',
      targetLanguage: '中文',
      translator: '李译员',
      progress: 65,
      downloadCount: 0,
      cost: 0
    },
    {
      id: '3',
      fileName: '财务报表.xlsx',
      fileType: 'xlsx',
      fileSize: 512000,
      uploadTime: '2024-01-15 14:20:00',
      status: 'completed',
      sourceLanguage: '中文',
      targetLanguage: '日文',
      translator: '张译员',
      progress: 100,
      downloadCount: 12,
      cost: 85.30
    }
  ];

  const fetchDocuments = async () => {
    setLoading(true);
    try {
      await new Promise(resolve => setTimeout(resolve, 1000));
      setDocuments(mockDocuments);
      setFilteredDocuments(mockDocuments);
      message.success('文档列表加载成功');
    } catch (error) {
      message.error('加载文档列表失败');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchDocuments();
  }, []);

  useEffect(() => {
    let filtered = documents;

    if (searchText) {
      filtered = filtered.filter(doc => 
        doc.fileName.toLowerCase().includes(searchText.toLowerCase()) ||
        doc.sourceLanguage.includes(searchText) ||
        doc.targetLanguage.includes(searchText) ||
        (doc.translator && doc.translator.includes(searchText))
      );
    }

    if (statusFilter !== 'all') {
      filtered = filtered.filter(doc => doc.status === statusFilter);
    }

    setFilteredDocuments(filtered);
  }, [documents, searchText, statusFilter]);

  const getStatusTag = (status: string) => {
    const statusConfig = {
      pending: { color: 'orange', text: '待处理' },
      translating: { color: 'blue', text: '翻译中' },
      completed: { color: 'green', text: '已完成' },
      failed: { color: 'red', text: '失败' }
    };
    const config = statusConfig[status as keyof typeof statusConfig];
    return <Tag color={config.color}>{config.text}</Tag>;
  };

  const getFileIcon = (fileType: string) => {
    const iconMap = {
      pdf: <FilePdfOutlined style={{ color: '#ff4d4f' }} />,
      docx: <FileWordOutlined style={{ color: '#1890ff' }} />,
      xlsx: <FileExcelOutlined style={{ color: '#52c41a' }} />,
      txt: <FileTextOutlined style={{ color: '#722ed1' }} />
    };
    return iconMap[fileType as keyof typeof iconMap] || <FileTextOutlined />;
  };

  const formatFileSize = (bytes: number) => {
    if (bytes === 0) return '0 Bytes';
    const k = 1024;
    const sizes = ['Bytes', 'KB', 'MB', 'GB'];
    const i = Math.floor(Math.log(bytes) / Math.log(k));
    return parseFloat((bytes / Math.pow(k, i)).toFixed(2)) + ' ' + sizes[i];
  };

  const handleDownload = (document: Document) => {
    if (document.status !== 'completed') {
      message.warning('文档尚未翻译完成，无法下载');
      return;
    }
    message.success(`开始下载：${document.fileName}`);
  };

  const handleDelete = (document: Document) => {
    Modal.confirm({
      title: '确认删除',
      content: `确定要删除文档 "${document.fileName}" 吗？`,
      onOk: () => {
        const newDocuments = documents.filter(doc => doc.id !== document.id);
        setDocuments(newDocuments);
        message.success('文档删除成功');
      }
    });
  };

  const columns: ColumnsType<Document> = [
    {
      title: '文件名',
      dataIndex: 'fileName',
      key: 'fileName',
      width: 250,
      render: (text, record) => (
        <div style={{ display: 'flex', alignItems: 'center' }}>
          {getFileIcon(record.fileType)}
          <span style={{ marginLeft: 8 }}>{text}</span>
        </div>
      )
    },
    {
      title: '文件大小',
      dataIndex: 'fileSize',
      key: 'fileSize',
      width: 120,
      render: formatFileSize
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 100,
      render: getStatusTag
    },
    {
      title: '翻译进度',
      dataIndex: 'progress',
      key: 'progress',
      width: 120,
      render: (progress, record) => (
        <Progress 
          percent={progress} 
          size="small" 
          status={record.status === 'failed' ? 'exception' : undefined}
        />
      )
    },
    {
      title: '源语言',
      dataIndex: 'sourceLanguage',
      key: 'sourceLanguage',
      width: 100,
    },
    {
      title: '目标语言',
      dataIndex: 'targetLanguage',
      key: 'targetLanguage',
      width: 100,
    },
    {
      title: '费用(元)',
      dataIndex: 'cost',
      key: 'cost',
      width: 100,
      render: (cost) => cost > 0 ? `¥${cost.toFixed(2)}` : '-'
    },
    {
      title: '操作',
      key: 'action',
      width: 160,
      render: (_, record) => (
        <Space>
          <Tooltip title="查看详情">
            <Button
              type="primary"
              size="small"
              icon={<EyeOutlined />}
            />
          </Tooltip>
          <Tooltip title="下载">
            <Button
              size="small"
              icon={<DownloadOutlined />}
              disabled={record.status !== 'completed'}
              onClick={() => handleDownload(record)}
            />
          </Tooltip>
          <Tooltip title="删除">
            <Button
              danger
              size="small"
              icon={<DeleteOutlined />}
              onClick={() => handleDelete(record)}
            />
          </Tooltip>
        </Space>
      ),
    },
  ];

  const stats = {
    total: filteredDocuments.length,
    completed: filteredDocuments.filter(d => d.status === 'completed').length,
    translating: filteredDocuments.filter(d => d.status === 'translating').length,
    totalRevenue: filteredDocuments.reduce((sum, d) => sum + d.cost, 0)
  };

  return (
    <div style={{ padding: '24px' }}>
      <Title level={2}>文档管理</Title>

      <Row gutter={16} style={{ marginBottom: '24px' }}>
        <Col span={6}>
          <Card>
            <Statistic
              title="总文档数"
              value={stats.total}
              prefix={<FileTextOutlined />}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="已完成"
              value={stats.completed}
              valueStyle={{ color: '#52c41a' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="翻译中"
              value={stats.translating}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="总收入"
              value={stats.totalRevenue}
              precision={2}
              prefix="¥"
              valueStyle={{ color: '#cf1322' }}
            />
          </Card>
        </Col>
      </Row>

      <Card>
        <Row gutter={16} style={{ marginBottom: '16px' }}>
          <Col span={8}>
            <Input
              placeholder="搜索文件名、语言、译员..."
              prefix={<SearchOutlined />}
              value={searchText}
              onChange={(e) => setSearchText(e.target.value)}
            />
          </Col>
          <Col span={6}>
            <Select
              value={statusFilter}
              onChange={setStatusFilter}
              style={{ width: '100%' }}
              placeholder="状态筛选"
            >
              <Option value="all">全部状态</Option>
              <Option value="pending">待处理</Option>
              <Option value="translating">翻译中</Option>
              <Option value="completed">已完成</Option>
              <Option value="failed">失败</Option>
            </Select>
          </Col>
          <Col span={10}>
            <Space>
              <Button
                type="primary"
                icon={<UploadOutlined />}
                onClick={() => setUploadModalVisible(true)}
              >
                上传文档
              </Button>
              <Button
                icon={<ReloadOutlined />}
                onClick={fetchDocuments}
                loading={loading}
              >
                刷新
              </Button>
            </Space>
          </Col>
        </Row>

        <Table
          columns={columns}
          dataSource={filteredDocuments}
          loading={loading}
          rowKey="id"
          scroll={{ x: 1200 }}
          pagination={{
            total: filteredDocuments.length,
            pageSize: 10,
            showSizeChanger: true,
            showQuickJumper: true,
            showTotal: (total, range) => 
              `第 ${range[0]}-${range[1]} 条，共 ${total} 条记录`
          }}
        />
      </Card>
    </div>
  );
};

export default DocumentList; 