import React, { useState, useEffect } from 'react';
import { 
  Table, 
  Card, 
  Button, 
  Input, 
  Select, 
  Space, 
  Tag, 
  Typography, 
  Modal,
  message,
  Row,
  Col,
  Statistic,
  Tooltip,
  Avatar,
  Rate,
  Progress,
  Badge
} from 'antd';
import { 
  SearchOutlined, 
  EyeOutlined, 
  EditOutlined,
  ReloadOutlined,
  UserOutlined,
  StarOutlined,
  TrophyOutlined,
  GlobalOutlined,
  PhoneOutlined,
  VideoCameraOutlined,
  FileTextOutlined
} from '@ant-design/icons';
import type { ColumnsType } from 'antd/es/table';

const { Title } = Typography;
const { Option } = Select;

interface Translator {
  id: string;
  name: string;
  email: string;
  phone: string;
  avatar?: string;
  languages: string[];
  specialties: string[];
  rating: number;
  totalCalls: number;
  completedCalls: number;
  totalEarnings: number;
  status: 'available' | 'busy' | 'offline';
  experience: number; // 年
  certifications: string[];
  joinDate: string;
  lastActiveTime: string;
  hourlyRate: number;
}

const TranslatorList: React.FC = () => {
  const [loading, setLoading] = useState(false);
  const [translators, setTranslators] = useState<Translator[]>([]);
  const [filteredTranslators, setFilteredTranslators] = useState<Translator[]>([]);
  const [searchText, setSearchText] = useState('');
  const [languageFilter, setLanguageFilter] = useState<string>('all');
  const [statusFilter, setStatusFilter] = useState<string>('all');

  // 模拟数据
  const mockTranslators: Translator[] = [
    {
      id: '1',
      name: '王译员',
      email: 'wang@translator.com',
      phone: '13800138001',
      languages: ['中文', '英文', '日文'],
      specialties: ['商务', '技术', '医疗'],
      rating: 4.8,
      totalCalls: 156,
      completedCalls: 152,
      totalEarnings: 15600,
      status: 'available',
      experience: 5,
      certifications: ['CATTI二级', '商务英语高级'],
      joinDate: '2023-06-15',
      lastActiveTime: '2024-01-15 14:45:00',
      hourlyRate: 150
    },
    {
      id: '2',
      name: '李译员',
      email: 'li@translator.com',
      phone: '13800138002',
      languages: ['中文', '英文', '法文'],
      specialties: ['法律', '文学', '艺术'],
      rating: 4.9,
      totalCalls: 89,
      completedCalls: 87,
      totalEarnings: 12400,
      status: 'busy',
      experience: 7,
      certifications: ['CATTI一级', '法语专业八级'],
      joinDate: '2023-08-20',
      lastActiveTime: '2024-01-15 13:15:00',
      hourlyRate: 180
    },
    {
      id: '3',
      name: '张译员',
      email: 'zhang@translator.com',
      phone: '13800138003',
      languages: ['中文', '德文', '俄文'],
      specialties: ['工程', '科技', '学术'],
      rating: 4.7,
      totalCalls: 67,
      completedCalls: 65,
      totalEarnings: 8900,
      status: 'available',
      experience: 3,
      certifications: ['德语专业八级', '俄语专业六级'],
      joinDate: '2023-10-01',
      lastActiveTime: '2024-01-15 16:20:00',
      hourlyRate: 120
    },
    {
      id: '4',
      name: '赵译员',
      email: 'zhao@translator.com',
      phone: '13800138004',
      languages: ['中文', '韩文'],
      specialties: ['娱乐', '时尚', '旅游'],
      rating: 4.6,
      totalCalls: 45,
      completedCalls: 43,
      totalEarnings: 5400,
      status: 'offline',
      experience: 2,
      certifications: ['韩语TOPIK6级'],
      joinDate: '2023-11-15',
      lastActiveTime: '2024-01-14 18:30:00',
      hourlyRate: 100
    },
    {
      id: '5',
      name: '孙译员',
      email: 'sun@translator.com',
      phone: '13800138005',
      languages: ['中文', '西班牙文', '葡萄牙文'],
      specialties: ['体育', '新闻', '政治'],
      rating: 4.5,
      totalCalls: 78,
      completedCalls: 74,
      totalEarnings: 9200,
      status: 'available',
      experience: 4,
      certifications: ['西语专业八级', 'DELE C2'],
      joinDate: '2023-09-10',
      lastActiveTime: '2024-01-15 15:10:00',
      hourlyRate: 130
    }
  ];

  const fetchTranslators = async () => {
    setLoading(true);
    try {
      await new Promise(resolve => setTimeout(resolve, 1000));
      setTranslators(mockTranslators);
      setFilteredTranslators(mockTranslators);
      message.success('译员列表加载成功');
    } catch (error) {
      message.error('加载译员列表失败');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchTranslators();
  }, []);

  useEffect(() => {
    let filtered = translators;

    if (searchText) {
      filtered = filtered.filter(translator => 
        translator.name.toLowerCase().includes(searchText.toLowerCase()) ||
        translator.email.toLowerCase().includes(searchText.toLowerCase()) ||
        translator.languages.some(lang => lang.includes(searchText)) ||
        translator.specialties.some(spec => spec.includes(searchText))
      );
    }

    if (languageFilter !== 'all') {
      filtered = filtered.filter(translator => 
        translator.languages.includes(languageFilter)
      );
    }

    if (statusFilter !== 'all') {
      filtered = filtered.filter(translator => translator.status === statusFilter);
    }

    setFilteredTranslators(filtered);
  }, [translators, searchText, languageFilter, statusFilter]);

  const getStatusTag = (status: string) => {
    const statusConfig = {
      available: { color: 'green', text: '可用' },
      busy: { color: 'orange', text: '忙碌' },
      offline: { color: 'red', text: '离线' }
    };
    const config = statusConfig[status as keyof typeof statusConfig];
    return <Badge status={status === 'available' ? 'success' : status === 'busy' ? 'processing' : 'error'} text={config.text} />;
  };

  const columns: ColumnsType<Translator> = [
    {
      title: '译员信息',
      key: 'translatorInfo',
      width: 250,
      render: (_, record) => (
        <div style={{ display: 'flex', alignItems: 'center' }}>
          <Avatar 
            size={50} 
            src={record.avatar} 
            icon={<UserOutlined />}
            style={{ marginRight: 12 }}
          />
          <div>
            <div style={{ fontWeight: 'bold', marginBottom: 4 }}>
              {record.name}
            </div>
            <div style={{ fontSize: '12px', color: '#666', marginBottom: 4 }}>
              {record.email}
            </div>
            <div style={{ fontSize: '12px', color: '#666' }}>
              {record.experience} 年经验
            </div>
          </div>
        </div>
      )
    },
    {
      title: '语言能力',
      dataIndex: 'languages',
      key: 'languages',
      width: 200,
      render: (languages) => (
        <div>
          {languages.map((lang: string) => (
            <Tag key={lang} color="blue" style={{ marginBottom: 4 }}>
              {lang}
            </Tag>
          ))}
        </div>
      )
    },
    {
      title: '专业领域',
      dataIndex: 'specialties',
      key: 'specialties',
      width: 180,
      render: (specialties) => (
        <div>
          {specialties.map((spec: string) => (
            <Tag key={spec} color="purple" style={{ marginBottom: 4 }}>
              {spec}
            </Tag>
          ))}
        </div>
      )
    },
    {
      title: '评分',
      dataIndex: 'rating',
      key: 'rating',
      width: 120,
      render: (rating) => (
        <div>
          <Rate disabled defaultValue={rating} style={{ fontSize: '14px' }} />
          <div style={{ fontSize: '12px', color: '#666' }}>
            {rating}/5.0
          </div>
        </div>
      )
    },
    {
      title: '工作统计',
      key: 'stats',
      width: 150,
      render: (_, record) => (
        <div>
          <div style={{ fontSize: '12px', marginBottom: 4 }}>
            总通话: {record.totalCalls} 次
          </div>
          <div style={{ fontSize: '12px', marginBottom: 4 }}>
            完成率: {((record.completedCalls / record.totalCalls) * 100).toFixed(1)}%
          </div>
          <div style={{ fontSize: '12px' }}>
            收入: ¥{record.totalEarnings.toLocaleString()}
          </div>
        </div>
      )
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 100,
      render: getStatusTag
    },
    {
      title: '时薪',
      dataIndex: 'hourlyRate',
      key: 'hourlyRate',
      width: 100,
      render: (rate) => `¥${rate}/小时`
    },
    {
      title: '操作',
      key: 'action',
      width: 150,
      render: (_, record) => (
        <Space>
          <Tooltip title="查看详情">
            <Button
              type="primary"
              size="small"
              icon={<EyeOutlined />}
            />
          </Tooltip>
          <Tooltip title="编辑">
            <Button
              size="small"
              icon={<EditOutlined />}
            />
          </Tooltip>
          <Tooltip title="分配任务">
            <Button
              size="small"
              icon={<PhoneOutlined />}
              disabled={record.status !== 'available'}
            />
          </Tooltip>
        </Space>
      ),
    },
  ];

  const stats = {
    total: filteredTranslators.length,
    available: filteredTranslators.filter(t => t.status === 'available').length,
    busy: filteredTranslators.filter(t => t.status === 'busy').length,
    averageRating: filteredTranslators.reduce((sum, t) => sum + t.rating, 0) / filteredTranslators.length || 0,
    totalEarnings: filteredTranslators.reduce((sum, t) => sum + t.totalEarnings, 0)
  };

  return (
    <div style={{ padding: '24px' }}>
      <Title level={2}>译员管理</Title>

      <Row gutter={16} style={{ marginBottom: '24px' }}>
        <Col span={6}>
          <Card>
            <Statistic
              title="总译员数"
              value={stats.total}
              prefix={<UserOutlined />}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="可用译员"
              value={stats.available}
              valueStyle={{ color: '#52c41a' }}
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="平均评分"
              value={stats.averageRating}
              precision={1}
              prefix={<StarOutlined />}
              valueStyle={{ color: '#faad14' }}
              suffix="/5.0"
            />
          </Card>
        </Col>
        <Col span={6}>
          <Card>
            <Statistic
              title="总收入"
              value={stats.totalEarnings}
              prefix="¥"
              valueStyle={{ color: '#cf1322' }}
            />
          </Card>
        </Col>
      </Row>

      <Card>
        <Row gutter={16} style={{ marginBottom: '16px' }}>
          <Col span={8}>
            <Input
              placeholder="搜索译员姓名、邮箱、语言、专业..."
              prefix={<SearchOutlined />}
              value={searchText}
              onChange={(e) => setSearchText(e.target.value)}
            />
          </Col>
          <Col span={6}>
            <Select
              value={languageFilter}
              onChange={setLanguageFilter}
              style={{ width: '100%' }}
              placeholder="语言筛选"
            >
              <Option value="all">全部语言</Option>
              <Option value="英文">英文</Option>
              <Option value="日文">日文</Option>
              <Option value="法文">法文</Option>
              <Option value="德文">德文</Option>
              <Option value="韩文">韩文</Option>
              <Option value="西班牙文">西班牙文</Option>
              <Option value="俄文">俄文</Option>
            </Select>
          </Col>
          <Col span={6}>
            <Select
              value={statusFilter}
              onChange={setStatusFilter}
              style={{ width: '100%' }}
              placeholder="状态筛选"
            >
              <Option value="all">全部状态</Option>
              <Option value="available">可用</Option>
              <Option value="busy">忙碌</Option>
              <Option value="offline">离线</Option>
            </Select>
          </Col>
          <Col span={4}>
            <Button
              icon={<ReloadOutlined />}
              onClick={fetchTranslators}
              loading={loading}
              style={{ width: '100%' }}
            >
              刷新
            </Button>
          </Col>
        </Row>

        <Table
          columns={columns}
          dataSource={filteredTranslators}
          loading={loading}
          rowKey="id"
          scroll={{ x: 1200 }}
          pagination={{
            total: filteredTranslators.length,
            pageSize: 10,
            showSizeChanger: true,
            showQuickJumper: true,
            showTotal: (total, range) => 
              `第 ${range[0]}-${range[1]} 条，共 ${total} 条记录`
          }}
        />
      </Card>
    </div>
  );
};

export default TranslatorList; 