import React, { useState, useEffect } from 'react';
import { 
  Table, 
  Card, 
  Button, 
  Input, 
  Select, 
  Space, 
  Tag, 
  Typography, 
  Modal,
  message,
  DatePicker,
  Row,
  Col,
  Statistic,
  Tooltip,
  Avatar,
  Form,
  Switch
} from 'antd';
import { 
  SearchOutlined, 
  EyeOutlined, 
  EditOutlined,
  DeleteOutlined,
  PlusOutlined,
  ReloadOutlined,
  UserOutlined,
  MailOutlined,
  PhoneOutlined,
  LockOutlined,
  UnlockOutlined
} from '@ant-design/icons';
import type { ColumnsType } from 'antd/es/table';

const { Title } = Typography;
const { Option } = Select;
const { RangePicker } = DatePicker;

interface User {
  id: string;
  username: string;
  email: string;
  phone: string;
  realName: string;
  role: 'admin' | 'translator' | 'customer' | 'manager';
  status: 'active' | 'inactive' | 'banned';
  avatar?: string;
  lastLoginTime?: string;
  registrationTime: string;
  totalCalls: number;
  totalSpent: number;
  preferredLanguages: string[];
  notes?: string;
}

const UserList: React.FC = () => {
  const [loading, setLoading] = useState(false);
  const [users, setUsers] = useState<User[]>([]);
  const [filteredUsers, setFilteredUsers] = useState<User[]>([]);
  const [searchText, setSearchText] = useState('');
  const [roleFilter, setRoleFilter] = useState<string>('all');
  const [statusFilter, setStatusFilter] = useState<string>('all');
  const [modalVisible, setModalVisible] = useState(false);
  const [editingUser, setEditingUser] = useState<User | null>(null);
  const [form] = Form.useForm();

  // 模拟数据
  const mockUsers: User[] = [
    {
      id: '1',
      username: 'admin001',
      email: 'admin@example.com',
      phone: '13800138001',
      realName: '系统管理员',
      role: 'admin',
      status: 'active',
      lastLoginTime: '2024-01-15 15:30:00',
      registrationTime: '2023-01-01 10:00:00',
      totalCalls: 0,
      totalSpent: 0,
      preferredLanguages: ['中文', '英文'],
      notes: '系统管理员账户'
    },
    {
      id: '2',
      username: 'translator_wang',
      email: 'wang@translator.com',
      phone: '13800138002',
      realName: '王译员',
      role: 'translator',
      status: 'active',
      lastLoginTime: '2024-01-15 14:45:00',
      registrationTime: '2023-06-15 09:30:00',
      totalCalls: 156,
      totalSpent: 0,
      preferredLanguages: ['中文', '英文', '日文'],
      notes: '资深英日翻译，5年经验'
    },
    {
      id: '3',
      username: 'customer_zhang',
      email: 'zhang@customer.com',
      phone: '13800138003',
      realName: '张先生',
      role: 'customer',
      status: 'active',
      lastLoginTime: '2024-01-15 16:20:00',
      registrationTime: '2023-12-01 14:20:00',
      totalCalls: 23,
      totalSpent: 1580.50,
      preferredLanguages: ['中文', '英文'],
      notes: '企业客户，经常需要商务翻译'
    },
    {
      id: '4',
      username: 'translator_li',
      email: 'li@translator.com',
      phone: '13800138004',
      realName: '李译员',
      role: 'translator',
      status: 'active',
      lastLoginTime: '2024-01-15 13:15:00',
      registrationTime: '2023-08-20 11:45:00',
      totalCalls: 89,
      totalSpent: 0,
      preferredLanguages: ['中文', '英文', '法文'],
      notes: '法语专业译员'
    },
    {
      id: '5',
      username: 'customer_li',
      email: 'li_customer@example.com',
      phone: '13800138005',
      realName: '李女士',
      role: 'customer',
      status: 'inactive',
      lastLoginTime: '2024-01-10 10:30:00',
      registrationTime: '2023-11-15 16:00:00',
      totalCalls: 8,
      totalSpent: 420.00,
      preferredLanguages: ['中文', '韩文'],
      notes: '个人用户，偶尔使用'
    },
    {
      id: '6',
      username: 'manager001',
      email: 'manager@example.com',
      phone: '13800138006',
      realName: '业务经理',
      role: 'manager',
      status: 'active',
      lastLoginTime: '2024-01-15 17:00:00',
      registrationTime: '2023-03-01 08:00:00',
      totalCalls: 0,
      totalSpent: 0,
      preferredLanguages: ['中文', '英文'],
      notes: '负责客户关系管理'
    }
  ];

  const fetchUsers = async () => {
    setLoading(true);
    try {
      await new Promise(resolve => setTimeout(resolve, 1000));
      setUsers(mockUsers);
      setFilteredUsers(mockUsers);
      message.success('用户列表加载成功');
    } catch (error) {
      message.error('加载用户列表失败');
    } finally {
      setLoading(false);
    }
  };

  useEffect(() => {
    fetchUsers();
  }, []);

  useEffect(() => {
    let filtered = users;

    if (searchText) {
      filtered = filtered.filter(user => 
        user.username.toLowerCase().includes(searchText.toLowerCase()) ||
        user.email.toLowerCase().includes(searchText.toLowerCase()) ||
        user.realName.includes(searchText) ||
        user.phone.includes(searchText)
      );
    }

    if (roleFilter !== 'all') {
      filtered = filtered.filter(user => user.role === roleFilter);
    }

    if (statusFilter !== 'all') {
      filtered = filtered.filter(user => user.status === statusFilter);
    }

    setFilteredUsers(filtered);
  }, [users, searchText, roleFilter, statusFilter]);

  const getRoleTag = (role: string) => {
    const roleConfig = {
      admin: { color: 'red', text: '管理员' },
      manager: { color: 'purple', text: '经理' },
      translator: { color: 'blue', text: '译员' },
      customer: { color: 'green', text: '客户' }
    };
    const config = roleConfig[role as keyof typeof roleConfig];
    return <Tag color={config.color}>{config.text}</Tag>;
  };

  const getStatusTag = (status: string) => {
    const statusConfig = {
      active: { color: 'green', text: '活跃' },
      inactive: { color: 'orange', text: '非活跃' },
      banned: { color: 'red', text: '已禁用' }
    };
    const config = statusConfig[status as keyof typeof statusConfig];
    return <Tag color={config.color}>{config.text}</Tag>;
  };

  const handleStatusToggle = (userId: string, newStatus: User['status']) => {
    const updatedUsers = users.map(user => 
      user.id === userId ? { ...user, status: newStatus } : user
    );
    setUsers(updatedUsers);
    message.success('用户状态更新成功');
  };

  const handleEdit = (user: User) => {
    setEditingUser(user);
    form.setFieldsValue(user);
    setModalVisible(true);
  };

  const handleDelete = (user: User) => {
    Modal.confirm({
      title: '确认删除',
      content: `确定要删除用户 "${user.realName}" 吗？此操作不可恢复。`,
      onOk: () => {
        const newUsers = users.filter(u => u.id !== user.id);
        setUsers(newUsers);
        message.success('用户删除成功');
      }
    });
  };

  const handleSave = async (values: any) => {
    try {
      if (editingUser) {
        const updatedUsers = users.map(user => 
          user.id === editingUser.id ? { ...user, ...values } : user
        );
        setUsers(updatedUsers);
        message.success('用户信息更新成功');
      } else {
        const newUser: User = {
          id: Date.now().toString(),
          ...values,
          registrationTime: new Date().toLocaleString(),
          totalCalls: 0,
          totalSpent: 0
        };
        setUsers([...users, newUser]);
        message.success('用户创建成功');
      }

      setModalVisible(false);
      setEditingUser(null);
      form.resetFields();
    } catch (error) {
      message.error('保存失败');
    }
  };

  const columns: ColumnsType<User> = [
    {
      title: '用户信息',
      key: 'userInfo',
      width: 250,
      render: (_, record) => (
        <div style={{ display: 'flex', alignItems: 'center' }}>
          <Avatar 
            size={40} 
            src={record.avatar} 
            icon={<UserOutlined />}
            style={{ marginRight: 12 }}
          />
          <div>
            <div style={{ fontWeight: 'bold', marginBottom: 4 }}>
              {record.realName}
            </div>
            <div style={{ fontSize: '12px', color: '#666' }}>
              @{record.username}
            </div>
          </div>
        </div>
      )
    },
    {
      title: '联系方式',
      key: 'contact',
      width: 200,
      render: (_, record) => (
        <div>
          <div style={{ display: 'flex', alignItems: 'center', marginBottom: 4 }}>
            <MailOutlined style={{ marginRight: 4, color: '#666' }} />
            <span style={{ fontSize: '12px' }}>{record.email}</span>
          </div>
          <div style={{ display: 'flex', alignItems: 'center' }}>
            <PhoneOutlined style={{ marginRight: 4, color: '#666' }} />
            <span style={{ fontSize: '12px' }}>{record.phone}</span>
          </div>
        </div>
      )
    },
    {
      title: '角色',
      dataIndex: 'role',
      key: 'role',
      width: 100,
      render: getRoleTag
    },
    {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      width: 100,
      render: getStatusTag
    },
    {
      title: '统计信息',
      key: 'stats',
      width: 150,
      render: (_, record) => (
        <div>
          <div style={{ fontSize: '12px', marginBottom: 4 }}>
            通话: {record.totalCalls} 次
          </div>
          <div style={{ fontSize: '12px' }}>
            消费: ¥{record.totalSpent.toFixed(2)}
          </div>
        </div>
      )
    },
    {
      title: '最后登录',
      dataIndex: 'lastLoginTime',
      key: 'lastLoginTime',
      width: 150,
      render: (time) => time || '从未登录'
    },
    {
      title: '操作',
      key: 'action',
      width: 200,
      render: (_, record) => (
        <Space>
          <Tooltip title="查看详情">
            <Button
              type="primary"
              size="small"
              icon={<EyeOutlined />}
            />
          </Tooltip>
          <Tooltip title="编辑">
            <Button
              size="small"
              icon={<EditOutlined />}
              onClick={() => handleEdit(record)}
            />
          </Tooltip>
          <Tooltip title={record.status === 'active' ? '禁用' : '启用'}>
            <Button
              size="small"
              icon={record.status === 'active' ? <LockOutlined /> : <UnlockOutlined />}
              onClick={() => handleStatusToggle(
                record.id, 
                record.status === 'active' ? 'banned' : 'active'
              )}
            />
          </Tooltip>
          <Tooltip title="删除">
            <Button
              danger
              size="small"
              icon={<DeleteOutlined />}
              onClick={() => handleDelete(record)}
            />
          </Tooltip>
        </Space>
      ),
    },
  ];

  const stats = {
    total: filteredUsers.length,
    admin: filteredUsers.filter(u => u.role === 'admin').length,
    translator: filteredUsers.filter(u => u.role === 'translator').length,
    customer: filteredUsers.filter(u => u.role === 'customer').length,
    active: filteredUsers.filter(u => u.status === 'active').length
  };

  return (
    <div style={{ padding: '24px' }}>
      <Title level={2}>用户管理</Title>

      <Row gutter={16} style={{ marginBottom: '24px' }}>
        <Col span={5}>
          <Card>
            <Statistic
              title="总用户数"
              value={stats.total}
              prefix={<UserOutlined />}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={5}>
          <Card>
            <Statistic
              title="管理员"
              value={stats.admin}
              valueStyle={{ color: '#cf1322' }}
            />
          </Card>
        </Col>
        <Col span={5}>
          <Card>
            <Statistic
              title="译员"
              value={stats.translator}
              valueStyle={{ color: '#1890ff' }}
            />
          </Card>
        </Col>
        <Col span={4}>
          <Card>
            <Statistic
              title="客户"
              value={stats.customer}
              valueStyle={{ color: '#52c41a' }}
            />
          </Card>
        </Col>
        <Col span={5}>
          <Card>
            <Statistic
              title="活跃用户"
              value={stats.active}
              valueStyle={{ color: '#722ed1' }}
            />
          </Card>
        </Col>
      </Row>

      <Card>
        <Row gutter={16} style={{ marginBottom: '16px' }}>
          <Col span={6}>
            <Input
              placeholder="搜索用户名、邮箱、姓名、电话..."
              prefix={<SearchOutlined />}
              value={searchText}
              onChange={(e) => setSearchText(e.target.value)}
            />
          </Col>
          <Col span={4}>
            <Select
              value={roleFilter}
              onChange={setRoleFilter}
              style={{ width: '100%' }}
              placeholder="角色筛选"
            >
              <Option value="all">全部角色</Option>
              <Option value="admin">管理员</Option>
              <Option value="manager">经理</Option>
              <Option value="translator">译员</Option>
              <Option value="customer">客户</Option>
            </Select>
          </Col>
          <Col span={4}>
            <Select
              value={statusFilter}
              onChange={setStatusFilter}
              style={{ width: '100%' }}
              placeholder="状态筛选"
            >
              <Option value="all">全部状态</Option>
              <Option value="active">活跃</Option>
              <Option value="inactive">非活跃</Option>
              <Option value="banned">已禁用</Option>
            </Select>
          </Col>
          <Col span={6}>
            <RangePicker style={{ width: '100%' }} placeholder={['注册开始日期', '注册结束日期']} />
          </Col>
          <Col span={4}>
            <Space>
              <Button
                type="primary"
                icon={<PlusOutlined />}
                onClick={() => {
                  setEditingUser(null);
                  form.resetFields();
                  setModalVisible(true);
                }}
              >
                新增用户
              </Button>
              <Button
                icon={<ReloadOutlined />}
                onClick={fetchUsers}
                loading={loading}
              />
            </Space>
          </Col>
        </Row>

        <Table
          columns={columns}
          dataSource={filteredUsers}
          loading={loading}
          rowKey="id"
          scroll={{ x: 1200 }}
          pagination={{
            total: filteredUsers.length,
            pageSize: 10,
            showSizeChanger: true,
            showQuickJumper: true,
            showTotal: (total, range) => 
              `第 ${range[0]}-${range[1]} 条，共 ${total} 条记录`
          }}
        />
      </Card>

      <Modal
        title={editingUser ? '编辑用户' : '新增用户'}
        open={modalVisible}
        onCancel={() => {
          setModalVisible(false);
          setEditingUser(null);
          form.resetFields();
        }}
        onOk={() => form.submit()}
        width={800}
      >
        <Form
          form={form}
          layout="vertical"
          onFinish={handleSave}
        >
          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                name="username"
                label="用户名"
                rules={[{ required: true, message: '请输入用户名' }]}
              >
                <Input />
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                name="realName"
                label="真实姓名"
                rules={[{ required: true, message: '请输入真实姓名' }]}
              >
                <Input />
              </Form.Item>
            </Col>
          </Row>
          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                name="email"
                label="邮箱"
                rules={[
                  { required: true, message: '请输入邮箱' },
                  { type: 'email', message: '请输入有效的邮箱地址' }
                ]}
              >
                <Input />
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                name="phone"
                label="电话"
                rules={[{ required: true, message: '请输入电话号码' }]}
              >
                <Input />
              </Form.Item>
            </Col>
          </Row>
          <Row gutter={16}>
            <Col span={12}>
              <Form.Item
                name="role"
                label="角色"
                rules={[{ required: true, message: '请选择角色' }]}
              >
                <Select>
                  <Option value="admin">管理员</Option>
                  <Option value="manager">经理</Option>
                  <Option value="translator">译员</Option>
                  <Option value="customer">客户</Option>
                </Select>
              </Form.Item>
            </Col>
            <Col span={12}>
              <Form.Item
                name="status"
                label="状态"
                rules={[{ required: true, message: '请选择状态' }]}
              >
                <Select>
                  <Option value="active">活跃</Option>
                  <Option value="inactive">非活跃</Option>
                  <Option value="banned">已禁用</Option>
                </Select>
              </Form.Item>
            </Col>
          </Row>
          <Form.Item
            name="preferredLanguages"
            label="偏好语言"
          >
            <Select mode="multiple" placeholder="选择偏好语言">
              <Option value="中文">中文</Option>
              <Option value="英文">英文</Option>
              <Option value="日文">日文</Option>
              <Option value="韩文">韩文</Option>
              <Option value="法文">法文</Option>
              <Option value="德文">德文</Option>
              <Option value="西班牙文">西班牙文</Option>
              <Option value="俄文">俄文</Option>
            </Select>
          </Form.Item>
          <Form.Item
            name="notes"
            label="备注"
          >
            <Input.TextArea rows={3} />
          </Form.Item>
        </Form>
      </Modal>
    </div>
  );
};

export default UserList; 