import { TranslationCall, DocumentTranslation, Appointment, ApiResponse, PaginatedResponse } from '../types';

// API基础URL配置
const API_BASE_URL = process.env.REACT_APP_API_URL || 'http://localhost:8000/api';

// HTTP请求方法
type HttpMethod = 'GET' | 'POST' | 'PUT' | 'DELETE' | 'PATCH';

// 请求选项
interface RequestOptions {
  method?: HttpMethod;
  headers?: Record<string, string>;
  body?: any;
  params?: Record<string, any>;
}

// API客户端类
export class ApiClient {
  private baseURL: string;
  private defaultHeaders: Record<string, string>;

  constructor(baseURL = API_BASE_URL) {
    this.baseURL = baseURL;
    this.defaultHeaders = {
      'Content-Type': 'application/json',
      'Accept': 'application/json',
    };
  }

  // 设置授权令牌
  setAuthToken(token: string): void {
    this.defaultHeaders['Authorization'] = `Bearer ${token}`;
  }

  // 移除授权令牌
  removeAuthToken(): void {
    delete this.defaultHeaders['Authorization'];
  }

  // 构建URL参数
  private buildURL(endpoint: string, params?: Record<string, any>): string {
    const url = new URL(`${this.baseURL}${endpoint}`);
    
    if (params) {
      Object.entries(params).forEach(([key, value]) => {
        if (value !== undefined && value !== null) {
          url.searchParams.append(key, String(value));
        }
      });
    }
    
    return url.toString();
  }

  // 发送HTTP请求
  private async request<T>(
    endpoint: string, 
    options: RequestOptions = {}
  ): Promise<ApiResponse<T>> {
    try {
      const { method = 'GET', headers = {}, body, params } = options;
      
      const url = this.buildURL(endpoint, params);
      
      const requestHeaders = {
        ...this.defaultHeaders,
        ...headers,
      };

      const requestInit: RequestInit = {
        method,
        headers: requestHeaders,
      };

      if (body && method !== 'GET') {
        if (body instanceof FormData) {
          // 对于FormData，不设置Content-Type，让浏览器自动设置
          delete requestHeaders['Content-Type'];
          requestInit.body = body;
        } else {
          requestInit.body = JSON.stringify(body);
        }
      }

      const response = await fetch(url, requestInit);
      
      // 检查响应状态
      if (!response.ok) {
        const errorText = await response.text();
        throw new Error(`HTTP ${response.status}: ${errorText}`);
      }

      const data = await response.json();
      
      return {
        success: true,
        data,
      };
    } catch (error) {
      console.error('API请求失败:', error);
      
      return {
        success: false,
        error: error instanceof Error ? error.message : '未知错误',
      };
    }
  }

  // GET请求
  async get<T>(endpoint: string, params?: Record<string, any>): Promise<ApiResponse<T>> {
    return this.request<T>(endpoint, { method: 'GET', params });
  }

  // POST请求
  async post<T>(endpoint: string, body?: any): Promise<ApiResponse<T>> {
    return this.request<T>(endpoint, { method: 'POST', body });
  }

  // PUT请求
  async put<T>(endpoint: string, body?: any): Promise<ApiResponse<T>> {
    return this.request<T>(endpoint, { method: 'PUT', body });
  }

  // PATCH请求
  async patch<T>(endpoint: string, body?: any): Promise<ApiResponse<T>> {
    return this.request<T>(endpoint, { method: 'PATCH', body });
  }

  // DELETE请求
  async delete<T>(endpoint: string): Promise<ApiResponse<T>> {
    return this.request<T>(endpoint, { method: 'DELETE' });
  }

  // 上传文件
  async upload<T>(endpoint: string, file: File, additionalData?: Record<string, any>): Promise<ApiResponse<T>> {
    const formData = new FormData();
    formData.append('file', file);
    
    if (additionalData) {
      Object.entries(additionalData).forEach(([key, value]) => {
        formData.append(key, String(value));
      });
    }

    return this.request<T>(endpoint, { 
      method: 'POST', 
      body: formData 
    });
  }

  // 获取分页数据
  async getPaginated<T>(
    endpoint: string, 
    page = 1, 
    pageSize = 10, 
    params?: Record<string, any>
  ): Promise<ApiResponse<PaginatedResponse<T>>> {
    const paginationParams = {
      page,
      pageSize,
      ...params,
    };
    
    return this.get<PaginatedResponse<T>>(endpoint, paginationParams);
  }

  // 通话管理API
  async getCall(id: string): Promise<ApiResponse<TranslationCall>> {
    return this.get<TranslationCall>(`/calls/${id}`);
  }

  async updateCall(id: string, data: Partial<TranslationCall>): Promise<ApiResponse<TranslationCall>> {
    return this.post<TranslationCall>(`/calls/${id}`, data);
  }

  async deleteCall(id: string): Promise<ApiResponse<boolean>> {
    return this.delete<boolean>(`/calls/${id}`);
  }

  async processRefund(callId: string, amount: number, reason: string): Promise<ApiResponse<boolean>> {
    return this.post<boolean>(`/calls/${callId}/refund`, { amount, reason });
  }

  async addCallNote(callId: string, note: string): Promise<ApiResponse<boolean>> {
    return this.post<boolean>(`/calls/${callId}/notes`, { note });
  }

  // 文档翻译API
  async getDocument(id: string): Promise<ApiResponse<DocumentTranslation>> {
    return this.get<DocumentTranslation>(`/documents/${id}`);
  }

  async updateDocument(id: string, data: Partial<DocumentTranslation>): Promise<ApiResponse<DocumentTranslation>> {
    return this.put<DocumentTranslation>(`/documents/${id}`, data);
  }

  async deleteDocument(id: string): Promise<ApiResponse<boolean>> {
    return this.delete<boolean>(`/documents/${id}`);
  }

  async reassignTranslator(documentId: string, translatorId: string): Promise<ApiResponse<boolean>> {
    return this.post<boolean>(`/documents/${documentId}/reassign`, { translatorId });
  }

  async retranslateDocument(documentId: string, quality: string): Promise<ApiResponse<boolean>> {
    return this.post<boolean>(`/documents/${documentId}/retranslate`, { quality });
  }

  async addDocumentNote(documentId: string, note: string): Promise<ApiResponse<boolean>> {
    return this.post<boolean>(`/documents/${documentId}/notes`, { note });
  }

  // 预约管理API
  async getAppointment(id: string): Promise<ApiResponse<Appointment>> {
    return this.get<Appointment>(`/appointments/${id}`);
  }

  async updateAppointment(id: string, data: Partial<Appointment>): Promise<ApiResponse<Appointment>> {
    return this.put<Appointment>(`/appointments/${id}`, data);
  }

  async deleteAppointment(id: string): Promise<ApiResponse<boolean>> {
    return this.delete<boolean>(`/appointments/${id}`);
  }

  async rescheduleAppointment(
    appointmentId: string, 
    newStartTime: string, 
    newEndTime: string
  ): Promise<ApiResponse<boolean>> {
    return this.post<boolean>(`/appointments/${appointmentId}/reschedule`, { newStartTime, newEndTime });
  }

  async reassignAppointmentTranslator(
    appointmentId: string, 
    translatorId: string
  ): Promise<ApiResponse<boolean>> {
    return this.post<boolean>(`/appointments/${appointmentId}/reassign`, { translatorId });
  }

  async addAppointmentNote(appointmentId: string, note: string): Promise<ApiResponse<boolean>> {
    return this.post<boolean>(`/appointments/${appointmentId}/notes`, { note });
  }

  // 退款处理API
  async refundPayment(paymentId: string, amount: number): Promise<ApiResponse<boolean>> {
    return this.post<boolean>(`/payments/${paymentId}/refund`, { amount });
  }

  // 统计数据API
  async getStatistics(): Promise<ApiResponse<any>> {
    return this.get<any>('/statistics');
  }

  // 用户管理API
  async getUsers(page: number = 1, pageSize: number = 10): Promise<ApiResponse<any>> {
    return this.get<any>(`/users?page=${page}&pageSize=${pageSize}`);
  }

  async updateUser(userId: string, data: any): Promise<ApiResponse<any>> {
    return this.put<any>(`/users/${userId}`, data);
  }

  // 译员管理API
  async getTranslators(page: number = 1, pageSize: number = 10): Promise<ApiResponse<any>> {
    return this.get<any>(`/translators?page=${page}&pageSize=${pageSize}`);
  }

  async updateTranslator(translatorId: string, data: any): Promise<ApiResponse<any>> {
    return this.put<any>(`/translators/${translatorId}`, data);
  }

  // 系统配置API
  async getSystemConfig(): Promise<ApiResponse<any>> {
    return this.get<any>('/config');
  }

  async updateSystemConfig(config: any): Promise<ApiResponse<any>> {
    return this.put<any>('/config', config);
  }
}

// 导出默认API客户端实例
export const api = new ApiClient();

// 导出常用的API方法
export const {
  get,
  post,
  put,
  patch,
  delete: del,
  upload,
  getPaginated,
} = api; 