import * as React from 'react';
import { useState } from 'react';
import {
  Modal,
  Form,
  Input,
  Select,
  Button,
  Space,
  message,
  DatePicker,
  TimePicker,
  Radio,
  Divider,
  Card,
  Tag,
  Avatar,
  Alert,
} from 'antd';
import {
  CalendarOutlined,
  UserOutlined,
  TranslationOutlined,
  DollarOutlined,
  ClockCircleOutlined,
  VideoCameraOutlined,
  PhoneOutlined,
} from '@ant-design/icons';
import dayjs from 'dayjs';
import { api } from '@/utils/api';

const { Option } = Select;
const { RangePicker } = TimePicker;

interface NewAppointmentModalProps {
  visible: boolean;
  onCancel: () => void;
  onSuccess: () => void;
}

interface AppointmentFormData {
  title: string;
  description?: string;
  type: 'interpretation' | 'consultation' | 'document_review';
  sourceLanguage: string;
  targetLanguage: string;
  date: dayjs.Dayjs;
  timeRange: [dayjs.Dayjs, dayjs.Dayjs];
  translatorId?: string;
  meetingType: 'online' | 'offline' | 'phone';
  location?: string;
  urgency: 'normal' | 'urgent';
  notes?: string;
}

const NewAppointmentModal: React.FC<NewAppointmentModalProps> = ({
  visible,
  onCancel,
  onSuccess,
}) => {
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [selectedDate, setSelectedDate] = useState<dayjs.Dayjs | null>(null);
  const [meetingType, setMeetingType] = useState<'online' | 'offline' | 'phone'>('online');
  const [estimatedCost, setEstimatedCost] = useState(0);
  const [availableTranslators, setAvailableTranslators] = useState<any[]>([]);

  const languages = [
    { code: 'zh-CN', name: '中文' },
    { code: 'en-US', name: '英语' },
    { code: 'ja-JP', name: '日语' },
    { code: 'ko-KR', name: '韩语' },
    { code: 'fr-FR', name: '法语' },
    { code: 'de-DE', name: '德语' },
    { code: 'es-ES', name: '西班牙语' },
    { code: 'ru-RU', name: '俄语' },
  ];

  const translators = [
    {
      id: 'translator_1',
      name: '李翻译',
      avatar: '👨‍💼',
      specialization: '商务翻译',
      languages: ['zh-CN', 'en-US'],
      rating: 4.9,
      hourlyRate: 200,
      available: true,
    },
    {
      id: 'translator_2',
      name: '王翻译',
      avatar: '👩‍💼',
      specialization: '法律翻译',
      languages: ['zh-CN', 'ja-JP'],
      rating: 4.8,
      hourlyRate: 250,
      available: true,
    },
    {
      id: 'translator_3',
      name: '张翻译',
      avatar: '👨‍🎓',
      specialization: '技术翻译',
      languages: ['zh-CN', 'en-US', 'ko-KR'],
      rating: 4.7,
      hourlyRate: 180,
      available: false,
    },
  ];

  // 计算预估费用
  const calculateCost = (
    type: string,
    duration: number,
    translatorId?: string,
    urgency: string = 'normal'
  ) => {
    const baseRates = {
      interpretation: 200,
      consultation: 150,
      document_review: 100,
    };

    let rate = baseRates[type as keyof typeof baseRates] || 150;
    
    if (translatorId) {
      const translator = translators.find(t => t.id === translatorId);
      if (translator) {
        rate = translator.hourlyRate;
      }
    }

    const urgencyMultiplier = urgency === 'urgent' ? 1.5 : 1.0;
    return rate * duration * urgencyMultiplier;
  };

  const handleFormChange = () => {
    const values = form.getFieldsValue();
    if (values.type && values.timeRange && values.timeRange.length === 2) {
      const duration = values.timeRange[1].diff(values.timeRange[0], 'hour', true);
      const cost = calculateCost(values.type, duration, values.translatorId, values.urgency);
      setEstimatedCost(cost);
    }
  };

  const handleDateChange = (date: dayjs.Dayjs | null) => {
    setSelectedDate(date);
    if (date) {
      // 模拟查询可用译员
      const available = translators.filter(t => t.available);
      setAvailableTranslators(available);
    }
  };

  const disabledDate = (current: dayjs.Dayjs) => {
    // 禁用过去的日期
    return current && current < dayjs().startOf('day');
  };

  const disabledTime = () => {
    const now = dayjs();
    const isToday = selectedDate && selectedDate.isSame(now, 'day');
    
    if (isToday) {
      return {
        disabledHours: () => {
          const hours = [];
          for (let i = 0; i < now.hour(); i++) {
            hours.push(i);
          }
          return hours;
        },
        disabledMinutes: (selectedHour: number) => {
          if (selectedHour === now.hour()) {
            const minutes = [];
            for (let i = 0; i <= now.minute(); i++) {
              minutes.push(i);
            }
            return minutes;
          }
          return [];
        },
      };
    }
    return {};
  };

  const handleSubmit = async (values: AppointmentFormData) => {
    try {
      setLoading(true);

      const startTime = values.date
        .hour(values.timeRange[0].hour())
        .minute(values.timeRange[0].minute());
      const endTime = values.date
        .hour(values.timeRange[1].hour())
        .minute(values.timeRange[1].minute());

      const appointmentData = {
        ...values,
        startTime: startTime.toISOString(),
        endTime: endTime.toISOString(),
        cost: estimatedCost,
        status: 'pending',
        meetingUrl: meetingType === 'online' ? `https://meet.example.com/${Date.now()}` : undefined,
      };

      // 模拟API调用
      await new Promise(resolve => setTimeout(resolve, 1500));

      message.success('预约创建成功！');
      form.resetFields();
      setEstimatedCost(0);
      setSelectedDate(null);
      setAvailableTranslators([]);
      onSuccess();
    } catch (error) {
      console.error('创建预约失败:', error);
      message.error('创建预约失败，请重试');
    } finally {
      setLoading(false);
    }
  };

  const handleCancel = () => {
    form.resetFields();
    setEstimatedCost(0);
    setSelectedDate(null);
    setAvailableTranslators([]);
    setMeetingType('online');
    onCancel();
  };

  const getTypeIcon = (type: string) => {
    switch (type) {
      case 'interpretation':
        return '🗣️';
      case 'consultation':
        return '💬';
      case 'document_review':
        return '📋';
      default:
        return '📅';
    }
  };

  const getMeetingTypeIcon = (type: string) => {
    switch (type) {
      case 'online':
        return <VideoCameraOutlined />;
      case 'phone':
        return <PhoneOutlined />;
      case 'offline':
        return <UserOutlined />;
      default:
        return <VideoCameraOutlined />;
    }
  };

  return (
    <Modal
      title={
        <Space>
          <CalendarOutlined />
          新建预约
        </Space>
      }
      visible={visible}
      onCancel={handleCancel}
      footer={null}
      width={700}
      destroyOnClose
    >
      <Form
        form={form}
        layout="vertical"
        onFinish={handleSubmit}
        onValuesChange={handleFormChange}
        initialValues={{
          type: 'interpretation',
          meetingType: 'online',
          urgency: 'normal',
        }}
      >
        {/* 基本信息 */}
        <Divider orientation="left">基本信息</Divider>

        <Form.Item
          name="title"
          label="预约标题"
          rules={[{ required: true, message: '请输入预约标题' }]}
        >
          <Input
            placeholder="请输入预约标题，如：商务会议翻译"
            prefix={<CalendarOutlined />}
          />
        </Form.Item>

        <Form.Item
          name="description"
          label="预约描述"
        >
          <Input.TextArea
            rows={3}
            placeholder="请详细描述预约内容、会议主题、参与人员等..."
          />
        </Form.Item>

        <Form.Item
          name="type"
          label="服务类型"
          rules={[{ required: true, message: '请选择服务类型' }]}
        >
          <Radio.Group buttonStyle="solid">
            <Radio.Button value="interpretation">
              🗣️ 口译服务 - 会议、谈判翻译
            </Radio.Button>
            <Radio.Button value="consultation">
              💬 翻译咨询 - 专业咨询服务
            </Radio.Button>
            <Radio.Button value="document_review">
              📋 文档审核 - 翻译质量检查
            </Radio.Button>
          </Radio.Group>
        </Form.Item>

        {/* 语言配置 */}
        <Divider orientation="left">语言配置</Divider>

        <div style={{ display: 'flex', gap: '16px' }}>
          <Form.Item
            name="sourceLanguage"
            label="源语言"
            style={{ flex: 1 }}
            rules={[{ required: true, message: '请选择源语言' }]}
          >
            <Select placeholder="选择源语言">
              {languages.map(lang => (
                <Option key={lang.code} value={lang.code}>
                  {lang.name}
                </Option>
              ))}
            </Select>
          </Form.Item>

          <Form.Item
            name="targetLanguage"
            label="目标语言"
            style={{ flex: 1 }}
            rules={[{ required: true, message: '请选择目标语言' }]}
          >
            <Select placeholder="选择目标语言">
              {languages.map(lang => (
                <Option key={lang.code} value={lang.code}>
                  {lang.name}
                </Option>
              ))}
            </Select>
          </Form.Item>
        </div>

        {/* 时间安排 */}
        <Divider orientation="left">时间安排</Divider>

        <div style={{ display: 'flex', gap: '16px' }}>
          <Form.Item
            name="date"
            label="预约日期"
            style={{ flex: 1 }}
            rules={[{ required: true, message: '请选择预约日期' }]}
          >
            <DatePicker
              style={{ width: '100%' }}
              placeholder="选择日期"
              disabledDate={disabledDate}
              onChange={handleDateChange}
            />
          </Form.Item>

          <Form.Item
            name="timeRange"
            label="时间段"
            style={{ flex: 1 }}
            rules={[{ required: true, message: '请选择时间段' }]}
          >
            <RangePicker
              style={{ width: '100%' }}
              placeholder={['开始时间', '结束时间']}
              format="HH:mm"
              minuteStep={15}
              disabledTime={disabledTime}
            />
          </Form.Item>
        </div>

        {/* 会议方式 */}
        <Form.Item
          name="meetingType"
          label="会议方式"
          rules={[{ required: true, message: '请选择会议方式' }]}
        >
          <Radio.Group
            buttonStyle="solid"
            onChange={(e) => setMeetingType(e.target.value)}
          >
            <Radio.Button value="online">
              <Space>
                <VideoCameraOutlined />
                线上会议
              </Space>
            </Radio.Button>
            <Radio.Button value="phone">
              <Space>
                <PhoneOutlined />
                电话会议
              </Space>
            </Radio.Button>
            <Radio.Button value="offline">
              <Space>
                <UserOutlined />
                线下会议
              </Space>
            </Radio.Button>
          </Radio.Group>
        </Form.Item>

        {meetingType === 'offline' && (
          <Form.Item
            name="location"
            label="会议地点"
            rules={[{ required: true, message: '请输入会议地点' }]}
          >
            <Input placeholder="请输入详细的会议地点" />
          </Form.Item>
        )}

        {/* 译员选择 */}
        <Divider orientation="left">译员选择</Divider>

        {selectedDate && (
          <Alert
            message="可用译员"
            description={`${selectedDate.format('YYYY年MM月DD日')} 共有 ${availableTranslators.length} 位译员可用`}
            type="info"
            style={{ marginBottom: 16 }}
          />
        )}

        <Form.Item
          name="translatorId"
          label="指定译员"
        >
          <Select placeholder="选择译员（可选，系统会自动分配）" allowClear>
            {availableTranslators.map(translator => (
              <Option key={translator.id} value={translator.id}>
                <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
                  <Space>
                    <span style={{ fontSize: '16px' }}>{translator.avatar}</span>
                    <div>
                      <div>{translator.name}</div>
                      <div style={{ fontSize: '12px', color: '#666' }}>
                        {translator.specialization} • ⭐ {translator.rating}
                      </div>
                    </div>
                  </Space>
                  <Tag color="blue">¥{translator.hourlyRate}/小时</Tag>
                </div>
              </Option>
            ))}
          </Select>
        </Form.Item>

        <Form.Item
          name="urgency"
          label="紧急程度"
        >
          <Radio.Group>
            <Radio value="normal">普通预约</Radio>
            <Radio value="urgent">紧急预约 (+50% 费用)</Radio>
          </Radio.Group>
        </Form.Item>

        <Form.Item
          name="notes"
          label="特殊要求"
        >
          <Input.TextArea
            rows={3}
            placeholder="请输入特殊要求或备注信息，如专业领域、术语要求等..."
          />
        </Form.Item>

        {/* 费用预估 */}
        {estimatedCost > 0 && (
          <div style={{
            background: '#f6f6f6',
            padding: '16px',
            borderRadius: '6px',
            marginBottom: '16px'
          }}>
            <Space>
              <DollarOutlined style={{ color: '#1890ff' }} />
              <span><strong>预估费用：</strong></span>
              <span style={{ fontSize: '18px', color: '#1890ff', fontWeight: 'bold' }}>
                ¥{estimatedCost.toFixed(2)}
              </span>
            </Space>
            <div style={{ fontSize: '12px', color: '#666', marginTop: '4px' }}>
              * 实际费用可能因服务复杂度而有所调整
            </div>
          </div>
        )}

        <Form.Item style={{ marginBottom: 0, textAlign: 'right' }}>
          <Space>
            <Button onClick={handleCancel}>
              取消
            </Button>
            <Button type="primary" htmlType="submit" loading={loading}>
              创建预约
            </Button>
          </Space>
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default NewAppointmentModal; 