import * as React from 'react';
import { useState } from 'react';
import {
  Modal,
  Form,
  Input,
  Select,
  Button,
  Space,
  message,
  Upload,
  Progress,
  Radio,
  Divider,
  Card,
  Tag,
} from 'antd';
import {
  FileTextOutlined,
  UploadOutlined,
  TranslationOutlined,
  DollarOutlined,
  ClockCircleOutlined,
  DeleteOutlined,
  EyeOutlined,
} from '@ant-design/icons';
import type { UploadFile, UploadProps } from 'antd/es/upload/interface';
import { api } from '@/utils/api';

const { Option } = Select;
const { Dragger } = Upload;

interface NewDocumentModalProps {
  visible: boolean;
  onCancel: () => void;
  onSuccess: () => void;
}

interface DocumentFormData {
  sourceLanguage: string;
  targetLanguage: string;
  quality: 'draft' | 'professional' | 'certified';
  urgency: 'normal' | 'urgent' | 'express';
  notes?: string;
  files: UploadFile[];
}

const NewDocumentModal: React.FC<NewDocumentModalProps> = ({
  visible,
  onCancel,
  onSuccess,
}) => {
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [fileList, setFileList] = useState<UploadFile[]>([]);
  const [uploading, setUploading] = useState(false);
  const [estimatedCost, setEstimatedCost] = useState(0);
  const [estimatedTime, setEstimatedTime] = useState(0);

  const languages = [
    { code: 'zh-CN', name: '中文' },
    { code: 'en-US', name: '英语' },
    { code: 'ja-JP', name: '日语' },
    { code: 'ko-KR', name: '韩语' },
    { code: 'fr-FR', name: '法语' },
    { code: 'de-DE', name: '德语' },
    { code: 'es-ES', name: '西班牙语' },
    { code: 'ru-RU', name: '俄语' },
  ];

  // 计算预估费用和时间
  const calculateEstimates = (files: UploadFile[], quality: string, urgency: string) => {
    let totalSize = 0;
    let totalPages = 0;

    files.forEach(file => {
      if (file.size) {
        totalSize += file.size;
        // 估算页数（假设每页约50KB）
        totalPages += Math.ceil(file.size / (50 * 1024));
      }
    });

    // 计算费用（每页基础价格）
    const baseRates = {
      draft: 2.0,
      professional: 5.0,
      certified: 10.0,
    };

    const urgencyMultipliers = {
      normal: 1.0,
      urgent: 1.5,
      express: 2.0,
    };

    const baseRate = baseRates[quality as keyof typeof baseRates] || 5.0;
    const urgencyMultiplier = urgencyMultipliers[urgency as keyof typeof urgencyMultipliers] || 1.0;
    const cost = totalPages * baseRate * urgencyMultiplier;

    // 计算时间（小时）
    const baseTimePerPage = quality === 'certified' ? 2 : quality === 'professional' ? 1 : 0.5;
    const time = totalPages * baseTimePerPage / (urgency === 'express' ? 2 : urgency === 'urgent' ? 1.5 : 1);

    return { cost, time: Math.max(1, time) };
  };

  const handleFormChange = () => {
    const values = form.getFieldsValue();
    if (fileList.length > 0 && values.quality && values.urgency) {
      const { cost, time } = calculateEstimates(fileList, values.quality, values.urgency);
      setEstimatedCost(cost);
      setEstimatedTime(time);
    }
  };

  const uploadProps: UploadProps = {
    name: 'file',
    multiple: true,
    fileList,
    beforeUpload: (file) => {
      const isValidType = [
        'application/pdf',
        'application/msword',
        'application/vnd.openxmlformats-officedocument.wordprocessingml.document',
        'text/plain',
        'application/vnd.ms-powerpoint',
        'application/vnd.openxmlformats-officedocument.presentationml.presentation',
      ].includes(file.type);

      if (!isValidType) {
        message.error('只支持 PDF、Word、PowerPoint 和文本文件！');
        return false;
      }

      const isLt10M = file.size! / 1024 / 1024 < 10;
      if (!isLt10M) {
        message.error('文件大小不能超过 10MB！');
        return false;
      }

      return false; // 阻止自动上传
    },
    onChange: (info) => {
      setFileList(info.fileList);
      // 重新计算费用
      setTimeout(handleFormChange, 100);
    },
    onRemove: (file) => {
      const newFileList = fileList.filter(item => item.uid !== file.uid);
      setFileList(newFileList);
      return true;
    },
  };

  const getFileIcon = (fileName: string) => {
    const ext = fileName.split('.').pop()?.toLowerCase();
    switch (ext) {
      case 'pdf':
        return '📄';
      case 'doc':
      case 'docx':
        return '📝';
      case 'ppt':
      case 'pptx':
        return '📊';
      case 'txt':
        return '📃';
      default:
        return '📄';
    }
  };

  const handleSubmit = async (values: DocumentFormData) => {
    if (fileList.length === 0) {
      message.error('请至少上传一个文件！');
      return;
    }

    try {
      setLoading(true);
      setUploading(true);

      // 上传文件
      const uploadPromises = fileList.map(async (file) => {
        if (file.originFileObj) {
          const uploadResult = await api.uploadFile(file.originFileObj, 'document');
          return uploadResult;
        }
        return null;
      });

      const uploadResults = await Promise.all(uploadPromises);
      
      // 创建翻译任务
      for (const result of uploadResults) {
        if (result?.success && result.data) {
          await api.translateDocument({
            fileUrl: result.data.fileUrl,
            fileName: result.data.fileName,
            sourceLanguage: values.sourceLanguage,
            targetLanguage: values.targetLanguage,
            quality: values.quality,
          });
        }
      }

      message.success('文档翻译任务创建成功！');
      form.resetFields();
      setFileList([]);
      setEstimatedCost(0);
      setEstimatedTime(0);
      onSuccess();
    } catch (error) {
      console.error('创建翻译任务失败:', error);
      message.error('创建翻译任务失败，请重试');
    } finally {
      setLoading(false);
      setUploading(false);
    }
  };

  const handleCancel = () => {
    form.resetFields();
    setFileList([]);
    setEstimatedCost(0);
    setEstimatedTime(0);
    onCancel();
  };

  const formatFileSize = (size: number) => {
    if (size < 1024) return `${size} B`;
    if (size < 1024 * 1024) return `${(size / 1024).toFixed(1)} KB`;
    return `${(size / (1024 * 1024)).toFixed(1)} MB`;
  };

  return (
    <Modal
      title={
        <Space>
          <FileTextOutlined />
          新建文档翻译
        </Space>
      }
      visible={visible}
      onCancel={handleCancel}
      footer={null}
      width={700}
      destroyOnClose
    >
      <Form
        form={form}
        layout="vertical"
        onFinish={handleSubmit}
        onValuesChange={handleFormChange}
        initialValues={{
          quality: 'professional',
          urgency: 'normal',
        }}
      >
        {/* 文件上传 */}
        <Divider orientation="left">文件上传</Divider>
        
        <Form.Item
          label="选择文件"
          required
        >
          <Dragger {...uploadProps}>
            <p className="ant-upload-drag-icon">
              <UploadOutlined style={{ fontSize: 48, color: '#1890ff' }} />
            </p>
            <p className="ant-upload-text">点击或拖拽文件到此区域上传</p>
            <p className="ant-upload-hint">
              支持 PDF、Word、PowerPoint、文本文件，单个文件不超过 10MB
            </p>
          </Dragger>
        </Form.Item>

        {/* 文件列表 */}
        {fileList.length > 0 && (
          <div style={{ marginBottom: 16 }}>
            <h4>已选择文件：</h4>
            {fileList.map(file => (
              <Card
                key={file.uid}
                size="small"
                style={{ marginBottom: 8 }}
                bodyStyle={{ padding: '8px 12px' }}
              >
                <div style={{ display: 'flex', justifyContent: 'space-between', alignItems: 'center' }}>
                  <Space>
                    <span style={{ fontSize: '16px' }}>{getFileIcon(file.name)}</span>
                    <span>{file.name}</span>
                    <Tag color="blue">{formatFileSize(file.size || 0)}</Tag>
                  </Space>
                  <Button
                    type="text"
                    size="small"
                    icon={<DeleteOutlined />}
                    onClick={() => {
                      const newFileList = fileList.filter(item => item.uid !== file.uid);
                      setFileList(newFileList);
                    }}
                  />
                </div>
              </Card>
            ))}
          </div>
        )}

        {/* 翻译配置 */}
        <Divider orientation="left">翻译配置</Divider>

        <div style={{ display: 'flex', gap: '16px' }}>
          <Form.Item
            name="sourceLanguage"
            label="源语言"
            style={{ flex: 1 }}
            rules={[{ required: true, message: '请选择源语言' }]}
          >
            <Select placeholder="选择源语言">
              {languages.map(lang => (
                <Option key={lang.code} value={lang.code}>
                  {lang.name}
                </Option>
              ))}
            </Select>
          </Form.Item>

          <Form.Item
            name="targetLanguage"
            label="目标语言"
            style={{ flex: 1 }}
            rules={[{ required: true, message: '请选择目标语言' }]}
          >
            <Select placeholder="选择目标语言">
              {languages.map(lang => (
                <Option key={lang.code} value={lang.code}>
                  {lang.name}
                </Option>
              ))}
            </Select>
          </Form.Item>
        </div>

        <Form.Item
          name="quality"
          label="翻译质量"
          rules={[{ required: true, message: '请选择翻译质量' }]}
        >
          <Radio.Group buttonStyle="solid">
            <Radio.Button value="draft">
              📝 草稿级 - 快速翻译，适合理解内容
            </Radio.Button>
            <Radio.Button value="professional">
              💼 专业级 - 商务标准，适合正式场合
            </Radio.Button>
            <Radio.Button value="certified">
              🏆 认证级 - 官方认证，适合法律文件
            </Radio.Button>
          </Radio.Group>
        </Form.Item>

        <Form.Item
          name="urgency"
          label="交付时间"
          rules={[{ required: true, message: '请选择交付时间' }]}
        >
          <Radio.Group buttonStyle="solid">
            <Radio.Button value="normal">
              🕐 标准 - 正常交付时间
            </Radio.Button>
            <Radio.Button value="urgent">
              ⚡ 加急 - 50% 加急费用
            </Radio.Button>
            <Radio.Button value="express">
              🚀 特急 - 100% 加急费用
            </Radio.Button>
          </Radio.Group>
        </Form.Item>

        <Form.Item
          name="notes"
          label="特殊要求"
        >
          <Input.TextArea
            rows={3}
            placeholder="请输入特殊要求或备注信息，如专业术语、格式要求等..."
          />
        </Form.Item>

        {/* 费用和时间预估 */}
        {estimatedCost > 0 && (
          <div style={{
            background: '#f6f6f6',
            padding: '16px',
            borderRadius: '6px',
            marginBottom: '16px'
          }}>
            <div style={{ display: 'flex', justifyContent: 'space-between', marginBottom: '8px' }}>
              <Space>
                <DollarOutlined style={{ color: '#1890ff' }} />
                <span><strong>预估费用：</strong></span>
                <span style={{ fontSize: '18px', color: '#1890ff', fontWeight: 'bold' }}>
                  ¥{estimatedCost.toFixed(2)}
                </span>
              </Space>
              <Space>
                <ClockCircleOutlined style={{ color: '#52c41a' }} />
                <span><strong>预估时间：</strong></span>
                <span style={{ fontSize: '16px', color: '#52c41a', fontWeight: 'bold' }}>
                  {estimatedTime.toFixed(1)} 小时
                </span>
              </Space>
            </div>
            <div style={{ fontSize: '12px', color: '#666' }}>
              * 实际费用和时间可能因文档复杂度而有所调整
            </div>
          </div>
        )}

        <Form.Item style={{ marginBottom: 0, textAlign: 'right' }}>
          <Space>
            <Button onClick={handleCancel}>
              取消
            </Button>
            <Button 
              type="primary" 
              htmlType="submit" 
              loading={loading}
              disabled={fileList.length === 0}
            >
              {uploading ? '上传中...' : '创建翻译任务'}
            </Button>
          </Space>
        </Form.Item>
      </Form>
    </Modal>
  );
};

export default NewDocumentModal; 