import { FC, ReactNode, useEffect, useState } from 'react';
import { Outlet } from 'react-router-dom';
import MobileNavigation from './MobileNavigation';

interface MobileLayoutProps {
  children?: ReactNode;
}

const MobileLayout: FC<MobileLayoutProps> = ({ children }) => {
  const [isMobile, setIsMobile] = useState(false);

  useEffect(() => {
    const checkMobile = () => {
      const userAgent = navigator.userAgent;
      const mobileKeywords = /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i;
      const isMobileDevice = mobileKeywords.test(userAgent);
      const isSmallScreen = window.innerWidth <= 768;
      setIsMobile(isMobileDevice || isSmallScreen);
    };

    checkMobile();
    window.addEventListener('resize', checkMobile);
    
    return () => window.removeEventListener('resize', checkMobile);
  }, []);

  const styles = {
    container: {
      display: 'flex',
      flexDirection: 'column' as const,
      height: '100vh',
      backgroundColor: '#f5f5f5',
      overflow: 'hidden',
    },
    content: {
      flex: 1,
      overflow: 'auto',
      paddingBottom: isMobile ? '80px' : '0',
      position: 'relative' as const,
    },
    mobileHeader: {
      backgroundColor: '#1890ff',
      color: 'white',
      padding: '12px 16px',
      textAlign: 'center' as const,
      fontSize: '18px',
      fontWeight: '600' as const,
      boxShadow: '0 2px 4px rgba(0, 0, 0, 0.1)',
    },
  };

  if (!isMobile) {
    // 如果不是移动设备，显示提示信息
    return (
      <div style={{
        display: 'flex',
        justifyContent: 'center',
        alignItems: 'center',
        height: '100vh',
        backgroundColor: '#f5f5f5',
        flexDirection: 'column',
        padding: '20px',
        textAlign: 'center',
      }}>
        <div style={{
          backgroundColor: 'white',
          padding: '40px',
          borderRadius: '12px',
          boxShadow: '0 4px 12px rgba(0, 0, 0, 0.1)',
          maxWidth: '400px',
        }}>
          <h2 style={{ color: '#1890ff', marginBottom: '16px' }}>📱 移动端应用</h2>
          <p style={{ color: '#666', marginBottom: '20px' }}>
            此应用专为移动设备设计。请在手机或平板电脑上访问，或调整浏览器窗口大小至移动设备尺寸。
          </p>
          <p style={{ color: '#999', fontSize: '14px' }}>
            您也可以使用浏览器的开发者工具切换到移动设备视图。
          </p>
        </div>
      </div>
    );
  }

  return (
    <div style={styles.container}>
      <div style={styles.mobileHeader}>
        Twilio 翻译应用
      </div>
      
      <div style={styles.content}>
        {children || <Outlet />}
      </div>
      
      <MobileNavigation />
    </div>
  );
};

export default MobileLayout; 