import React, { useState, useEffect, useRef } from 'react';
import { Button, Card, Input, Space, Typography, message, Row, Col, Badge, Divider } from 'antd';
import { 
  PhoneOutlined, 
  VideoCameraOutlined, 
  AudioOutlined, 
  AudioMutedOutlined,
  VideoCameraAddOutlined,
  StopOutlined,
  UserOutlined,
  HomeOutlined,
  WifiOutlined
} from '@ant-design/icons';
import { Room, RemoteParticipant, LocalParticipant } from 'twilio-video';
import { TwilioService, VideoCallOptions, ParticipantInfo } from '../services/twilioService';

const { Title, Text } = Typography;

const VideoCallTest: React.FC = () => {
  const [twilioService] = useState(() => new TwilioService());
  const [room, setRoom] = useState<Room | null>(null);
  const [participants, setParticipants] = useState<ParticipantInfo[]>([]);
  const [isConnecting, setIsConnecting] = useState(false);
  const [isConnected, setIsConnected] = useState(false);
  const [audioEnabled, setAudioEnabled] = useState(true);
  const [videoEnabled, setVideoEnabled] = useState(true);
  
  // 表单状态
  const [roomName, setRoomName] = useState('test-room');
  const [identity, setIdentity] = useState('user-' + Math.floor(Math.random() * 1000));
  
  // 视频引用
  const localVideoRef = useRef<HTMLVideoElement>(null);
  const remoteVideoRef = useRef<HTMLVideoElement>(null);

  // 连接到房间
  const connectToRoom = async () => {
    if (isConnecting || !roomName || !identity) {
      message.warning('请填写房间名称和用户身份');
      return;
    }

    setIsConnecting(true);
    try {
      const options: VideoCallOptions = {
        roomName,
        identity,
        audio: audioEnabled,
        video: videoEnabled,
      };

      console.log('连接参数:', options);
      const connectedRoom = await twilioService.connectToRoom(options);
      setRoom(connectedRoom);
      setIsConnected(true);
      
      setupRoomEventListeners(connectedRoom);
      
      message.success(`成功连接到房间: ${roomName}`);
    } catch (error: any) {
      console.error('连接失败:', error);
      message.error(`连接失败: ${error.message}`);
    } finally {
      setIsConnecting(false);
    }
  };

  // 设置房间事件监听器
  const setupRoomEventListeners = (room: Room) => {
    const updateParticipants = () => {
      const participantList = twilioService.getParticipants();
      setParticipants(participantList);
      console.log('参与者更新:', participantList);
    };

    // 参与者连接
    room.on('participantConnected', (participant: RemoteParticipant) => {
      console.log(`参与者加入: ${participant.identity}`);
      message.info(`${participant.identity} 加入了通话`);
      updateParticipants();
      
      // 监听远程视频轨道
      participant.on('trackSubscribed', (track) => {
        if (track.kind === 'video' && remoteVideoRef.current) {
          track.attach(remoteVideoRef.current);
        }
      });
    });

    // 参与者断开
    room.on('participantDisconnected', (participant: RemoteParticipant) => {
      console.log(`参与者离开: ${participant.identity}`);
      message.info(`${participant.identity} 离开了通话`);
      updateParticipants();
    });

    // 房间断开
    room.on('disconnected', () => {
      console.log('房间连接断开');
      setIsConnected(false);
      setRoom(null);
      setParticipants([]);
      message.info('已断开视频通话连接');
    });

    // 本地视频轨道
    const localParticipant = room.localParticipant;
    if (localParticipant && localVideoRef.current) {
      localParticipant.videoTracks.forEach((publication) => {
        if (publication.track) {
          publication.track.attach(localVideoRef.current!);
        }
      });
    }

    updateParticipants();
  };

  // 离开房间
  const leaveRoom = () => {
    if (room) {
      twilioService.disconnect();
      setIsConnected(false);
      setRoom(null);
      setParticipants([]);
      message.info('已离开视频通话');
    }
  };

  // 切换音频
  const toggleAudio = () => {
    const newAudioEnabled = twilioService.toggleAudio();
    setAudioEnabled(newAudioEnabled);
    message.info(newAudioEnabled ? '音频已开启' : '音频已关闭');
  };

  // 切换视频
  const toggleVideo = () => {
    const newVideoEnabled = twilioService.toggleVideo();
    setVideoEnabled(newVideoEnabled);
    message.info(newVideoEnabled ? '视频已开启' : '视频已关闭');
  };

  // 测试服务器连接
  const testServerConnection = async () => {
    try {
      const response = await fetch('http://localhost:3001/health');
      const data = await response.json();
      message.success('Token服务器连接正常');
      console.log('服务器状态:', data);
    } catch (error) {
      message.error('Token服务器连接失败，请确保服务器已启动');
      console.error('服务器连接错误:', error);
    }
  };

  useEffect(() => {
    // 组件挂载时测试服务器连接
    testServerConnection();
    
    return () => {
      // 组件卸载时清理连接
      if (room) {
        twilioService.disconnect();
      }
    };
  }, []);

  const styles = {
    container: {
      padding: '20px',
      maxWidth: '1200px',
      margin: '0 auto',
    },
    videoContainer: {
      display: 'flex',
      gap: '16px',
      marginBottom: '20px',
    },
    videoCard: {
      flex: 1,
      minHeight: '300px',
    },
    video: {
      width: '100%',
      height: '250px',
      backgroundColor: '#000',
      borderRadius: '8px',
    },
    controlPanel: {
      marginBottom: '20px',
    },
    participantList: {
      marginTop: '20px',
    },
    statusBadge: {
      marginBottom: '10px',
    }
  };

  return (
    <div style={styles.container}>
      <Title level={2}>🎥 Twilio 视频通话测试</Title>
      
      {/* 连接状态 */}
      <div style={styles.statusBadge}>
        <Badge 
          status={isConnected ? 'success' : 'default'} 
          text={isConnected ? '已连接' : '未连接'} 
        />
        <Button 
          size="small" 
          type="link" 
          icon={<WifiOutlined />}
          onClick={testServerConnection}
        >
          测试服务器
        </Button>
      </div>

      {/* 视频区域 */}
      <div style={styles.videoContainer}>
        <Card title="本地视频" style={styles.videoCard}>
          <video 
            ref={localVideoRef}
            style={styles.video}
            autoPlay
            muted
            playsInline
          />
        </Card>
        <Card title="远程视频" style={styles.videoCard}>
          <video 
            ref={remoteVideoRef}
            style={styles.video}
            autoPlay
            playsInline
          />
        </Card>
      </div>

      {/* 控制面板 */}
      <Card title="控制面板" style={styles.controlPanel}>
        <Row gutter={[16, 16]}>
          <Col span={12}>
            <Space direction="vertical" style={{ width: '100%' }}>
              <Input
                placeholder="房间名称"
                value={roomName}
                onChange={(e) => setRoomName(e.target.value)}
                prefix={<HomeOutlined />}
                disabled={isConnected}
              />
              <Input
                placeholder="用户身份"
                value={identity}
                onChange={(e) => setIdentity(e.target.value)}
                prefix={<UserOutlined />}
                disabled={isConnected}
              />
            </Space>
          </Col>
          <Col span={12}>
            <Space wrap>
              {!isConnected ? (
                <Button
                  type="primary"
                  icon={<VideoCameraAddOutlined />}
                  loading={isConnecting}
                  onClick={connectToRoom}
                  size="large"
                >
                  {isConnecting ? '连接中...' : '加入通话'}
                </Button>
              ) : (
                <>
                  <Button
                    danger
                    icon={<StopOutlined />}
                    onClick={leaveRoom}
                    size="large"
                  >
                    离开通话
                  </Button>
                  <Button
                    type={audioEnabled ? 'default' : 'primary'}
                    icon={audioEnabled ? <AudioOutlined /> : <AudioMutedOutlined />}
                    onClick={toggleAudio}
                  >
                    {audioEnabled ? '关闭音频' : '开启音频'}
                  </Button>
                  <Button
                    type={videoEnabled ? 'default' : 'primary'}
                    icon={<VideoCameraOutlined />}
                    onClick={toggleVideo}
                  >
                    {videoEnabled ? '关闭视频' : '开启视频'}
                  </Button>
                </>
              )}
            </Space>
          </Col>
        </Row>
      </Card>

      {/* 参与者列表 */}
      {participants.length > 0 && (
        <Card title="参与者列表" style={styles.participantList}>
          <Row gutter={[16, 8]}>
            {participants.map((participant) => (
              <Col span={8} key={participant.sid}>
                <Card size="small">
                  <Space>
                    <UserOutlined />
                    <div>
                      <Text strong>{participant.identity}</Text>
                      <br />
                      <Text type="secondary">
                        {participant.isLocal ? '本地' : '远程'} | 
                        音频: {participant.audioEnabled ? '开' : '关'} | 
                        视频: {participant.videoEnabled ? '开' : '关'}
                      </Text>
                    </div>
                  </Space>
                </Card>
              </Col>
            ))}
          </Row>
        </Card>
      )}

      <Divider />
      
      {/* 使用说明 */}
      <Card title="📋 使用说明" size="small">
        <Text>
          <strong>测试步骤：</strong><br />
          1. 确保Token服务器已启动（端口3001）<br />
          2. 填写房间名称和用户身份<br />
          3. 点击"加入通话"按钮<br />
          4. 在另一个浏览器标签页中使用相同房间名称测试多人通话<br />
          5. 使用音频/视频控制按钮测试功能
        </Text>
      </Card>
    </div>
  );
};

export default VideoCallTest; 