import * as React from 'react';
import { useState, useEffect } from 'react';
import { useParams, useNavigate } from 'react-router-dom';
import {
  Card,
  Descriptions,
  Button,
  Tag,
  Rate,
  Typography,
  Divider,
  Space,
  Modal,
  Input,
  message,
  Spin,
  Timeline,
  Tabs,
  Avatar,
  Progress,
} from 'antd';
import {
  ArrowLeftOutlined,
  PlayCircleOutlined,
  PauseCircleOutlined,
  DownloadOutlined,
  StarOutlined,
  PhoneOutlined,
  ClockCircleOutlined,
  DollarOutlined,
  UserOutlined,
  SoundOutlined,
  FileTextOutlined,
  TranslationOutlined,
} from '@ant-design/icons';
import { TranslationCall } from '@/types';
import { database } from '@/utils/database';
import { api } from '@/utils/api';

const { Title, Text, Paragraph } = Typography;
const { TextArea } = Input;
const { TabPane } = Tabs;

interface CallDetailProps {}

const CallDetail: React.FC<CallDetailProps> = () => {
  const { id } = useParams<{ id: string }>();
  const navigate = useNavigate();
  
  const [call, setCall] = useState<TranslationCall | null>(null);
  const [loading, setLoading] = useState(true);
  const [isPlaying, setIsPlaying] = useState(false);
  const [currentTime, setCurrentTime] = useState(0);
  const [duration, setDuration] = useState(0);
  const [ratingModalVisible, setRatingModalVisible] = useState(false);
  const [rating, setRating] = useState(0);
  const [feedback, setFeedback] = useState('');
  const [submittingRating, setSubmittingRating] = useState(false);

  // 模拟音频播放状态
  const [audioProgress, setAudioProgress] = useState(0);

  useEffect(() => {
    if (id) {
      loadCallDetails();
    }
  }, [id]);

  const loadCallDetails = async () => {
    try {
      setLoading(true);
      await database.connect();
      
      // 模拟获取通话详情
      const mockCall: TranslationCall = {
        id: id!,
        userId: 'user_1',
        callId: `CA${Date.now()}`,
        clientName: '张先生',
        clientPhone: '+86 138 0013 8000',
        type: 'human',
        status: 'completed',
        sourceLanguage: 'zh-CN',
        targetLanguage: 'en-US',
        startTime: '2024-01-15T10:30:00Z',
        endTime: '2024-01-15T10:45:00Z',
        duration: 900,
        cost: 45.00,
        rating: 5,
        feedback: '翻译非常专业，沟通顺畅，非常满意！',
        translatorId: 'translator_1',
        translatorName: '李翻译',
        translatorPhone: '+86 138 0013 8001',
        recordingUrl: '/recordings/call_123456.mp3',
        transcription: '用户: 您好，我想了解一下贵公司的产品服务。\n翻译: Hello, I would like to learn about your company\'s products and services.\n客户: Thank you for your interest. Let me introduce our main products...\n翻译: 感谢您的关注。让我为您介绍我们的主要产品...',
        translation: '这是一次关于产品咨询的商务通话，客户询问了公司的主要产品和服务，我们提供了详细的介绍和说明。',
      };

      setCall(mockCall);
      setDuration(mockCall.duration || 0);
      setRating(mockCall.rating || 0);
      setFeedback(mockCall.feedback || '');
    } catch (error) {
      console.error('加载通话详情失败:', error);
      message.error('加载通话详情失败');
    } finally {
      setLoading(false);
    }
  };

  const handlePlayPause = () => {
    setIsPlaying(!isPlaying);
    
    if (!isPlaying) {
      // 模拟音频播放
      const interval = setInterval(() => {
        setCurrentTime(prev => {
          const newTime = prev + 1;
          setAudioProgress((newTime / duration) * 100);
          
          if (newTime >= duration) {
            clearInterval(interval);
            setIsPlaying(false);
            setCurrentTime(0);
            setAudioProgress(0);
          }
          
          return newTime;
        });
      }, 1000);
    }
  };

  const handleDownloadRecording = async () => {
    if (!call?.recordingUrl) return;
    
    try {
      message.info('开始下载录音文件...');
      // 模拟下载
      await new Promise(resolve => setTimeout(resolve, 2000));
      message.success('录音文件下载完成');
    } catch (error) {
      message.error('下载录音文件失败');
    }
  };

  const handleSubmitRating = async () => {
    if (!call) return;
    
    try {
      setSubmittingRating(true);
      
      await database.updateUser(call.userId, {
        // 更新评分和反馈
      });
      
      setCall({
        ...call,
        rating,
        feedback,
      });
      
      setRatingModalVisible(false);
      message.success('评价提交成功');
    } catch (error) {
      message.error('提交评价失败');
    } finally {
      setSubmittingRating(false);
    }
  };

  const formatTime = (seconds: number) => {
    const mins = Math.floor(seconds / 60);
    const secs = seconds % 60;
    return `${mins.toString().padStart(2, '0')}:${secs.toString().padStart(2, '0')}`;
  };

  const getStatusColor = (status: string) => {
    const colors = {
      pending: 'orange',
      active: 'blue',
      completed: 'green',
      cancelled: 'red',
    };
    return colors[status as keyof typeof colors] || 'default';
  };

  const getStatusText = (status: string) => {
    const texts = {
      pending: '等待中',
      active: '通话中',
      completed: '已完成',
      cancelled: '已取消',
    };
    return texts[status as keyof typeof texts] || status;
  };

  const getTypeIcon = (type: string) => {
    const icons = {
      ai: '🤖',
      human: '👤',
      video: '📹',
      sign: '🤟',
    };
    return icons[type as keyof typeof icons] || '📞';
  };

  const getTypeText = (type: string) => {
    const texts = {
      ai: 'AI翻译',
      human: '人工翻译',
      video: '视频通话',
      sign: '手语翻译',
    };
    return texts[type as keyof typeof texts] || type;
  };

  if (loading) {
    return (
      <div style={{ textAlign: 'center', padding: '50px' }}>
        <Spin size="large" />
        <div style={{ marginTop: '16px' }}>加载通话详情...</div>
      </div>
    );
  }

  if (!call) {
    return (
      <div style={{ textAlign: 'center', padding: '50px' }}>
        <div>通话记录不存在</div>
        <Button type="primary" onClick={() => navigate('/calls')} style={{ marginTop: '16px' }}>
          返回通话列表
        </Button>
      </div>
    );
  }

  return (
    <div style={{ padding: '24px' }}>
      {/* 头部导航 */}
      <div style={{ marginBottom: '24px' }}>
        <Button
          icon={<ArrowLeftOutlined />}
          onClick={() => navigate('/calls')}
          style={{ marginRight: '16px' }}
        >
          返回
        </Button>
        <Title level={2} style={{ display: 'inline-block', margin: 0 }}>
          通话详情 #{call.id}
        </Title>
      </div>

      {/* 基本信息卡片 */}
      <Card title="基本信息" style={{ marginBottom: '24px' }}>
        <Descriptions column={2} bordered>
          <Descriptions.Item label="通话ID" span={1}>
            {call.callId}
          </Descriptions.Item>
          <Descriptions.Item label="状态" span={1}>
            <Tag color={getStatusColor(call.status)}>
              {getStatusText(call.status)}
            </Tag>
          </Descriptions.Item>
          <Descriptions.Item label="类型" span={1}>
            <Space>
              <span>{getTypeIcon(call.type)}</span>
              {getTypeText(call.type)}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="语言对" span={1}>
            <Tag color="blue">{call.sourceLanguage}</Tag>
            <span style={{ margin: '0 8px' }}>→</span>
            <Tag color="green">{call.targetLanguage}</Tag>
          </Descriptions.Item>
          <Descriptions.Item label="开始时间" span={1}>
            <Space>
              <ClockCircleOutlined />
              {new Date(call.startTime).toLocaleString()}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="结束时间" span={1}>
            <Space>
              <ClockCircleOutlined />
              {call.endTime ? new Date(call.endTime).toLocaleString() : '-'}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="通话时长" span={1}>
            <Space>
              <PhoneOutlined />
              {formatTime(call.duration || 0)}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="费用" span={1}>
            <Space>
              <DollarOutlined />
              <Text strong>¥{call.cost.toFixed(2)}</Text>
            </Space>
          </Descriptions.Item>
          {call.clientName && (
            <Descriptions.Item label="客户姓名" span={1}>
              <Space>
                <UserOutlined />
                {call.clientName}
              </Space>
            </Descriptions.Item>
          )}
          {call.clientPhone && (
            <Descriptions.Item label="客户电话" span={1}>
              <Space>
                <PhoneOutlined />
                {call.clientPhone}
              </Space>
            </Descriptions.Item>
          )}
          {call.translatorName && (
            <Descriptions.Item label="译员" span={1}>
              <Space>
                <Avatar size="small" icon={<UserOutlined />} />
                {call.translatorName}
              </Space>
            </Descriptions.Item>
          )}
          {call.translatorPhone && (
            <Descriptions.Item label="译员电话" span={1}>
              <Space>
                <PhoneOutlined />
                {call.translatorPhone}
              </Space>
            </Descriptions.Item>
          )}
        </Descriptions>
      </Card>

      {/* 录音播放器 */}
      {call.recordingUrl && (
        <Card 
          title={
            <Space>
              <SoundOutlined />
              录音播放
            </Space>
          }
          style={{ marginBottom: '24px' }}
        >
          <div style={{ textAlign: 'center', padding: '20px' }}>
            <div style={{ marginBottom: '20px' }}>
              <Button
                type="primary"
                size="large"
                icon={isPlaying ? <PauseCircleOutlined /> : <PlayCircleOutlined />}
                onClick={handlePlayPause}
                style={{ marginRight: '16px' }}
              >
                {isPlaying ? '暂停' : '播放'}
              </Button>
              <Button
                icon={<DownloadOutlined />}
                onClick={handleDownloadRecording}
              >
                下载录音
              </Button>
            </div>
            
            <div style={{ margin: '20px 0' }}>
              <Progress
                percent={audioProgress}
                showInfo={false}
                strokeColor="#1890ff"
              />
              <div style={{ display: 'flex', justifyContent: 'space-between', marginTop: '8px' }}>
                <Text type="secondary">{formatTime(currentTime)}</Text>
                <Text type="secondary">{formatTime(duration)}</Text>
              </div>
            </div>
          </div>
        </Card>
      )}

      {/* 详细内容标签页 */}
      <Card>
        <Tabs defaultActiveKey="transcription">
          <TabPane
            tab={
              <Space>
                <FileTextOutlined />
                转录内容
              </Space>
            }
            key="transcription"
          >
            <div style={{ minHeight: '200px' }}>
              {call.transcription ? (
                <Paragraph>
                  <pre style={{ whiteSpace: 'pre-wrap', fontFamily: 'inherit' }}>
                    {call.transcription}
                  </pre>
                </Paragraph>
              ) : (
                <div style={{ textAlign: 'center', color: '#999', padding: '50px' }}>
                  暂无转录内容
                </div>
              )}
            </div>
          </TabPane>
          
          <TabPane
            tab={
              <Space>
                <TranslationOutlined />
                翻译摘要
              </Space>
            }
            key="translation"
          >
            <div style={{ minHeight: '200px' }}>
              {call.translation ? (
                <Paragraph>{call.translation}</Paragraph>
              ) : (
                <div style={{ textAlign: 'center', color: '#999', padding: '50px' }}>
                  暂无翻译摘要
                </div>
              )}
            </div>
          </TabPane>
          
          <TabPane
            tab={
              <Space>
                <StarOutlined />
                评价反馈
              </Space>
            }
            key="rating"
          >
            <div style={{ minHeight: '200px', padding: '20px' }}>
              <div style={{ marginBottom: '20px' }}>
                <Text strong>服务评分：</Text>
                <Rate disabled value={call.rating} style={{ marginLeft: '8px' }} />
                {call.rating && (
                  <Text style={{ marginLeft: '8px' }}>
                    ({call.rating}/5 分)
                  </Text>
                )}
              </div>
              
              {call.feedback && (
                <div>
                  <Text strong>用户反馈：</Text>
                  <Paragraph style={{ marginTop: '8px' }}>
                    {call.feedback}
                  </Paragraph>
                </div>
              )}
              
              <div style={{ marginTop: '20px' }}>
                <Button
                  type="primary"
                  icon={<StarOutlined />}
                  onClick={() => setRatingModalVisible(true)}
                >
                  {call.rating ? '修改评价' : '添加评价'}
                </Button>
              </div>
            </div>
          </TabPane>
        </Tabs>
      </Card>

      {/* 评价弹窗 */}
      <Modal
        title="服务评价"
        visible={ratingModalVisible}
        onOk={handleSubmitRating}
        onCancel={() => setRatingModalVisible(false)}
        confirmLoading={submittingRating}
        okText="提交"
        cancelText="取消"
      >
        <div style={{ marginBottom: '16px' }}>
          <Text strong>服务评分：</Text>
          <Rate
            value={rating}
            onChange={setRating}
            style={{ marginLeft: '8px' }}
          />
        </div>
        
        <div>
          <Text strong>反馈意见：</Text>
          <TextArea
            value={feedback}
            onChange={(e: React.ChangeEvent<HTMLTextAreaElement>) => setFeedback(e.target.value)}
            placeholder="请分享您对本次翻译服务的意见和建议..."
            rows={4}
            style={{ marginTop: '8px' }}
          />
        </div>
      </Modal>
    </div>
  );
};

export default CallDetail; 