import * as React from 'react';
import { useState, useEffect } from 'react';
import { useParams, useNavigate } from 'react-router-dom';
import {
  Card,
  Descriptions,
  Button,
  Tag,
  Typography,
  Space,
  Modal,
  Input,
  message,
  Spin,
  Progress,
  Tabs,
  Upload,
  List,
  Image,
  Tooltip,
  Steps,
} from 'antd';
import {
  ArrowLeftOutlined,
  DownloadOutlined,
  FileTextOutlined,
  EyeOutlined,
  CloudDownloadOutlined,
  FilePdfOutlined,
  FileWordOutlined,
  FileExcelOutlined,
  FilePptOutlined,
  FileImageOutlined,
  ClockCircleOutlined,
  CheckCircleOutlined,
  ExclamationCircleOutlined,
  LoadingOutlined,
  TranslationOutlined,
  DollarOutlined,
  CalendarOutlined,
} from '@ant-design/icons';
import { DocumentTranslation } from '@/types';
import { database } from '@/utils/database';
import { api } from '@/utils/api';

const { Title, Text, Paragraph } = Typography;
const { TextArea } = Input;
const { TabPane } = Tabs;
const { Step } = Steps;

interface DocumentDetailProps {}

const DocumentDetail: React.FC<DocumentDetailProps> = () => {
  const { id } = useParams<{ id: string }>();
  const navigate = useNavigate();
  
  const [document, setDocument] = useState<DocumentTranslation | null>(null);
  const [loading, setLoading] = useState(true);
  const [downloadModalVisible, setDownloadModalVisible] = useState(false);
  const [previewModalVisible, setPreviewModalVisible] = useState(false);
  const [previewContent, setPreviewContent] = useState('');

  useEffect(() => {
    if (id) {
      loadDocumentDetails();
    }
  }, [id]);

  const loadDocumentDetails = async () => {
    try {
      setLoading(true);
      await database.connect();
      
      // 模拟获取文档详情
      const mockDocument: DocumentTranslation = {
        id: id!,
        userId: 'user_1',
        fileName: '商务合同.pdf',
        fileSize: 2048576,
        fileType: 'pdf',
        fileUrl: '/uploads/business_contract.pdf',
        sourceLanguage: 'zh-CN',
        targetLanguage: 'en-US',
        status: 'completed',
        progress: 100,
        createdAt: '2024-01-15T09:00:00Z',
        updatedAt: '2024-01-15T09:30:00Z',
        completedAt: '2024-01-15T09:30:00Z',
        cost: 25.50,
        translatedFileUrl: '/downloads/business_contract_en.pdf',
        wordCount: 1250,
        pageCount: 5,
        translatorId: 'translator_2',
        quality: 'professional',
      };

      setDocument(mockDocument);
    } catch (error) {
      console.error('加载文档详情失败:', error);
      message.error('加载文档详情失败');
    } finally {
      setLoading(false);
    }
  };

  const handleDownload = async (type: 'original' | 'translated') => {
    if (!document) return;
    
    try {
      message.info('开始下载文件...');
      
      // 模拟下载
      await new Promise(resolve => setTimeout(resolve, 2000));
      
      const fileName = type === 'original' 
        ? document.fileName 
        : document.translatedFileUrl?.split('/').pop() || 'translated_file';
      
      message.success(`${fileName} 下载完成`);
    } catch (error) {
      message.error('下载文件失败');
    }
  };

  const handlePreview = async () => {
    if (!document?.fileUrl) {
      message.warning('暂无预览内容');
      return;
    }
    
    try {
      setPreviewContent('文档预览内容加载中...');
      setPreviewModalVisible(true);
      
      // 模拟加载预览内容
      await new Promise(resolve => setTimeout(resolve, 1000));
      
      setPreviewContent(`
商务合同

甲方：ABC公司
乙方：XYZ企业

第一条 合作内容
双方就以下事项达成合作协议...

第二条 合作期限
本合同有效期自2024年1月1日至2024年12月31日...

第三条 费用条款
合作费用总计人民币50万元整...

[此处为预览内容，完整内容请下载查看]
      `);
    } catch (error) {
      message.error('加载预览失败');
    }
  };

  const getFileIcon = (fileType: string) => {
    const icons = {
      pdf: <FilePdfOutlined style={{ color: '#ff4d4f' }} />,
      doc: <FileWordOutlined style={{ color: '#1890ff' }} />,
      docx: <FileWordOutlined style={{ color: '#1890ff' }} />,
      xls: <FileExcelOutlined style={{ color: '#52c41a' }} />,
      xlsx: <FileExcelOutlined style={{ color: '#52c41a' }} />,
      ppt: <FilePptOutlined style={{ color: '#fa8c16' }} />,
      pptx: <FilePptOutlined style={{ color: '#fa8c16' }} />,
      jpg: <FileImageOutlined style={{ color: '#722ed1' }} />,
      jpeg: <FileImageOutlined style={{ color: '#722ed1' }} />,
      png: <FileImageOutlined style={{ color: '#722ed1' }} />,
    };
    return icons[fileType as keyof typeof icons] || <FileTextOutlined />;
  };

  const getStatusColor = (status: string) => {
    const colors = {
      pending: 'orange',
      processing: 'blue',
      completed: 'green',
      failed: 'red',
      cancelled: 'default',
    };
    return colors[status as keyof typeof colors] || 'default';
  };

  const getStatusText = (status: string) => {
    const texts = {
      pending: '等待处理',
      processing: '翻译中',
      completed: '已完成',
      failed: '翻译失败',
      cancelled: '已取消',
    };
    return texts[status as keyof typeof texts] || status;
  };

  const getStatusIcon = (status: string) => {
    const icons = {
      pending: <ClockCircleOutlined />,
      processing: <LoadingOutlined spin />,
      completed: <CheckCircleOutlined />,
      failed: <ExclamationCircleOutlined />,
      cancelled: <ExclamationCircleOutlined />,
    };
    return icons[status as keyof typeof icons] || <ClockCircleOutlined />;
  };

  const formatFileSize = (bytes: number) => {
    if (bytes === 0) return '0 B';
    const k = 1024;
    const sizes = ['B', 'KB', 'MB', 'GB'];
    const i = Math.floor(Math.log(bytes) / Math.log(k));
    return parseFloat((bytes / Math.pow(k, i)).toFixed(2)) + ' ' + sizes[i];
  };

  const getTranslationSteps = () => {
    if (!document) return [];
    
    const steps = [
      {
        title: '文件上传',
        status: 'finish',
        icon: <CheckCircleOutlined />,
        description: new Date(document.createdAt).toLocaleString(),
      },
      {
        title: '文档分析',
        status: document.status === 'pending' ? 'wait' : 'finish',
        icon: document.status === 'pending' ? <ClockCircleOutlined /> : <CheckCircleOutlined />,
        description: '分析文档结构和内容',
      },
      {
        title: '翻译处理',
        status: document.status === 'processing' ? 'process' : 
               document.status === 'completed' ? 'finish' : 'wait',
        icon: document.status === 'processing' ? <LoadingOutlined spin /> :
              document.status === 'completed' ? <CheckCircleOutlined /> : <ClockCircleOutlined />,
        description: document.translatorId ? `译员：${document.translatorId}` : '等待分配译员',
      },
      {
        title: '质量审核',
        status: document.status === 'completed' ? 'finish' : 'wait',
        icon: document.status === 'completed' ? <CheckCircleOutlined /> : <ClockCircleOutlined />,
        description: document.status === 'completed' ? '审核完成' : '等待审核',
      },
      {
        title: '完成交付',
        status: document.status === 'completed' ? 'finish' : 'wait',
        icon: document.status === 'completed' ? <CheckCircleOutlined /> : <ClockCircleOutlined />,
        description: document.completedAt ? new Date(document.completedAt).toLocaleString() : '等待完成',
      },
    ];
    
    return steps;
  };

  if (loading) {
    return (
      <div style={{ textAlign: 'center', padding: '50px' }}>
        <Spin size="large" />
        <div style={{ marginTop: '16px' }}>加载文档详情...</div>
      </div>
    );
  }

  if (!document) {
    return (
      <div style={{ textAlign: 'center', padding: '50px' }}>
        <div>文档记录不存在</div>
        <Button type="primary" onClick={() => navigate('/documents')} style={{ marginTop: '16px' }}>
          返回文档列表
        </Button>
      </div>
    );
  }

  return (
    <div style={{ padding: '24px' }}>
      {/* 头部导航 */}
      <div style={{ marginBottom: '24px' }}>
        <Button
          icon={<ArrowLeftOutlined />}
          onClick={() => navigate('/documents')}
          style={{ marginRight: '16px' }}
        >
          返回
        </Button>
        <Title level={2} style={{ display: 'inline-block', margin: 0 }}>
          文档详情 #{document.id}
        </Title>
      </div>

      {/* 基本信息卡片 */}
      <Card title="基本信息" style={{ marginBottom: '24px' }}>
        <Descriptions column={2} bordered>
          <Descriptions.Item label="文件名" span={1}>
            <Space>
              {getFileIcon(document.fileType)}
              {document.fileName}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="状态" span={1}>
            <Space>
              {getStatusIcon(document.status)}
              <Tag color={getStatusColor(document.status)}>
                {getStatusText(document.status)}
              </Tag>
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="文件大小" span={1}>
            {formatFileSize(document.fileSize)}
          </Descriptions.Item>
          <Descriptions.Item label="文件类型" span={1}>
            <Tag>{document.fileType.toUpperCase()}</Tag>
          </Descriptions.Item>
          <Descriptions.Item label="语言对" span={1}>
            <Tag color="blue">{document.sourceLanguage}</Tag>
            <span style={{ margin: '0 8px' }}>→</span>
            <Tag color="green">{document.targetLanguage}</Tag>
          </Descriptions.Item>
          <Descriptions.Item label="翻译类型" span={1}>
            <Tag color="purple">文档翻译</Tag>
          </Descriptions.Item>
          <Descriptions.Item label="上传时间" span={1}>
            <Space>
              <CalendarOutlined />
              {new Date(document.createdAt).toLocaleString()}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="完成时间" span={1}>
            <Space>
              <CalendarOutlined />
              {document.completedAt ? new Date(document.completedAt).toLocaleString() : '-'}
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="字数统计" span={1}>
            {document.wordCount ? `${document.wordCount.toLocaleString()} 字` : '-'}
          </Descriptions.Item>
          <Descriptions.Item label="页数" span={1}>
            {document.pageCount ? `${document.pageCount} 页` : '-'}
          </Descriptions.Item>
          <Descriptions.Item label="费用" span={1}>
            <Space>
              <DollarOutlined />
              <Text strong>¥{document.cost.toFixed(2)}</Text>
            </Space>
          </Descriptions.Item>
          <Descriptions.Item label="质量等级" span={1}>
            <Tag color="gold">{document.quality}</Tag>
          </Descriptions.Item>
        </Descriptions>
        
        <div style={{ marginTop: '16px' }}>
          <Text strong>备注说明：</Text>
          <Paragraph style={{ marginTop: '8px' }}>
            专业文档翻译，保持原有格式
          </Paragraph>
        </div>
      </Card>

      {/* 翻译进度 */}
      <Card title="翻译进度" style={{ marginBottom: '24px' }}>
        <div style={{ marginBottom: '20px' }}>
          <Progress
            percent={document.progress}
            status={document.status === 'failed' ? 'exception' : 'normal'}
            strokeColor={{
              '0%': '#108ee9',
              '100%': '#87d068',
            }}
          />
        </div>
        
        <Steps current={getTranslationSteps().findIndex(step => step.status === 'process')}>
          {getTranslationSteps().map((step, index) => (
            <Step
              key={index}
              title={step.title}
              description={step.description}
              status={step.status as any}
              icon={step.icon}
            />
          ))}
        </Steps>
      </Card>

      {/* 操作和预览 */}
      <Card title="文件操作">
        <Tabs defaultActiveKey="actions">
          <TabPane
            tab={
              <Space>
                <DownloadOutlined />
                下载文件
              </Space>
            }
            key="actions"
          >
            <div style={{ padding: '20px' }}>
              <Space direction="vertical" size="large" style={{ width: '100%' }}>
                <div>
                  <Title level={4}>原始文件</Title>
                  <Space>
                    <Button
                      type="primary"
                      icon={<DownloadOutlined />}
                      onClick={() => handleDownload('original')}
                    >
                      下载原文件
                    </Button>
                    <Button
                      icon={<EyeOutlined />}
                      onClick={handlePreview}
                    >
                      预览
                    </Button>
                  </Space>
                </div>
                
                {document.status === 'completed' && document.translatedFileUrl && (
                  <div>
                    <Title level={4}>翻译文件</Title>
                    <Space>
                      <Button
                        type="primary"
                        icon={<CloudDownloadOutlined />}
                        onClick={() => handleDownload('translated')}
                      >
                        下载译文
                      </Button>
                      <Button
                        icon={<EyeOutlined />}
                        onClick={() => message.info('译文预览功能开发中')}
                      >
                        预览译文
                      </Button>
                    </Space>
                  </div>
                )}
              </Space>
            </div>
          </TabPane>
          
          <TabPane
            tab={
              <Space>
                <TranslationOutlined />
                翻译详情
              </Space>
            }
            key="details"
          >
            <div style={{ padding: '20px' }}>
              <List
                itemLayout="horizontal"
                dataSource={[
                  {
                    title: '译员信息',
                    content: document.translatorId || '未分配',
                    icon: <TranslationOutlined />,
                  },
                  {
                    title: '审核员',
                    content: '系统审核',
                    icon: <CheckCircleOutlined />,
                  },
                  {
                    title: '紧急程度',
                    content: '普通',
                    icon: <ClockCircleOutlined />,
                  },
                  {
                    title: '质量要求',
                    content: document.quality === 'professional' ? '专业级' :
                             document.quality === 'certified' ? '认证级' : '草稿级',
                    icon: <CheckCircleOutlined />,
                  },
                ]}
                renderItem={(item) => (
                  <List.Item>
                    <List.Item.Meta
                      avatar={item.icon}
                      title={item.title}
                      description={item.content}
                    />
                  </List.Item>
                )}
              />
            </div>
          </TabPane>
        </Tabs>
      </Card>

      {/* 文件预览弹窗 */}
      <Modal
        title="文件预览"
        visible={previewModalVisible}
        onCancel={() => setPreviewModalVisible(false)}
        footer={[
          <Button key="close" onClick={() => setPreviewModalVisible(false)}>
            关闭
          </Button>,
          <Button
            key="download"
            type="primary"
            icon={<DownloadOutlined />}
            onClick={() => handleDownload('original')}
          >
            下载原文件
          </Button>,
        ]}
        width={800}
      >
        <div style={{ maxHeight: '500px', overflow: 'auto' }}>
          <pre style={{ whiteSpace: 'pre-wrap', fontFamily: 'inherit' }}>
            {previewContent}
          </pre>
        </div>
      </Modal>
    </div>
  );
};

export default DocumentDetail; 