import { FC, useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { AppointmentService } from '../../services/appointmentService';
import { BillingService } from '../../services/billingService';
import { 
  Appointment, 
  Interpreter, 
  CallType, 
  TranslationType,
  UserAccount 
} from '../../types/billing';

const MobileAppointment: FC = () => {
  const navigate = useNavigate();
  const appointmentService = AppointmentService.getInstance();
  const billingService = BillingService.getInstance();

  const [userAccount, setUserAccount] = useState<UserAccount | null>(null);
  const [selectedDate, setSelectedDate] = useState<string>('');
  const [selectedTime, setSelectedTime] = useState<string>('');
  const [callType, setCallType] = useState<CallType>(CallType.VOICE);
  const [translationType, setTranslationType] = useState<TranslationType>(TranslationType.TEXT);
  const [selectedLanguages, setSelectedLanguages] = useState({
    from: 'zh-CN',
    to: 'en-US',
  });
  const [selectedInterpreter, setSelectedInterpreter] = useState<Interpreter | null>(null);
  const [availableInterpreters, setAvailableInterpreters] = useState<Interpreter[]>([]);
  const [description, setDescription] = useState('');
  const [estimatedCost, setEstimatedCost] = useState(0);
  const [isSubmitting, setIsSubmitting] = useState(false);

  const languages = [
    { code: 'zh-CN', name: '中文', flag: '🇨🇳' },
    { code: 'en-US', name: 'English', flag: '🇺🇸' },
    { code: 'ja-JP', name: '日本語', flag: '🇯🇵' },
    { code: 'ko-KR', name: '한국어', flag: '🇰🇷' },
    { code: 'es-ES', name: 'Español', flag: '🇪🇸' },
    { code: 'fr-FR', name: 'Français', flag: '🇫🇷' },
    { code: 'de-DE', name: 'Deutsch', flag: '🇩🇪' },
  ];

  // 生成可选时间段
  const timeSlots = [
    '09:00', '09:30', '10:00', '10:30', '11:00', '11:30',
    '14:00', '14:30', '15:00', '15:30', '16:00', '16:30',
    '17:00', '17:30', '18:00', '18:30', '19:00', '19:30',
    '20:00', '20:30', '21:00'
  ];

  // 生成未来7天的日期选项
  const getDateOptions = () => {
    const dates = [];
    for (let i = 0; i < 7; i++) {
      const date = new Date();
      date.setDate(date.getDate() + i);
      dates.push({
        value: date.toISOString().split('T')[0],
        label: i === 0 ? '今天' : i === 1 ? '明天' : 
               `${date.getMonth() + 1}月${date.getDate()}日`,
        weekday: date.toLocaleDateString('zh-CN', { weekday: 'short' })
      });
    }
    return dates;
  };

  useEffect(() => {
    const account = billingService.getUserAccount();
    setUserAccount(account);
  }, []);

  useEffect(() => {
    if (selectedDate) {
      const date = new Date(selectedDate);
      const interpreters = appointmentService.getAvailableInterpreters(
        date,
        [selectedLanguages.from, selectedLanguages.to]
      );
      setAvailableInterpreters(interpreters);
    }
  }, [selectedDate, selectedLanguages]);

  useEffect(() => {
    // 计算预估费用
    if (callType && translationType && userAccount) {
      const interpreterRate = selectedInterpreter?.pricePerMinute;
      const baseCost = billingService.calculateCallCost(
        callType,
        translationType,
        30, // 假设30分钟
        interpreterRate
      );
      setEstimatedCost(baseCost);
    }
  }, [callType, translationType, selectedInterpreter, userAccount]);

  useEffect(() => {
    // 根据通话类型设置默认翻译类型
    if (callType === CallType.VIDEO) {
      setTranslationType(TranslationType.SIGN_LANGUAGE);
    } else {
      setTranslationType(TranslationType.TEXT);
    }
  }, [callType]);

  const formatCurrency = (cents: number) => {
    return (cents / 100).toFixed(2);
  };

  const handleSubmit = async () => {
    if (!selectedDate || !selectedTime || !callType || !translationType) {
      alert('请完善预约信息');
      return;
    }

    if (!userAccount || userAccount.balance < estimatedCost) {
      alert('账户余额不足，请先充值');
      navigate('/mobile/recharge');
      return;
    }

    setIsSubmitting(true);

    try {
      // 构建预约数据
      const appointmentData = {
        userId: 'user_1', // 实际应该从用户状态获取
        title: `${callType === CallType.VOICE ? '语音' : '视频'}通话预约`,
        description: `${translationType === TranslationType.TEXT ? '文本翻译' : 
                     translationType === TranslationType.SIGN_LANGUAGE ? '手语翻译' : '人工翻译'}`,
        scheduledTime: new Date(`${selectedDate}T${selectedTime}`),
        duration: 60, // 默认60分钟
        callType,
        translationType,
        interpreterIds: selectedInterpreter ? [selectedInterpreter.id] : undefined,
        estimatedCost,
        status: 'scheduled' as const,
      };

      // 创建预约
      const appointment = appointmentService.createAppointment(appointmentData);
      
      alert('预约创建成功！');
      navigate('/mobile/home');
    } catch (error) {
      console.error('创建预约失败:', error);
      alert('创建预约失败，请重试');
    } finally {
      setIsSubmitting(false);
    }
  };

  const styles = {
    container: {
      padding: '16px',
      backgroundColor: '#f5f5f5',
      minHeight: '100vh',
    },
    header: {
      display: 'flex',
      alignItems: 'center',
      marginBottom: '20px',
    },
    backButton: {
      background: 'none',
      border: 'none',
      fontSize: '24px',
      cursor: 'pointer',
      marginRight: '12px',
    },
    title: {
      fontSize: '20px',
      fontWeight: '600' as const,
      color: '#333',
    },
    section: {
      backgroundColor: 'white',
      borderRadius: '16px',
      padding: '20px',
      marginBottom: '20px',
      boxShadow: '0 2px 12px rgba(0, 0, 0, 0.1)',
    },
    sectionTitle: {
      fontSize: '18px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '16px',
    },
    callTypeSelector: {
      display: 'flex',
      gap: '12px',
      marginBottom: '16px',
    },
    callTypeButton: (active: boolean) => ({
      flex: 1,
      padding: '16px',
      borderRadius: '12px',
      border: active ? '2px solid #1890ff' : '2px solid #f0f0f0',
      backgroundColor: active ? '#e6f7ff' : 'white',
      color: active ? '#1890ff' : '#666',
      fontSize: '16px',
      fontWeight: '500' as const,
      cursor: 'pointer',
      textAlign: 'center' as const,
    }),
    dateGrid: {
      display: 'grid',
      gridTemplateColumns: 'repeat(2, 1fr)',
      gap: '12px',
      marginBottom: '16px',
    },
    dateOption: (selected: boolean) => ({
      padding: '16px',
      borderRadius: '12px',
      border: selected ? '2px solid #1890ff' : '2px solid #f0f0f0',
      backgroundColor: selected ? '#e6f7ff' : 'white',
      cursor: 'pointer',
      textAlign: 'center' as const,
    }),
    dateLabel: {
      fontSize: '16px',
      fontWeight: '500' as const,
      color: '#333',
      marginBottom: '4px',
    },
    dateWeekday: {
      fontSize: '12px',
      color: '#999',
    },
    timeGrid: {
      display: 'grid',
      gridTemplateColumns: 'repeat(3, 1fr)',
      gap: '8px',
    },
    timeSlot: (selected: boolean, available: boolean) => ({
      padding: '12px 8px',
      borderRadius: '8px',
      border: selected ? '2px solid #1890ff' : '1px solid #d9d9d9',
      backgroundColor: selected ? '#e6f7ff' : available ? 'white' : '#f5f5f5',
      color: selected ? '#1890ff' : available ? '#333' : '#999',
      fontSize: '14px',
      textAlign: 'center' as const,
      cursor: available ? 'pointer' : 'not-allowed',
    }),
    languageRow: {
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'space-between',
      marginBottom: '16px',
    },
    languageSelect: {
      flex: 1,
      padding: '12px',
      borderRadius: '8px',
      border: '1px solid #d9d9d9',
      backgroundColor: 'white',
      fontSize: '14px',
    },
    swapButton: {
      margin: '0 12px',
      padding: '8px',
      borderRadius: '20px',
      border: 'none',
      backgroundColor: '#f0f8ff',
      cursor: 'pointer',
      fontSize: '16px',
    },
    translationTypeSelector: {
      display: 'flex',
      flexDirection: 'column' as const,
      gap: '12px',
      marginBottom: '16px',
    },
    translationTypeButton: (active: boolean) => ({
      padding: '16px',
      borderRadius: '12px',
      border: active ? '2px solid #1890ff' : '1px solid #d9d9d9',
      backgroundColor: active ? '#e6f7ff' : 'white',
      color: active ? '#1890ff' : '#666',
      fontSize: '14px',
      cursor: 'pointer',
      textAlign: 'left' as const,
    }),
    interpreterList: {
      marginTop: '16px',
    },
    interpreterItem: (selected: boolean) => ({
      display: 'flex',
      alignItems: 'center',
      padding: '16px',
      borderRadius: '12px',
      border: selected ? '2px solid #1890ff' : '1px solid #d9d9d9',
      backgroundColor: selected ? '#e6f7ff' : 'white',
      marginBottom: '12px',
      cursor: 'pointer',
    }),
    interpreterAvatar: {
      fontSize: '32px',
      marginRight: '16px',
    },
    interpreterInfo: {
      flex: 1,
    },
    interpreterName: {
      fontSize: '16px',
      fontWeight: '500' as const,
      color: '#333',
      marginBottom: '4px',
    },
    interpreterDetails: {
      fontSize: '12px',
      color: '#666',
      marginBottom: '4px',
    },
    interpreterRate: {
      fontSize: '14px',
      fontWeight: '500' as const,
      color: '#fa8c16',
    },
    descriptionInput: {
      width: '100%',
      minHeight: '80px',
      padding: '12px',
      borderRadius: '8px',
      border: '1px solid #d9d9d9',
      fontSize: '14px',
      resize: 'vertical' as const,
    },
    costSummary: {
      backgroundColor: '#f8f9fa',
      borderRadius: '12px',
      padding: '16px',
      marginBottom: '20px',
    },
    costRow: {
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
      marginBottom: '8px',
    },
    costLabel: {
      fontSize: '14px',
      color: '#666',
    },
    costValue: {
      fontSize: '16px',
      fontWeight: '600' as const,
      color: '#1890ff',
    },
    submitButton: {
      width: '100%',
      padding: '16px',
      borderRadius: '12px',
      border: 'none',
      backgroundColor: selectedDate && selectedTime && !isSubmitting ? '#1890ff' : '#d9d9d9',
      color: 'white',
      fontSize: '16px',
      fontWeight: '600' as const,
      cursor: selectedDate && selectedTime && !isSubmitting ? 'pointer' : 'not-allowed',
    },
  };

  return (
    <div style={styles.container}>
      {/* 头部 */}
      <div style={styles.header}>
        <button style={styles.backButton} onClick={() => navigate(-1)}>
          ←
        </button>
        <div style={styles.title}>预约通话</div>
      </div>

      {/* 通话类型选择 */}
      <div style={styles.section}>
        <div style={styles.sectionTitle}>选择通话类型</div>
        <div style={styles.callTypeSelector}>
          <button
            style={styles.callTypeButton(callType === CallType.VOICE)}
            onClick={() => setCallType(CallType.VOICE)}
          >
            📞 语音通话
          </button>
          <button
            style={styles.callTypeButton(callType === CallType.VIDEO)}
            onClick={() => setCallType(CallType.VIDEO)}
          >
            📹 视频通话
          </button>
        </div>
      </div>

      {/* 日期选择 */}
      <div style={styles.section}>
        <div style={styles.sectionTitle}>选择日期</div>
        <div style={styles.dateGrid}>
          {getDateOptions().map((date) => (
            <div
              key={date.value}
              style={styles.dateOption(selectedDate === date.value)}
              onClick={() => setSelectedDate(date.value)}
            >
              <div style={styles.dateLabel}>{date.label}</div>
              <div style={styles.dateWeekday}>{date.weekday}</div>
            </div>
          ))}
        </div>
      </div>

      {/* 时间选择 */}
      {selectedDate && (
        <div style={styles.section}>
          <div style={styles.sectionTitle}>选择时间</div>
          <div style={styles.timeGrid}>
            {timeSlots.map((time) => {
              const isAvailable = appointmentService.isTimeSlotAvailable(
                new Date(`${selectedDate}T${time}:00`),
                30
              );
              return (
                <button
                  key={time}
                  style={styles.timeSlot(selectedTime === time, isAvailable)}
                  onClick={() => isAvailable && setSelectedTime(time)}
                  disabled={!isAvailable}
                >
                  {time}
                </button>
              );
            })}
          </div>
        </div>
      )}

      {/* 语言选择 */}
      <div style={styles.section}>
        <div style={styles.sectionTitle}>选择语言</div>
        <div style={styles.languageRow}>
          <select
            style={styles.languageSelect}
            value={selectedLanguages.from}
            onChange={(e) => setSelectedLanguages({...selectedLanguages, from: e.target.value})}
          >
            {languages.map(lang => (
              <option key={lang.code} value={lang.code}>
                {lang.flag} {lang.name}
              </option>
            ))}
          </select>
          
          <button 
            style={styles.swapButton} 
            onClick={() => setSelectedLanguages({
              from: selectedLanguages.to,
              to: selectedLanguages.from
            })}
          >
            🔄
          </button>
          
          <select
            style={styles.languageSelect}
            value={selectedLanguages.to}
            onChange={(e) => setSelectedLanguages({...selectedLanguages, to: e.target.value})}
          >
            {languages.map(lang => (
              <option key={lang.code} value={lang.code}>
                {lang.flag} {lang.name}
              </option>
            ))}
          </select>
        </div>
      </div>

      {/* 翻译服务选择 */}
      <div style={styles.section}>
        <div style={styles.sectionTitle}>选择翻译服务</div>
        <div style={styles.translationTypeSelector}>
          {callType === CallType.VOICE && (
            <button
              style={styles.translationTypeButton(translationType === TranslationType.TEXT)}
              onClick={() => setTranslationType(TranslationType.TEXT)}
            >
              <div>💬 实时文字翻译</div>
              <div style={{ fontSize: '12px', color: '#666', marginTop: '4px' }}>
                AI自动翻译，快速准确
              </div>
            </button>
          )}
          
          {callType === CallType.VIDEO && (
            <>
              <button
                style={styles.translationTypeButton(translationType === TranslationType.SIGN_LANGUAGE)}
                onClick={() => setTranslationType(TranslationType.SIGN_LANGUAGE)}
              >
                <div>👋 虚拟人手语翻译</div>
                <div style={{ fontSize: '12px', color: '#666', marginTop: '4px' }}>
                  AI虚拟人实时手语翻译
                </div>
              </button>
              
              <button
                style={styles.translationTypeButton(translationType === TranslationType.HUMAN_INTERPRETER)}
                onClick={() => setTranslationType(TranslationType.HUMAN_INTERPRETER)}
              >
                <div>👨‍💼 专业翻译员</div>
                <div style={{ fontSize: '12px', color: '#666', marginTop: '4px' }}>
                  人工翻译，专业可靠
                </div>
              </button>
            </>
          )}
        </div>

        {/* 翻译员选择 */}
        {translationType === TranslationType.HUMAN_INTERPRETER && (
          <div style={styles.interpreterList}>
            <div style={styles.sectionTitle}>选择翻译员</div>
            {availableInterpreters.map((interpreter) => (
              <div
                key={interpreter.id}
                style={styles.interpreterItem(selectedInterpreter?.id === interpreter.id)}
                onClick={() => setSelectedInterpreter(interpreter)}
              >
                <div style={styles.interpreterAvatar}>{interpreter.avatar}</div>
                <div style={styles.interpreterInfo}>
                  <div style={styles.interpreterName}>{interpreter.name}</div>
                  <div style={styles.interpreterDetails}>
                    {interpreter.languages.join(', ')} | ⭐ {interpreter.rating} | {interpreter.specialties.join(', ')}
                  </div>
                  <div style={styles.interpreterRate}>
                    ¥{formatCurrency(interpreter.pricePerMinute)}/分钟
                  </div>
                </div>
              </div>
            ))}
          </div>
        )}
      </div>

      {/* 备注信息 */}
      <div style={styles.section}>
        <div style={styles.sectionTitle}>备注信息（可选）</div>
        <textarea
          style={styles.descriptionInput}
          placeholder="请输入特殊要求或备注信息..."
          value={description}
          onChange={(e) => setDescription(e.target.value)}
        />
      </div>

      {/* 费用预估 */}
      {estimatedCost > 0 && (
        <div style={styles.costSummary}>
          <div style={styles.costRow}>
            <span style={styles.costLabel}>预估费用（30分钟）</span>
            <span style={styles.costValue}>¥{formatCurrency(estimatedCost)}</span>
          </div>
          <div style={styles.costRow}>
            <span style={styles.costLabel}>当前余额</span>
            <span style={styles.costValue}>
              ¥{userAccount ? formatCurrency(userAccount.balance) : '0.00'}
            </span>
          </div>
        </div>
      )}

      {/* 提交按钮 */}
      <button
        style={styles.submitButton}
        onClick={handleSubmit}
        disabled={!selectedDate || !selectedTime || isSubmitting}
      >
        {isSubmitting ? '预约中...' : '确认预约'}
      </button>
    </div>
  );
};

export default MobileAppointment; 