import { FC, useState } from 'react';

interface Document {
  id: string;
  name: string;
  size: string;
  status: 'uploading' | 'processing' | 'completed' | 'failed';
  progress: number;
  originalLanguage: string;
  targetLanguage: string;
  uploadTime: string;
}

const MobileDocuments: FC = () => {
  const [documents, setDocuments] = useState<Document[]>([
    {
      id: '1',
      name: '商业合同.pdf',
      size: '2.3 MB',
      status: 'completed',
      progress: 100,
      originalLanguage: 'zh-CN',
      targetLanguage: 'en-US',
      uploadTime: '2024-01-15 14:30',
    },
    {
      id: '2',
      name: '技术文档.docx',
      size: '1.8 MB',
      status: 'processing',
      progress: 65,
      originalLanguage: 'en-US',
      targetLanguage: 'zh-CN',
      uploadTime: '2024-01-15 15:20',
    },
  ]);

  const [selectedLanguages, setSelectedLanguages] = useState({
    from: 'zh-CN',
    to: 'en-US',
  });

  const languages = [
    { code: 'zh-CN', name: '中文', flag: '🇨🇳' },
    { code: 'en-US', name: 'English', flag: '🇺🇸' },
    { code: 'ja-JP', name: '日本語', flag: '🇯🇵' },
    { code: 'ko-KR', name: '한국어', flag: '🇰🇷' },
    { code: 'es-ES', name: 'Español', flag: '🇪🇸' },
    { code: 'fr-FR', name: 'Français', flag: '🇫🇷' },
    { code: 'de-DE', name: 'Deutsch', flag: '🇩🇪' },
  ];

  const handleFileUpload = (event: React.ChangeEvent<HTMLInputElement>) => {
    const files = event.target.files;
    if (files && files.length > 0) {
      const file = files[0];
      const newDocument: Document = {
        id: Date.now().toString(),
        name: file.name,
        size: `${(file.size / 1024 / 1024).toFixed(1)} MB`,
        status: 'uploading',
        progress: 0,
        originalLanguage: selectedLanguages.from,
        targetLanguage: selectedLanguages.to,
        uploadTime: new Date().toLocaleString('zh-CN'),
      };
      
      setDocuments(prev => [newDocument, ...prev]);
      
      // 模拟上传进度
      simulateUpload(newDocument.id);
    }
  };

  const simulateUpload = (docId: string) => {
    let progress = 0;
    const interval = setInterval(() => {
      progress += Math.random() * 15;
      if (progress >= 100) {
        progress = 100;
        setDocuments(prev => prev.map(doc => 
          doc.id === docId 
            ? { ...doc, status: 'processing', progress: 0 }
            : doc
        ));
        clearInterval(interval);
        simulateProcessing(docId);
      } else {
        setDocuments(prev => prev.map(doc => 
          doc.id === docId 
            ? { ...doc, progress: Math.floor(progress) }
            : doc
        ));
      }
    }, 200);
  };

  const simulateProcessing = (docId: string) => {
    let progress = 0;
    const interval = setInterval(() => {
      progress += Math.random() * 10;
      if (progress >= 100) {
        progress = 100;
        setDocuments(prev => prev.map(doc => 
          doc.id === docId 
            ? { ...doc, status: 'completed', progress: 100 }
            : doc
        ));
        clearInterval(interval);
      } else {
        setDocuments(prev => prev.map(doc => 
          doc.id === docId 
            ? { ...doc, progress: Math.floor(progress) }
            : doc
        ));
      }
    }, 300);
  };

  const getStatusText = (status: Document['status']) => {
    switch (status) {
      case 'uploading': return '上传中';
      case 'processing': return '翻译中';
      case 'completed': return '已完成';
      case 'failed': return '失败';
      default: return '';
    }
  };

  const getStatusColor = (status: Document['status']) => {
    switch (status) {
      case 'uploading': return '#1890ff';
      case 'processing': return '#fa8c16';
      case 'completed': return '#52c41a';
      case 'failed': return '#ff4d4f';
      default: return '#666';
    }
  };

  const swapLanguages = () => {
    setSelectedLanguages({
      from: selectedLanguages.to,
      to: selectedLanguages.from,
    });
  };

  const styles = {
    container: {
      padding: '16px',
      backgroundColor: '#f5f5f5',
      minHeight: '100%',
    },
    uploadSection: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '20px',
      marginBottom: '20px',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    uploadTitle: {
      fontSize: '18px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '16px',
      textAlign: 'center' as const,
    },
    languageSelector: {
      marginBottom: '20px',
    },
    languageRow: {
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'space-between',
      marginBottom: '12px',
    },
    languageSelect: {
      flex: 1,
      padding: '12px',
      borderRadius: '8px',
      border: '1px solid #d9d9d9',
      backgroundColor: 'white',
      fontSize: '14px',
    },
    swapButton: {
      margin: '0 12px',
      padding: '8px',
      borderRadius: '20px',
      border: 'none',
      backgroundColor: '#f0f8ff',
      cursor: 'pointer',
      fontSize: '16px',
    },
    uploadArea: {
      border: '2px dashed #d9d9d9',
      borderRadius: '8px',
      padding: '40px 20px',
      textAlign: 'center' as const,
      backgroundColor: '#fafafa',
      cursor: 'pointer',
      transition: 'border-color 0.3s ease',
    },
    uploadIcon: {
      fontSize: '48px',
      marginBottom: '12px',
      color: '#1890ff',
    },
    uploadText: {
      fontSize: '16px',
      color: '#666',
      marginBottom: '8px',
    },
    uploadSubtext: {
      fontSize: '14px',
      color: '#999',
    },
    hiddenInput: {
      display: 'none',
    },
    documentsSection: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '16px',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    sectionTitle: {
      fontSize: '18px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '16px',
    },
    documentItem: {
      display: 'flex',
      alignItems: 'center',
      padding: '16px',
      borderRadius: '8px',
      backgroundColor: '#f8f9fa',
      marginBottom: '12px',
    },
    documentIcon: {
      fontSize: '24px',
      marginRight: '12px',
    },
    documentInfo: {
      flex: 1,
    },
    documentName: {
      fontSize: '14px',
      fontWeight: '500' as const,
      color: '#333',
      marginBottom: '4px',
    },
    documentDetails: {
      fontSize: '12px',
      color: '#666',
      marginBottom: '4px',
    },
    documentLanguages: {
      fontSize: '12px',
      color: '#1890ff',
    },
    documentStatus: {
      textAlign: 'right' as const,
    },
    statusText: {
      fontSize: '12px',
      fontWeight: '500' as const,
      marginBottom: '4px',
    },
    progressBar: {
      width: '60px',
      height: '4px',
      backgroundColor: '#f0f0f0',
      borderRadius: '2px',
      overflow: 'hidden',
    },
    progressFill: {
      height: '100%',
      backgroundColor: '#1890ff',
      transition: 'width 0.3s ease',
    },
    actionButton: {
      padding: '4px 8px',
      borderRadius: '4px',
      border: 'none',
      backgroundColor: '#1890ff',
      color: 'white',
      fontSize: '12px',
      cursor: 'pointer',
      marginTop: '4px',
    },
  };

  return (
    <div style={styles.container}>
      {/* 上传区域 */}
      <div style={styles.uploadSection}>
        <h2 style={styles.uploadTitle}>📄 文档翻译</h2>
        
        {/* 语言选择 */}
        <div style={styles.languageSelector}>
          <div style={styles.languageRow}>
            <select
              style={styles.languageSelect}
              value={selectedLanguages.from}
              onChange={(e) => setSelectedLanguages({...selectedLanguages, from: e.target.value})}
            >
              {languages.map(lang => (
                <option key={lang.code} value={lang.code}>
                  {lang.flag} {lang.name}
                </option>
              ))}
            </select>
            
            <button style={styles.swapButton} onClick={swapLanguages}>
              🔄
            </button>
            
            <select
              style={styles.languageSelect}
              value={selectedLanguages.to}
              onChange={(e) => setSelectedLanguages({...selectedLanguages, to: e.target.value})}
            >
              {languages.map(lang => (
                <option key={lang.code} value={lang.code}>
                  {lang.flag} {lang.name}
                </option>
              ))}
            </select>
          </div>
        </div>

        {/* 上传区域 */}
        <label style={styles.uploadArea}>
          <input
            type="file"
            style={styles.hiddenInput}
            accept=".pdf,.doc,.docx,.txt"
            onChange={handleFileUpload}
          />
          <div style={styles.uploadIcon}>📁</div>
          <div style={styles.uploadText}>点击上传文档</div>
          <div style={styles.uploadSubtext}>
            支持 PDF、DOC、DOCX、TXT 格式
          </div>
        </label>
      </div>

      {/* 文档列表 */}
      <div style={styles.documentsSection}>
        <h3 style={styles.sectionTitle}>我的文档</h3>
        
        {documents.length === 0 ? (
          <div style={{ textAlign: 'center', padding: '40px', color: '#999' }}>
            暂无文档，请上传您的第一个文档
          </div>
        ) : (
          documents.map((doc) => (
            <div key={doc.id} style={styles.documentItem}>
              <div style={styles.documentIcon}>
                {doc.name.endsWith('.pdf') ? '📄' : '📝'}
              </div>
              
              <div style={styles.documentInfo}>
                <div style={styles.documentName}>{doc.name}</div>
                <div style={styles.documentDetails}>
                  {doc.size} • {doc.uploadTime}
                </div>
                <div style={styles.documentLanguages}>
                  {languages.find(l => l.code === doc.originalLanguage)?.flag} → {' '}
                  {languages.find(l => l.code === doc.targetLanguage)?.flag}
                </div>
              </div>
              
              <div style={styles.documentStatus}>
                <div style={{
                  ...styles.statusText,
                  color: getStatusColor(doc.status)
                }}>
                  {getStatusText(doc.status)}
                </div>
                
                {doc.status !== 'completed' && (
                  <div style={styles.progressBar}>
                    <div 
                      style={{
                        ...styles.progressFill,
                        width: `${doc.progress}%`
                      }}
                    />
                  </div>
                )}
                
                {doc.status === 'completed' && (
                  <button style={styles.actionButton}>
                    下载
                  </button>
                )}
              </div>
            </div>
          ))
        )}
      </div>
    </div>
  );
};

export default MobileDocuments; 