import { FC, useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { BillingService } from '../../services/billingService';
import { AppointmentService } from '../../services/appointmentService';
import { UserType, UserAccount, Appointment } from '../../types/billing';

const MobileHome: FC = () => {
  const navigate = useNavigate();
  const [userAccount, setUserAccount] = useState<UserAccount | null>(null);
  const [upcomingAppointments, setUpcomingAppointments] = useState<Appointment[]>([]);
  const billingService = BillingService.getInstance();
  const appointmentService = AppointmentService.getInstance();

  useEffect(() => {
    // 模拟用户账户数据
    const mockAccount: UserAccount = {
      id: 'user_1',
      userType: UserType.INDIVIDUAL,
      balance: 5000, // 50元
    };
    
    billingService.setUserAccount(mockAccount);
    setUserAccount(mockAccount);

    // 获取即将到来的预约
    const appointments = appointmentService.getUpcomingAppointments('user_1', 3);
    setUpcomingAppointments(appointments);
  }, []);

  const quickActions = [
    {
      id: 1,
      title: '语音通话',
      description: '发起实时语音翻译通话',
      icon: '📞',
      color: '#52c41a',
      action: () => navigate('/mobile/call?type=voice'),
    },
    {
      id: 2,
      title: '视频通话',
      description: '发起视频通话和手语翻译',
      icon: '📹',
      color: '#1890ff',
      action: () => navigate('/mobile/call?type=video'),
    },
    {
      id: 3,
      title: '预约通话',
      description: '预约专业翻译员服务',
      icon: '📅',
      color: '#722ed1',
      action: () => navigate('/mobile/appointment'),
    },
    {
      id: 4,
      title: '充值',
      description: '账户余额充值',
      icon: '💰',
      color: '#fa8c16',
      action: () => navigate('/mobile/recharge'),
    },
  ];

  const recentActivities = [
    {
      id: 1,
      type: 'call',
      title: '与 John Smith 的通话',
      time: '2小时前',
      status: '已完成',
      cost: '¥15.50',
    },
    {
      id: 2,
      type: 'appointment',
      title: '商务会议翻译',
      time: '明天 14:00',
      status: '已预约',
      cost: '¥180.00',
    },
    {
      id: 3,
      type: 'call',
      title: '医疗咨询翻译',
      time: '2天前',
      status: '已完成',
      cost: '¥32.00',
    },
  ];

  const formatBalance = (balance: number) => {
    return (balance / 100).toFixed(2);
  };

  const getActivityIcon = (type: string) => {
    switch (type) {
      case 'call': return '📞';
      case 'appointment': return '📅';
      case 'recharge': return '💰';
      default: return '📋';
    }
  };

  const getStatusColor = (status: string) => {
    switch (status) {
      case '已完成': return '#52c41a';
      case '已预约': return '#1890ff';
      case '进行中': return '#fa8c16';
      case '已取消': return '#ff4d4f';
      default: return '#666';
    }
  };

  const styles = {
    container: {
      padding: '16px',
      backgroundColor: '#f5f5f5',
      minHeight: '100%',
    },
    balanceCard: {
      backgroundColor: 'linear-gradient(135deg, #667eea 0%, #764ba2 100%)',
      background: 'linear-gradient(135deg, #667eea 0%, #764ba2 100%)',
      borderRadius: '16px',
      padding: '20px',
      marginBottom: '20px',
      color: 'white',
      boxShadow: '0 4px 12px rgba(102, 126, 234, 0.3)',
    },
    balanceTitle: {
      fontSize: '14px',
      opacity: 0.9,
      marginBottom: '8px',
    },
    balanceAmount: {
      fontSize: '32px',
      fontWeight: '700' as const,
      marginBottom: '4px',
    },
    balanceSubtitle: {
      fontSize: '12px',
      opacity: 0.8,
    },
    userTypeTag: {
      position: 'absolute' as const,
      top: '16px',
      right: '16px',
      backgroundColor: 'rgba(255, 255, 255, 0.2)',
      padding: '4px 8px',
      borderRadius: '12px',
      fontSize: '12px',
      fontWeight: '500' as const,
    },
    welcomeCard: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '20px',
      marginBottom: '20px',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    welcomeTitle: {
      fontSize: '24px',
      fontWeight: '600' as const,
      color: '#1890ff',
      marginBottom: '8px',
    },
    welcomeSubtitle: {
      fontSize: '16px',
      color: '#666',
      marginBottom: '0',
    },
    sectionTitle: {
      fontSize: '18px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '16px',
      marginTop: '24px',
    },
    quickActionsGrid: {
      display: 'grid',
      gridTemplateColumns: 'repeat(2, 1fr)',
      gap: '12px',
      marginBottom: '24px',
    },
    actionCard: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '16px',
      textAlign: 'center' as const,
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
      border: 'none',
      cursor: 'pointer',
      transition: 'transform 0.2s ease, box-shadow 0.2s ease',
      position: 'relative' as const,
    },
    actionIcon: {
      fontSize: '32px',
      marginBottom: '8px',
      display: 'block',
    },
    actionTitle: {
      fontSize: '14px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '4px',
    },
    actionDescription: {
      fontSize: '12px',
      color: '#666',
      lineHeight: '1.4',
    },
    appointmentPreview: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '16px',
      marginBottom: '20px',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    appointmentTitle: {
      fontSize: '16px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '12px',
    },
    appointmentItem: {
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
      padding: '8px 0',
      borderBottom: '1px solid #f0f0f0',
    },
    appointmentInfo: {
      flex: 1,
    },
    appointmentName: {
      fontSize: '14px',
      fontWeight: '500' as const,
      color: '#333',
      marginBottom: '2px',
    },
    appointmentTime: {
      fontSize: '12px',
      color: '#666',
    },
    appointmentStatus: {
      fontSize: '12px',
      padding: '2px 8px',
      borderRadius: '10px',
      backgroundColor: '#e6f7ff',
      color: '#1890ff',
    },
    activityList: {
      backgroundColor: 'white',
      borderRadius: '12px',
      padding: '16px',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    activityItem: {
      display: 'flex',
      alignItems: 'center',
      padding: '12px 0',
      borderBottom: '1px solid #f0f0f0',
    },
    activityIcon: {
      width: '40px',
      height: '40px',
      borderRadius: '20px',
      backgroundColor: '#f0f8ff',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      marginRight: '12px',
      fontSize: '18px',
    },
    activityContent: {
      flex: 1,
    },
    activityTitle: {
      fontSize: '14px',
      fontWeight: '500' as const,
      color: '#333',
      marginBottom: '4px',
    },
    activityTime: {
      fontSize: '12px',
      color: '#999',
    },
    activityRight: {
      textAlign: 'right' as const,
    },
    activityStatus: {
      fontSize: '12px',
      fontWeight: '500' as const,
      marginBottom: '4px',
    },
    activityCost: {
      fontSize: '14px',
      fontWeight: '600' as const,
      color: '#333',
    },
  };

  const handleActionPress = (action: () => void) => {
    action();
  };

  return (
    <div style={styles.container}>
      {/* 余额卡片 */}
      {userAccount && (
        <div style={styles.balanceCard}>
          <div style={styles.userTypeTag}>
            {userAccount.userType === UserType.INDIVIDUAL ? '个人用户' : '企业用户'}
          </div>
          <div style={styles.balanceTitle}>账户余额</div>
          <div style={styles.balanceAmount}>¥{formatBalance(userAccount.balance)}</div>
          <div style={styles.balanceSubtitle}>可用于通话和翻译服务</div>
        </div>
      )}

      {/* 快捷操作 */}
      <h2 style={styles.sectionTitle}>快捷操作</h2>
      <div style={styles.quickActionsGrid}>
        {quickActions.map((action) => (
          <button
            key={action.id}
            style={styles.actionCard}
            onClick={() => handleActionPress(action.action)}
            onMouseEnter={(e) => {
              e.currentTarget.style.transform = 'translateY(-2px)';
              e.currentTarget.style.boxShadow = '0 4px 12px rgba(0, 0, 0, 0.15)';
            }}
            onMouseLeave={(e) => {
              e.currentTarget.style.transform = 'translateY(0)';
              e.currentTarget.style.boxShadow = '0 2px 8px rgba(0, 0, 0, 0.1)';
            }}
          >
            <span style={styles.actionIcon}>{action.icon}</span>
            <div style={styles.actionTitle}>{action.title}</div>
            <div style={styles.actionDescription}>{action.description}</div>
          </button>
        ))}
      </div>

      {/* 即将到来的预约 */}
      {upcomingAppointments.length > 0 && (
        <div style={styles.appointmentPreview}>
          <div style={styles.appointmentTitle}>即将到来的预约</div>
          {upcomingAppointments.map((appointment) => (
            <div key={appointment.id} style={styles.appointmentItem}>
              <div style={styles.appointmentInfo}>
                <div style={styles.appointmentName}>{appointment.title}</div>
                <div style={styles.appointmentTime}>
                  {appointment.scheduledTime.toLocaleDateString()} {appointment.scheduledTime.toLocaleTimeString()}
                </div>
              </div>
              <div style={styles.appointmentStatus}>{appointment.status}</div>
            </div>
          ))}
        </div>
      )}

      {/* 最近活动 */}
      <h2 style={styles.sectionTitle}>最近活动</h2>
      <div style={styles.activityList}>
        {recentActivities.map((activity) => (
          <div key={activity.id} style={styles.activityItem}>
            <div style={styles.activityIcon}>
              {getActivityIcon(activity.type)}
            </div>
            <div style={styles.activityContent}>
              <div style={styles.activityTitle}>{activity.title}</div>
              <div style={styles.activityTime}>{activity.time}</div>
            </div>
            <div style={styles.activityRight}>
              <div style={{...styles.activityStatus, color: getStatusColor(activity.status)}}>
                {activity.status}
              </div>
              <div style={styles.activityCost}>{activity.cost}</div>
            </div>
          </div>
        ))}
      </div>
    </div>
  );
};

export default MobileHome; 