import { FC, useState, useEffect } from 'react';
import { useNavigate } from 'react-router-dom';
import { BillingService } from '../../services/billingService';
import { UserAccount, UserType } from '../../types/billing';

const MobileSettings: FC = () => {
  const navigate = useNavigate();
  const billingService = BillingService.getInstance();

  const [userAccount, setUserAccount] = useState<UserAccount | null>(null);
  const [notificationSettings, setNotificationSettings] = useState({
    callReminder: true,
    balanceAlert: true,
    promotions: false,
  });
  const [languageSettings, setLanguageSettings] = useState({
    interface: 'zh-CN',
    defaultSource: 'zh-CN',
    defaultTarget: 'en-US',
  });

  useEffect(() => {
    const account = billingService.getUserAccount();
    setUserAccount(account);
  }, []);

  const formatCurrency = (cents: number) => {
    return `¥${(cents / 100).toFixed(2)}`;
  };

  const getUserTypeText = (userType: UserType) => {
    return userType === UserType.INDIVIDUAL ? '个人用户' : '企业用户';
  };

  const handleLogout = () => {
    const confirmed = confirm('确定要退出登录吗？');
    if (confirmed) {
      // 这里应该清除用户登录状态
      navigate('/login');
    }
  };

  const settingsOptions = [
    {
      category: '账户信息',
      items: [
        {
          label: '个人资料',
          value: userAccount?.id || '未设置',
          icon: '👤',
          onClick: () => navigate('/mobile/profile'),
        },
        {
          label: '账户类型',
          value: userAccount ? getUserTypeText(userAccount.userType) : '未知',
          icon: '🏷️',
          onClick: () => {},
        },
        {
          label: '账户余额',
          value: userAccount ? formatCurrency(userAccount.balance) : '¥0.00',
          icon: '💰',
          onClick: () => navigate('/mobile/recharge'),
        },
      ],
    },
    {
      category: '通话设置',
      items: [
        {
          label: '默认通话类型',
          value: '语音通话',
          icon: '📞',
          onClick: () => {},
        },
        {
          label: '音质设置',
          value: '高清',
          icon: '🎵',
          onClick: () => {},
        },
        {
          label: '自动录音',
          value: '关闭',
          icon: '🎙️',
          onClick: () => {},
        },
      ],
    },
    {
      category: '翻译设置',
      items: [
        {
          label: '默认源语言',
          value: '中文',
          icon: '🌐',
          onClick: () => {},
        },
        {
          label: '默认目标语言',
          value: 'English',
          icon: '🌍',
          onClick: () => {},
        },
        {
          label: '翻译历史',
          value: '查看记录',
          icon: '📝',
          onClick: () => navigate('/mobile/translation-history'),
        },
      ],
    },
    {
      category: '通知设置',
      items: [
        {
          label: '通话提醒',
          value: notificationSettings.callReminder ? '开启' : '关闭',
          icon: '🔔',
          onClick: () => setNotificationSettings(prev => ({
            ...prev,
            callReminder: !prev.callReminder
          })),
        },
        {
          label: '余额提醒',
          value: notificationSettings.balanceAlert ? '开启' : '关闭',
          icon: '⚠️',
          onClick: () => setNotificationSettings(prev => ({
            ...prev,
            balanceAlert: !prev.balanceAlert
          })),
        },
        {
          label: '推广消息',
          value: notificationSettings.promotions ? '开启' : '关闭',
          icon: '📢',
          onClick: () => setNotificationSettings(prev => ({
            ...prev,
            promotions: !prev.promotions
          })),
        },
      ],
    },
    {
      category: '其他',
      items: [
        {
          label: '帮助中心',
          value: '',
          icon: '❓',
          onClick: () => navigate('/mobile/help'),
        },
        {
          label: '意见反馈',
          value: '',
          icon: '💬',
          onClick: () => navigate('/mobile/feedback'),
        },
        {
          label: '关于我们',
          value: 'v1.0.0',
          icon: 'ℹ️',
          onClick: () => navigate('/mobile/about'),
        },
        {
          label: '退出登录',
          value: '',
          icon: '🚪',
          onClick: handleLogout,
        },
      ],
    },
  ];

  const styles = {
    container: {
      backgroundColor: '#f5f5f5',
      minHeight: '100vh',
      paddingBottom: '80px',
    },
    header: {
      backgroundColor: 'white',
      padding: '16px',
      display: 'flex',
      alignItems: 'center',
      borderBottom: '1px solid #f0f0f0',
    },
    backButton: {
      background: 'none',
      border: 'none',
      fontSize: '24px',
      cursor: 'pointer',
      marginRight: '12px',
    },
    title: {
      fontSize: '20px',
      fontWeight: '600' as const,
      color: '#333',
    },
    userCard: {
      backgroundColor: 'white',
      margin: '16px',
      borderRadius: '16px',
      padding: '20px',
      display: 'flex',
      alignItems: 'center',
      boxShadow: '0 2px 12px rgba(0, 0, 0, 0.1)',
    },
    avatar: {
      width: '60px',
      height: '60px',
      borderRadius: '50%',
      backgroundColor: '#1890ff',
      display: 'flex',
      alignItems: 'center',
      justifyContent: 'center',
      fontSize: '24px',
      color: 'white',
      marginRight: '16px',
    },
    userInfo: {
      flex: 1,
    },
    userName: {
      fontSize: '18px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '4px',
    },
    userType: {
      fontSize: '14px',
      color: '#666',
      marginBottom: '8px',
    },
    balance: {
      fontSize: '16px',
      fontWeight: '600' as const,
      color: '#1890ff',
    },
    section: {
      margin: '16px',
      marginTop: '8px',
    },
    sectionTitle: {
      fontSize: '16px',
      fontWeight: '600' as const,
      color: '#333',
      marginBottom: '12px',
      paddingLeft: '4px',
    },
    settingsGroup: {
      backgroundColor: 'white',
      borderRadius: '12px',
      overflow: 'hidden',
      boxShadow: '0 2px 8px rgba(0, 0, 0, 0.1)',
    },
    settingItem: {
      padding: '16px 20px',
      display: 'flex',
      alignItems: 'center',
      borderBottom: '1px solid #f8f8f8',
      cursor: 'pointer',
      transition: 'background-color 0.2s',
    },
    settingItemLast: {
      borderBottom: 'none',
    },
    settingIcon: {
      fontSize: '20px',
      marginRight: '12px',
      width: '24px',
      textAlign: 'center' as const,
    },
    settingContent: {
      flex: 1,
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
    },
    settingLabel: {
      fontSize: '16px',
      color: '#333',
    },
    settingValue: {
      fontSize: '14px',
      color: '#666',
    },
    arrow: {
      fontSize: '12px',
      color: '#ccc',
      marginLeft: '8px',
    },
  };

  return (
    <div style={styles.container}>
      {/* 头部 */}
      <div style={styles.header}>
        <button style={styles.backButton} onClick={() => navigate(-1)}>
          ←
        </button>
        <h1 style={styles.title}>设置</h1>
      </div>

      {/* 用户信息卡片 */}
      <div style={styles.userCard}>
        <div style={styles.avatar}>
          👤
        </div>
        <div style={styles.userInfo}>
          <div style={styles.userName}>
            {userAccount?.id || '用户'}
          </div>
          <div style={styles.userType}>
            {userAccount ? getUserTypeText(userAccount.userType) : '未知类型'}
          </div>
          <div style={styles.balance}>
            余额: {userAccount ? formatCurrency(userAccount.balance) : '¥0.00'}
          </div>
        </div>
      </div>

      {/* 设置选项 */}
      {settingsOptions.map((section, sectionIndex) => (
        <div key={sectionIndex} style={styles.section}>
          <div style={styles.sectionTitle}>{section.category}</div>
          <div style={styles.settingsGroup}>
            {section.items.map((item, itemIndex) => (
              <div
                key={itemIndex}
                style={{
                  ...styles.settingItem,
                  ...(itemIndex === section.items.length - 1 ? styles.settingItemLast : {}),
                }}
                onClick={item.onClick}
              >
                <div style={styles.settingIcon}>{item.icon}</div>
                <div style={styles.settingContent}>
                  <div style={styles.settingLabel}>{item.label}</div>
                  <div style={{ display: 'flex', alignItems: 'center' }}>
                    {item.value && (
                      <div style={styles.settingValue}>{item.value}</div>
                    )}
                    <div style={styles.arrow}>›</div>
                  </div>
                </div>
              </div>
            ))}
          </div>
        </div>
      ))}
    </div>
  );
};

export default MobileSettings; 