import { 
  Appointment, 
  CallType, 
  TranslationType, 
  Interpreter 
} from '../types/billing';

export class AppointmentService {
  private static instance: AppointmentService;
  private appointments: Appointment[] = [];
  private interpreters: Interpreter[] = [];

  private constructor() {
    this.initializeMockData();
  }

  public static getInstance(): AppointmentService {
    if (!AppointmentService.instance) {
      AppointmentService.instance = new AppointmentService();
    }
    return AppointmentService.instance;
  }

  // 初始化模拟数据
  private initializeMockData() {
    // 模拟翻译员数据
    this.interpreters = [
      {
        id: 'interpreter_1',
        name: '张翻译',
        avatar: '👩‍💼',
        languages: ['zh-CN', 'en-US'],
        specialties: ['商务', '法律'],
        rating: 4.8,
        pricePerMinute: 150,
        availability: {},
        isOnline: true,
      },
      {
        id: 'interpreter_2',
        name: '李翻译',
        avatar: '👨‍💼',
        languages: ['zh-CN', 'ja-JP'],
        specialties: ['医疗', '技术'],
        rating: 4.9,
        pricePerMinute: 180,
        availability: {},
        isOnline: false,
      },
      {
        id: 'interpreter_3',
        name: '王翻译',
        avatar: '👩‍🏫',
        languages: ['zh-CN', 'ko-KR'],
        specialties: ['教育', '文化'],
        rating: 4.7,
        pricePerMinute: 120,
        availability: {},
        isOnline: true,
      },
    ];

    // 模拟预约数据
    this.appointments = [
      {
        id: 'appointment_1',
        userId: 'user_1',
        title: '商务会议翻译',
        description: '与韩国客户的商务洽谈',
        scheduledTime: new Date(Date.now() + 24 * 60 * 60 * 1000), // 明天
        duration: 60,
        callType: CallType.VIDEO,
        translationType: TranslationType.HUMAN_INTERPRETER,
        interpreterIds: ['interpreter_3'],
        estimatedCost: 18000, // 180元
        status: 'scheduled',
        createdAt: new Date(),
        updatedAt: new Date(),
      },
      {
        id: 'appointment_2',
        userId: 'user_1',
        title: '医疗咨询',
        description: '日语医疗咨询翻译',
        scheduledTime: new Date(Date.now() + 3 * 24 * 60 * 60 * 1000), // 3天后
        duration: 30,
        callType: CallType.VIDEO,
        translationType: TranslationType.HUMAN_INTERPRETER,
        interpreterIds: ['interpreter_2'],
        estimatedCost: 5400, // 54元
        status: 'confirmed',
        createdAt: new Date(),
        updatedAt: new Date(),
      },
    ];
  }

  // 创建预约
  createAppointment(appointmentData: Omit<Appointment, 'id' | 'createdAt' | 'updatedAt'>): Appointment {
    const appointment: Appointment = {
      ...appointmentData,
      id: `appointment_${Date.now()}`,
      createdAt: new Date(),
      updatedAt: new Date(),
    };

    this.appointments.push(appointment);
    return appointment;
  }

  // 获取用户预约列表
  getUserAppointments(userId: string): Appointment[] {
    return this.appointments.filter(appointment => appointment.userId === userId);
  }

  // 获取指定日期的预约
  getAppointmentsByDate(userId: string, date: Date): Appointment[] {
    const targetDate = new Date(date);
    targetDate.setHours(0, 0, 0, 0);
    const nextDate = new Date(targetDate);
    nextDate.setDate(nextDate.getDate() + 1);

    return this.appointments.filter(appointment => 
      appointment.userId === userId &&
      appointment.scheduledTime >= targetDate &&
      appointment.scheduledTime < nextDate
    );
  }

  // 获取指定月份的预约
  getAppointmentsByMonth(userId: string, year: number, month: number): Appointment[] {
    return this.appointments.filter(appointment => {
      const appointmentDate = new Date(appointment.scheduledTime);
      return appointment.userId === userId &&
             appointmentDate.getFullYear() === year &&
             appointmentDate.getMonth() === month;
    });
  }

  // 更新预约状态
  updateAppointmentStatus(appointmentId: string, status: Appointment['status']): boolean {
    const appointment = this.appointments.find(a => a.id === appointmentId);
    if (appointment) {
      appointment.status = status;
      appointment.updatedAt = new Date();
      return true;
    }
    return false;
  }

  // 取消预约
  cancelAppointment(appointmentId: string): boolean {
    return this.updateAppointmentStatus(appointmentId, 'cancelled');
  }

  // 获取可用翻译员
  getAvailableInterpreters(
    date: Date,
    languages: string[],
    specialty?: string
  ): Interpreter[] {
    const dateKey = date.toISOString().split('T')[0];
    
    return this.interpreters.filter(interpreter => {
      // 检查语言支持
      const hasLanguage = languages.some(lang => interpreter.languages.includes(lang));
      
      // 检查专业领域
      const hasSpecialty = !specialty || interpreter.specialties.includes(specialty);
      
      // 检查可用性（简化版，实际应该检查具体时间段）
      const isAvailable = interpreter.availability[dateKey] !== false;
      
      return hasLanguage && hasSpecialty && isAvailable;
    });
  }

  // 获取翻译员信息
  getInterpreter(interpreterId: string): Interpreter | null {
    return this.interpreters.find(interpreter => interpreter.id === interpreterId) || null;
  }

  // 获取所有翻译员
  getAllInterpreters(): Interpreter[] {
    return this.interpreters;
  }

  // 检查时间段是否可用
  isTimeSlotAvailable(date: Date, duration: number, interpreterIds?: string[]): boolean {
    const endTime = new Date(date.getTime() + duration * 60 * 1000);
    
    // 检查是否与现有预约冲突
    const conflicts = this.appointments.filter(appointment => {
      if (appointment.status === 'cancelled') return false;
      
      const appointmentStart = new Date(appointment.scheduledTime);
      const appointmentEnd = new Date(appointmentStart.getTime() + appointment.duration * 60 * 1000);
      
      // 检查时间是否重叠
      const timeOverlap = date < appointmentEnd && endTime > appointmentStart;
      
      // 如果指定了翻译员，检查翻译员是否冲突
      const interpreterConflict = interpreterIds && appointment.interpreterIds &&
        interpreterIds.some(id => appointment.interpreterIds!.includes(id));
      
      return timeOverlap && (!interpreterIds || interpreterConflict);
    });
    
    return conflicts.length === 0;
  }

  // 获取预约详情
  getAppointment(appointmentId: string): Appointment | null {
    return this.appointments.find(appointment => appointment.id === appointmentId) || null;
  }

  // 获取即将到来的预约
  getUpcomingAppointments(userId: string, limit: number = 5): Appointment[] {
    const now = new Date();
    return this.appointments
      .filter(appointment => 
        appointment.userId === userId &&
        appointment.scheduledTime > now &&
        appointment.status !== 'cancelled'
      )
      .sort((a, b) => a.scheduledTime.getTime() - b.scheduledTime.getTime())
      .slice(0, limit);
  }
} 